@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -26,9 +26,9 @@ if platform.system() == 'Windows':
 from PyQt5.QtCore import QTimer, QMutex
 
 # local imports
-from gui.utilities.toolsQtWidget import sleepAndEvents
-from base.tpool import Worker
-from base.driverDataClass import DriverData
+from mw4.gui.utilities.toolsQtWidget import sleepAndEvents
+from mw4.base.tpool import Worker
+from mw4.base.driverDataClass import DriverData
 
 
 class AscomClass(DriverData):
@@ -36,18 +36,19 @@ class AscomClass(DriverData):
     """
 
     log = logging.getLogger(__name__)
-    CYCLE_POLL_STATUS = 3000
-    CYCLE_POLL_DATA = 3000
 
-    def __init__(self, app=None, data=None, threadPool=None):
+    def __init__(self, app=None, data=None):
         super().__init__()
 
         self.app = app
-        self.threadPool = threadPool
+        self.data = data
+        self.threadPool = app.threadPool
+        self.msg = app.msg
+        self.updateRate = 3000
+        self.loadConfig = False
         self.tM = QMutex()
 
         self.client = None
-        self.data = data
         self.propertyExceptions = []
         self.deviceName = ''
         self.deviceConnected = False
@@ -69,8 +70,8 @@ class AscomClass(DriverData):
         """
         :return: true for test purpose
         """
-        self.cyclePollData.start(self.CYCLE_POLL_DATA)
-        self.cyclePollStatus.start(self.CYCLE_POLL_STATUS)
+        self.cyclePollData.start(self.updateRate)
+        self.cyclePollStatus.start(self.updateRate)
         return True
 
     def stopTimer(self):
@@ -87,7 +88,6 @@ class AscomClass(DriverData):
         :return: value
         """
         value = None
-        valueProp = valueProp.lower()
         if valueProp in self.propertyExceptions:
             return value
 
@@ -99,7 +99,7 @@ class AscomClass(DriverData):
             self.log.debug(t)
             self.propertyExceptions.append(valueProp)
         else:
-            if valueProp != 'imagearray':
+            if valueProp != 'ImageArray':
                 t = f'[{self.deviceName}] property [{valueProp}] has value: [{value}]'
                 self.log.trace(t)
             else:
@@ -112,7 +112,6 @@ class AscomClass(DriverData):
         :param valueProp:
         :param value:
         """
-        valueProp = valueProp.lower()
         if valueProp in self.propertyExceptions:
             return False
 
@@ -122,7 +121,7 @@ class AscomClass(DriverData):
         except Exception as e:
             t = f'[{self.deviceName}] [{cmd}], property [{valueProp}] not implemented: {e}'
             self.log.debug(t)
-            if valueProp != 'Connect':
+            if valueProp != 'Connected':
                 self.propertyExceptions.append(valueProp)
             return False
         else:
@@ -173,8 +172,8 @@ class AscomClass(DriverData):
         """
         self.propertyExceptions = []
         for retry in range(0, 10):
-            self.setAscomProperty('connected', True)
-            suc = self.getAscomProperty('connected')
+            self.setAscomProperty('Connected', True)
+            suc = self.getAscomProperty('Connected')
 
             if suc:
                 t = f'[{self.deviceName}] connected, retries: [{retry}]'
@@ -188,7 +187,7 @@ class AscomClass(DriverData):
             suc = False
 
         if not suc:
-            self.app.message.emit(f'ASCOM connect error: [{self.deviceName}]', 2)
+            self.msg.emit(2, 'ASCOM ', 'Connect error', f'{self.deviceName}')
             self.deviceConnected = False
             self.serverConnected = False
             return False
@@ -200,7 +199,7 @@ class AscomClass(DriverData):
         if not self.deviceConnected:
             self.deviceConnected = True
             self.signals.deviceConnected.emit(f'{self.deviceName}')
-            self.app.message.emit(f'ASCOM device found:  [{self.deviceName}]', 0)
+            self.msg.emit(0, 'ASCOM ', 'Device found', f'{self.deviceName}')
         return True
 
     def workerGetInitialConfig(self):
@@ -216,17 +215,17 @@ class AscomClass(DriverData):
         """
         :return: success
         """
-        suc = self.getAscomProperty('connected')
+        suc = self.getAscomProperty('Connected')
 
         if self.deviceConnected and not suc:
             self.deviceConnected = False
             self.signals.deviceDisconnected.emit(f'{self.deviceName}')
-            self.app.message.emit(f'ASCOM device remove: [{self.deviceName}]', 0)
+            self.msg.emit(0, 'ASCOM ', 'Device remove', f'{self.deviceName}')
 
         elif not self.deviceConnected and suc:
             self.deviceConnected = True
             self.signals.deviceConnected.emit(f'{self.deviceName}')
-            self.app.message.emit(f'ASCOM device found:  [{self.deviceName}]', 0)
+            self.msg.emit(0, 'ASCOM ', 'Device found', f'{self.deviceName}')
 
         return suc
 
@@ -305,9 +304,8 @@ class AscomClass(DriverData):
         self.callMethodThreaded(self.workerGetInitialConfig)
         return True
 
-    def startCommunication(self, loadConfig=False):
+    def startCommunication(self):
         """
-        :param loadConfig:
         :return: True for test purpose
         """
         self.data.clear()
@@ -343,5 +341,5 @@ class AscomClass(DriverData):
             self.propertyExceptions = []
         self.signals.deviceDisconnected.emit(f'{self.deviceName}')
         self.signals.serverDisconnected.emit({f'{self.deviceName}': 0})
-        self.app.message.emit(f'ASCOM device remove: [{self.deviceName}]', 0)
+        self.msg.emit(0, 'ALPACA', 'Device  remove', f'{self.deviceName}')
         return True
