@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -21,7 +21,7 @@ import logging
 from skyfield.api import Angle
 
 # local import
-from mountcontrol.convert import convertToAngle, convertRaToAngle, convertDecToAngle
+from mw4.mountcontrol.convert import convertToAngle, convertRaToAngle, convertDecToAngle
 
 __all__ = ['getCoordinates',
            'getSQM',
@@ -32,11 +32,14 @@ __all__ = ['getCoordinates',
 log = logging.getLogger()
 
 
-def getCoordinates(header={}):
+def getCoordinates(header=None):
     """
     :param header:
     :return:
     """
+    if header is None:
+        header = {}
+
     if 'RA' in header and 'DEC' in header:
         hasDecimal = True
     else:
@@ -50,24 +53,30 @@ def getCoordinates(header={}):
     if hasDecimal:
         ra = convertToAngle(header['RA'], isHours=True)
         dec = convertToAngle(header['DEC'], isHours=False)
+        log.debug('Decimal coordinates used')
     elif hasSexagesimal:
         ra = convertRaToAngle(header['OBJCTRA'])
         dec = convertDecToAngle(header['OBJCTDEC'])
+        log.debug('Sexagesimal coordinates used')
     else:
         ra = Angle(hours=0)
         dec = Angle(degrees=0)
+        log.debug('No coordinates found')
 
-    log.debug(f'HasFloat: [{hasDecimal}], HasDeg: [{hasSexagesimal}], Header:[{header}]')
-    log.debug(f'Ra:[{ra}][{ra.hours}], Dec: [{dec}][{dec.degrees}]')
+    log.trace(f'Header:[{header}]')
+    log.debug(f'Ra:[{ra}][{ra.hours}][{ra._degrees}], Dec: [{dec}][{dec.degrees}]')
 
     return ra, dec
 
 
-def getSQM(header={}):
+def getSQM(header=None):
     """
     :param header:
     :return:
     """
+    if header is None:
+        header = {}
+
     for key in ['SQM', 'SKY-QLTY', 'MPSAS']:
         value = header.get(key)
         if value is None:
@@ -78,11 +87,14 @@ def getSQM(header={}):
     return float(value)
 
 
-def getExposure(header={}):
+def getExposure(header=None):
     """
     :param header:
     :return:
     """
+    if header is None:
+        header = {}
+
     for key in ['EXPOSURE', 'EXPTIME']:
         value = header.get(key)
         if value is None:
@@ -93,11 +105,14 @@ def getExposure(header={}):
     return float(value)
 
 
-def getScale(header={}):
+def getScale(header=None):
     """
     :param header:
     :return:
     """
+    if header is None:
+        header = {}
+
     hasScale = 'SCALE' in header
     focalLength = float(header.get('FOCALLEN', 0))
     binning = float(header.get('XBINNING', 0))
