@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -21,8 +21,9 @@ import logging
 from PyQt5.QtCore import QTimer
 
 # local imports
-from gui.utilities.toolsQtWidget import sleepAndEvents
-from indibase.qtIndiBase import Client
+from mw4.gui.utilities.toolsQtWidget import sleepAndEvents
+from mw4.indibase.indiBase import Client
+from mw4.base.driverDataClass import Signals
 
 
 class IndiClass:
@@ -34,7 +35,8 @@ class IndiClass:
 
     RETRY_DELAY = 1500
     NUMBER_RETRY = 5
-    UPDATE_RATE = 1000
+
+    SHOW_COMM = False
 
     INDIGO = {
         # numbers
@@ -81,6 +83,13 @@ class IndiClass:
         'X_AUX_OUTLET_NAMES.POWER_OUTLET_NAME_2': 'POWER_CONTROL_LABEL.POWER_LABEL_2',
         'X_AUX_OUTLET_NAMES.POWER_OUTLET_NAME_3': 'POWER_CONTROL_LABEL.POWER_LABEL_3',
         'X_AUX_OUTLET_NAMES.POWER_OUTLET_NAME_4': 'POWER_CONTROL_LABEL.POWER_LABEL_4',
+
+        # Uranus Meteo device
+        'SENSORS.AbsolutePressure': 'WEATHER_PARAMETERS.WEATHER_PRESSURE',
+        'SENSORS.DewPoint': 'WEATHER_PARAMETERS.WEATHER_DEWPOINT',
+        'CLOUDS.CloudSkyTemperature': 'SKY_QUALITY.SKY_TEMPERATURE',
+        'SKYQUALITY.MPAS': 'SKY_QUALITY.SKY_BRIGHTNESS',
+
     }
 
     INDI = {y: x for x, y in INDIGO.items()}
@@ -97,22 +106,21 @@ class IndiClass:
         'covercalibrator': (1 << 9) | (1 << 10),
         'switch': (1 << 7) | (1 << 3) | (1 << 15) | (1 << 18),
     }
+    signals = Signals()
 
-    def __init__(self, app=None, data=None, threadPool=None):
+    def __init__(self, app=None, data=None):
         self.app = app
+        self.msg = app.msg
         self.data = data
-        self.client = Client(host=None, threadPool=threadPool)
+        self.threadPool = app.threadPool
+        self.client = Client(host=None)
 
-        if self.app is not None:
-            # this is for direct use of indiClass in devicePopupW for
-            # device discovery as we have in this case no app link, but we
-            # need the signaling work.
-            clientSig = self.client.signals
-            selfSig = self.signals
-            clientSig.deviceConnected.connect(selfSig.deviceConnected)
-            clientSig.deviceDisconnected.connect(selfSig.deviceDisconnected)
-            clientSig.serverConnected.connect(selfSig.serverConnected)
-            clientSig.serverDisconnected.connect(selfSig.serverDisconnected)
+        clientSig = self.client.signals
+        selfSig = self.signals
+        clientSig.deviceConnected.connect(selfSig.deviceConnected)
+        clientSig.deviceDisconnected.connect(selfSig.deviceDisconnected)
+        clientSig.serverConnected.connect(selfSig.serverConnected)
+        clientSig.serverDisconnected.connect(selfSig.serverDisconnected)
 
         self.deviceName = ''
         self.device = None
@@ -120,10 +128,8 @@ class IndiClass:
         self._hostaddress = None
         self._host = None
         self._port = None
-        self.retryCounter = 0
         self.discoverType = None
         self.discoverList = None
-        self.loadIndiConfig = False
         self.isINDIGO = False
         self.messages = False
 
@@ -134,6 +140,7 @@ class IndiClass:
             'port': 7624,
             'loadConfig': False,
             'messages': False,
+            'updateRate': 1000,
         }
 
         self.timerRetry = QTimer()
@@ -153,7 +160,6 @@ class IndiClass:
         self.client.signals.defLight.connect(self.updateLight)
         self.client.signals.newBLOB.connect(self.updateBLOB)
         self.client.signals.defBLOB.connect(self.updateBLOB)
-        self.client.signals.deviceConnected.connect(self.loadConfig)
         self.client.signals.deviceConnected.connect(self.setUpdateConfig)
         self.client.signals.serverConnected.connect(self.serverConnected)
         self.client.signals.serverDisconnected.connect(self.serverDisconnected)
@@ -196,8 +202,9 @@ class IndiClass:
         """
         if self.deviceName:
             suc = self.client.watchDevice(self.deviceName)
-            self.log.debug(f'INDI watch: [{self.deviceName}], result: [{suc}]')
+            self.log.info(f'INDI watch: [{self.deviceName}], result: [{suc}]')
             return suc
+        self.client.watchDevice()
         return False
 
     def serverDisconnected(self, devices):
@@ -205,8 +212,7 @@ class IndiClass:
         :param devices:
         :return: true for test purpose
         """
-        t = f'INDI server for [{self.deviceName}] disconnected, '
-        t += f'related devices: {devices.keys()}'
+        t = f'INDI server for [{self.deviceName}] disconnected'
         self.log.debug(t)
         return True
 
@@ -221,7 +227,7 @@ class IndiClass:
         """
         if deviceName == self.deviceName:
             self.device = self.client.getDevice(deviceName)
-            self.app.message.emit(f'INDI device found:   [{deviceName}]', 0)
+            self.msg.emit(0, 'INDI', 'Device found', f'{deviceName}')
         else:
             self.log.info(f'INDI device snoop: [{deviceName}]')
         return True
@@ -235,7 +241,7 @@ class IndiClass:
         :return: true for test purpose
         """
         if deviceName == self.deviceName:
-            self.app.message.emit(f'INDI removed device: [{deviceName}]', 0)
+            self.msg.emit(0, 'INDI', 'Device removed', f'{deviceName}')
             self.device = None
             self.data.clear()
             return True
@@ -250,45 +256,27 @@ class IndiClass:
 
         :return: True for test purpose
         """
+        self.timerRetry.start(self.RETRY_DELAY)
         if not self.deviceName:
             return False
-        if self.data:
-            self.deviceConnected = True
-            return True
+        if self.client.connected:
+            return False
 
-        self.retryCounter += 1
-        suc = self.client.connectServer()
-        if suc:
-            return True
+        self.client.connectServer()
+        return True
 
-        t = f'Cannot start: [{self.deviceName}] retries: [{self.retryCounter}]'
-        self.log.debug(t)
-        if self.retryCounter < self.NUMBER_RETRY:
-            self.timerRetry.start(self.RETRY_DELAY)
-        return False
-
-    def startCommunication(self, loadConfig=False):
+    def startCommunication(self):
         """
-        :param loadConfig:
         :return: success of reconnecting to server
         """
         self.data.clear()
-        self.loadIndiConfig = loadConfig
-        self.retryCounter = 0
-        self.client.startTimers()
-        suc = self.client.connectServer()
-        if not suc:
-            t = f'Cannot start: [{self.deviceName}] retries: [{self.retryCounter}]'
-            self.log.debug(t)
-        else:
-            self.timerRetry.start(self.RETRY_DELAY)
-        return suc
+        self.timerRetry.start(self.RETRY_DELAY)
+        return True
 
     def stopCommunication(self):
         """
         :return: success of reconnecting to server
         """
-        self.client.stopTimers()
         suc = self.client.disconnectServer(self.deviceName)
         self.deviceName = ''
         self.deviceConnected = False
@@ -312,23 +300,21 @@ class IndiClass:
             suc = self.client.connectDevice(deviceName=deviceName)
         return suc
 
-    def loadConfig(self, deviceName):
+    def loadIndiConfig(self, deviceName):
         """
-        loadConfig send the command to the indi server to load the default
+        loadIndiConfig send the command to the indi server to load the default
         config for the given device.
 
         :param deviceName:
         :return: success
         """
-        if not self.loadIndiConfig:
-            return False
-
         loadObject = self.device.getSwitch('CONFIG_PROCESS')
         loadObject['CONFIG_LOAD'] = True
         suc = self.client.sendNewSwitch(deviceName=deviceName,
                                         propertyName='CONFIG_PROCESS',
-                                        elements=loadObject,
-                                        )
+                                        elements=loadObject)
+        t = f'Config load [{deviceName}] success: [{suc}], value: [True]'
+        self.log.info(t)
         return suc
 
     def setUpdateConfig(self, deviceName):
@@ -336,7 +322,22 @@ class IndiClass:
         :param deviceName:
         :return: success
         """
-        pass
+        if deviceName != self.deviceName:
+            return False
+        if self.device is None:
+            return False
+
+        if self.loadConfig:
+            self.loadIndiConfig(deviceName=deviceName)
+
+        update = self.device.getNumber('POLLING_PERIOD')
+        update['PERIOD_MS'] = int(self.updateRate)
+        suc = self.client.sendNewNumber(deviceName=deviceName,
+                                        propertyName='POLLING_PERIOD',
+                                        elements=update)
+        t = f'Polling [{deviceName}] success: [{suc}], value:[{update["PERIOD_MS"]}]'
+        self.log.info(t)
+        return suc
 
     def convertIndigoProperty(self, key):
         """
@@ -364,7 +365,8 @@ class IndiClass:
 
         for element, value in self.device.getNumber(propertyName).items():
             key = propertyName + '.' + element
-            # print('number', self.deviceName, key, value)
+            if self.SHOW_COMM:
+                print('number', self.deviceName, key, value)
             key = self.convertIndigoProperty(key)
             self.data[key] = float(value)
 
@@ -390,7 +392,8 @@ class IndiClass:
             # todo: is that the item which tells me it's an indigo server ?
             if propertyName == 'PROFILE':
                 self.isINDIGO = True
-            # print('switch', self.deviceName, key, value)
+            if self.SHOW_COMM:
+                print('switch', self.deviceName, key, value)
             key = self.convertIndigoProperty(key)
             self.data[key] = value == 'On'
 
@@ -413,7 +416,8 @@ class IndiClass:
 
         for element, value in self.device.getText(propertyName).items():
             key = propertyName + '.' + element
-            # print('text  ', self.deviceName, key, value)
+            if self.SHOW_COMM:
+                print('text  ', self.deviceName, key, value)
             key = self.convertIndigoProperty(key)
             self.data[key] = value
 
@@ -436,7 +440,8 @@ class IndiClass:
 
         for element, value in self.device.getLight(propertyName).items():
             key = propertyName + '.' + element
-            # print('light ', self.deviceName, key, value)
+            if self.SHOW_COMM:
+                print('light ', self.deviceName, key, value)
             key = self.convertIndigoProperty(key)
             self.data[key] = value
 
@@ -456,6 +461,8 @@ class IndiClass:
             return False
         if deviceName != self.deviceName:
             return False
+        if self.SHOW_COMM:
+            print('blob ', deviceName)
         return True
 
     @staticmethod
@@ -481,23 +488,26 @@ class IndiClass:
         if self.messages:
             if text.startswith('[WARNING]'):
                 text = self.removePrefix(text, '[WARNING]')
-                self.app.message.emit(f'INDI {device:15s} {text}', 0)
+                self.msg.emit(0, 'INDI', 'Device warning', f'{device:15s} {text}')
+            elif text.startswith('[INFO]'):
+                text = self.removePrefix(text, '[INFO]')
+                self.msg.emit(0, 'INDI', 'Device info', f'{device:15s} {text}')
             elif text.startswith('[ERROR]'):
                 text = self.removePrefix(text, '[ERROR]')
-                self.app.message.emit(f'INDI {device:15s} {text}', 2)
+                self.msg.emit(2, 'INDI', 'Device error', f'{device:15s} {text}')
             else:
-                self.app.message.emit(f'INDI {device:15s} {text}', 0)
+                self.msg.emit(0, 'INDI', 'Device message', f'{device:15s} {text}')
             return True
         return False
 
     def addDiscoveredDevice(self, deviceName, propertyName):
         """
         addDevicesWithType gety called whenever a new device send out text
-        messages. than it checks, if the device type fits to the search type
+        messages. then it checks, if the device type fits to the search type
         desired. if they match, the device name is added to the list.
 
-        unfortunately the indi definitions are not well defined. so for example
-        SQM reports only aux general. this is value '0'. So i have to treat all
+        unfortunately the indi definitions are not well-defined. so for example
+        SQM reports only aux general. this is value '0'. So I have to treat all
         devices reporting device type '0' as devices which could be used for
         everything.
 
@@ -528,14 +538,14 @@ class IndiClass:
 
     def discoverDevices(self, deviceType=''):
         """
-        discoverDevices implements a discover for devices of a certain device
+        discoverDevices implements a discovery for devices of a certain device
         type. it is called from a button press and checks which button it was.
         after that for the right device it collects all necessary data for host
         value, instantiates an INDI client and watches for all devices connected
-        to this server. Than it connects a subroutine for collecting the right
+        to this server. Then it connects a subroutine for collecting the right
         device names and waits a certain amount of time. the data collection
         takes place as long as the model dialog is open. when the user closes
-        this dialog, the collected data is written to the drop down list.
+        this dialog, the collected data is written to the drop-down list.
 
         :param deviceType: device type of discovered indi devices
         :return: success
@@ -544,7 +554,6 @@ class IndiClass:
         self.discoverType = self.INDI_TYPES.get(deviceType, 0)
         self.client.signals.defText.connect(self.addDiscoveredDevice)
         self.client.connectServer()
-        self.client.watchDevice()
         sleepAndEvents(2000)
         self.client.signals.defText.disconnect(self.addDiscoveredDevice)
         self.client.disconnectServer()
