@@ -106,7 +106,7 @@ def redirectSTD():
     """
     # transfer all sys outputs to logging
     sys.stderr = LoggerWriter(logging.getLogger().error, 'STDERR', sys.stderr)
-    sys.stdout = LoggerWriter(logging.getLogger().info, 'STDOUT', sys.stdout)
+    # sys.stdout = LoggerWriter(logging.getLogger().info, 'STDOUT', sys.stdout)
     return True
 
 
@@ -137,7 +137,7 @@ def setupLogging(redirect=True):
 
     # setting different log level for imported packages to avoid unnecessary data
     # urllib3 is used by requests, so we have to add this as well
-    logging.getLogger('PyQt5').setLevel(logging.WARNING)
+    logging.getLogger('PyQt5').setLevel(logging.DEBUG)
     logging.getLogger('requests').setLevel(logging.WARNING)
     logging.getLogger('urllib3').setLevel(logging.WARNING)
     logging.getLogger('astropy').setLevel(logging.WARNING)
