@@ -23,9 +23,9 @@ from PyQt5.QtCore import QTimer, QObject
 import requests
 
 # local imports
-from base.driverDataClass import DriverData
-from base.driverDataClass import RemoteDeviceShutdown
-from base.tpool import Worker
+from mw4.base.driverDataClass import DriverData
+from mw4.base.driverDataClass import RemoteDeviceShutdown
+from mw4.base.tpool import Worker
 
 
 class NINAClass(DriverData, QObject):
@@ -34,7 +34,7 @@ class NINAClass(DriverData, QObject):
     log = logging.getLogger(__name__)
 
     NINA_TIMEOUT = 3
-    HOST_ADDR = '127.0.0.1'
+    HOST_ADDR = 'localhost'
     PORT = 59590
     PROTOCOL = 'http'
     BASE_URL = f'{PROTOCOL}://{HOST_ADDR}:{PORT}'
