@@ -24,10 +24,11 @@ isReference = False
 isWindows = platform.system() == 'Windows'
 isLinux = platform.system() == 'Linux'
 isMac = platform.system() == 'Darwin'
+enableAutomation = True
 
 
 def checkAutomation():
     verResult = Version('3.8.2') <= Version(platform.python_version())
     winResult = platform.system() == 'Windows'
     result = verResult and winResult
-    return result
+    return result and enableAutomation
