@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -24,9 +23,9 @@ from PyQt5.QtCore import QTimer, QObject
 import requests
 
 # local imports
-from base.driverDataClass import DriverData
-from base.driverDataClass import RemoteDeviceShutdown
-from base.tpool import Worker
+from mw4.base.driverDataClass import DriverData
+from mw4.base.driverDataClass import RemoteDeviceShutdown
+from mw4.base.tpool import Worker
 
 
 class SGProClass(DriverData, QObject):
@@ -34,19 +33,20 @@ class SGProClass(DriverData, QObject):
     """
     log = logging.getLogger(__name__)
 
-    CYCLE_POLL_STATUS = 1000
-    CYCLE_POLL_DATA = 1000
-    SGPRO_TIMEOUT = 1
-    HOST_ADDR = '127.0.0.1'
+    SGPRO_TIMEOUT = 3
+    HOST_ADDR = 'localhost'
     PORT = 59590
     PROTOCOL = 'http'
     BASE_URL = f'{PROTOCOL}://{HOST_ADDR}:{PORT}'
 
-    def __init__(self, app=None, data=None, threadPool=None):
+    def __init__(self, app=None, data=None):
         super().__init__()
         self.app = app
-        self.threadPool = threadPool
+        self.threadPool = app.threadPool
+        self.msg = app.msg
         self.data = data
+        self.updateRate = 1000
+        self.loadConfig = False
         self._deviceName = ''
         self.defaultConfig = {
             'deviceList': ['SGPro controlled'],
@@ -121,7 +121,7 @@ class SGProClass(DriverData, QObject):
         if response is None:
             return False
 
-        return response['Success']
+        return response.get('Success', '')
 
     def sgDisconnectDevice(self):
         """
@@ -132,7 +132,7 @@ class SGProClass(DriverData, QObject):
         if response is None:
             return False
 
-        return response['Success']
+        return response.get('Success', '')
 
     def sgEnumerateDevice(self):
         """
@@ -143,7 +143,7 @@ class SGProClass(DriverData, QObject):
         if response is None:
             return []
 
-        return response['Devices']
+        return response.get('Devices', '')
 
     def workerConnectDevice(self):
         """
@@ -166,7 +166,8 @@ class SGProClass(DriverData, QObject):
             t = f'[{self.deviceName}] connected'
             self.log.debug(t)
         else:
-            self.app.message.emit(f'SGPro connect error: [{self.deviceName}]', 2)
+            self.msg.emit(2, 'SGPRO', 'Connect error',
+                          f'{self.deviceName}')
             self.deviceConnected = False
             self.serverConnected = False
         return suc
@@ -175,8 +176,8 @@ class SGProClass(DriverData, QObject):
         """
         :return: true for test purpose
         """
-        self.cycleData.start(self.CYCLE_POLL_DATA)
-        self.cycleDevice.start(self.CYCLE_POLL_STATUS)
+        self.cycleData.start(self.updateRate)
+        self.cycleDevice.start(self.updateRate)
         return True
 
     def stopTimer(self):
@@ -228,18 +229,20 @@ class SGProClass(DriverData, QObject):
         self.storePropertyToData(response['State'], 'Device.Status')
         self.storePropertyToData(response['Message'], 'Device.Message')
 
-        if response['State'] == 'DISCONNECTED':
+        if response.get('State', '') == 'DISCONNECTED':
             if self.deviceConnected:
                 self.deviceConnected = False
                 self.signals.deviceDisconnected.emit(f'{self.deviceName}')
-                self.app.message.emit(f'SGPro device remove: [{self.deviceName}]', 0)
+                self.msg.emit(0, 'SGPRO', 'Device remove',
+                              f'{self.deviceName}')
 
         else:
             if not self.deviceConnected:
                 self.deviceConnected = True
                 self.getInitialConfig()
                 self.signals.deviceConnected.emit(f'{self.deviceName}')
-                self.app.message.emit(f'SGPro device found:  [{self.deviceName}]', 0)
+                self.msg.emit(0, 'SGPRO', 'Device found',
+                              f'{self.deviceName}')
 
         return True
 
@@ -251,9 +254,8 @@ class SGProClass(DriverData, QObject):
         self.threadPool.start(worker)
         return True
 
-    def startCommunication(self, loadConfig=False):
+    def startCommunication(self):
         """
-        :param: loadConfig:
         :return: True for test purpose
         """
         self.data.clear()
@@ -277,7 +279,8 @@ class SGProClass(DriverData, QObject):
         self.serverConnected = False
         self.signals.deviceDisconnected.emit(f'{self.deviceName}')
         self.signals.serverDisconnected.emit({f'{self.deviceName}': 0})
-        self.app.message.emit(f'SGPro device remove: [{self.deviceName}]', 0)
+        self.msg.emit(0, 'SGPRO', 'Device remove',
+                      f'{self.deviceName}')
         return True
 
     def discoverDevices(self):
