@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -19,39 +19,26 @@ import platform
 
 # external packages
 from PyQt5.QtCore import Qt
-from PyQt5.QtWidgets import QWidget, QListView, QComboBox, QLineEdit
+from PyQt5.QtWidgets import QListView, QComboBox, QLineEdit
 from PyQt5.QtWidgets import QCheckBox, QDoubleSpinBox
 
 if platform.system() == 'Windows':
     import win32com.client
 
 # local import
-from base.indiClass import IndiClass
-from base.alpacaClass import AlpacaClass
-from base.sgproClass import SGProClass
-from base.ninaClass import NINAClass
-from gui.utilities import toolsQtWidget
-from gui.widgets.devicePopup_ui import Ui_DevicePopup
+from mw4.base.indiClass import IndiClass
+from mw4.base.alpacaClass import AlpacaClass
+from mw4.base.sgproClass import SGProClass
+from mw4.base.ninaClass import NINAClass
+from mw4.gui.utilities import toolsQtWidget
+from mw4.gui.widgets.devicePopup_ui import Ui_DevicePopup
 
 
 class DevicePopup(toolsQtWidget.MWidget):
     """
     """
 
-    __all__ = ['DevicePopup',
-               ]
-
-    framework2tabs = {
-        'indi': 'INDI / INDIGO',
-        'ascom': 'ASCOM',
-        'alpaca': 'ALPACA',
-        'sgpro': 'SGPro',
-        'nina': 'N.I.N.A.',
-        'astrometry': 'astrometry',
-        'astap': 'ASTAP',
-        'onlineWeather': 'Online Weather',
-        'relay': 'Relay',
-    }
+    __all__ = ['DevicePopup']
 
     def __init__(self,
                  parentWidget,
@@ -65,7 +52,7 @@ class DevicePopup(toolsQtWidget.MWidget):
         self.data = data
         self.driver = driver
         self.deviceType = deviceType
-        self.message = app.message
+        self.msg = app.msg
 
         self.ui = Ui_DevicePopup()
         self.ui.setupUi(self)
@@ -84,12 +71,15 @@ class DevicePopup(toolsQtWidget.MWidget):
                 'deviceList': self.ui.indiDeviceList,
                 'messages': self.ui.indiMessages,
                 'loadConfig': self.ui.indiLoadConfig,
+                'updateRate': self.ui.indiUpdateRate,
             },
             'alpaca': {
                 'hostaddress': self.ui.alpacaHostAddress,
                 'port': self.ui.alpacaPort,
                 'user': self.ui.alpacaUser,
                 'password': self.ui.alpacaPassword,
+                'deviceList': self.ui.alpacaDeviceList,
+                'updateRate': self.ui.alpacaUpdateRate,
             },
             'ascom': {
                 'deviceName': self.ui.ascomDevice,
@@ -114,10 +104,21 @@ class DevicePopup(toolsQtWidget.MWidget):
                 'appPath': self.ui.astapAppPath,
                 'indexPath': self.ui.astapIndexPath,
             },
+            'watney': {
+                'deviceList': self.ui.watneyDeviceList,
+                'searchRadius': self.ui.watneySearchRadius,
+                'timeout': self.ui.watneyTimeout,
+                'appPath': self.ui.watneyAppPath,
+                'indexPath': self.ui.watneyIndexPath,
+            },
             'onlineWeather': {
                 'apiKey': self.ui.onlineWeatherApiKey,
                 'hostaddress': self.ui.onlineWeatherHostAddress,
             },
+            'seeing': {
+                'apiKey': self.ui.seeingWeatherApiKey,
+                'hostaddress': self.ui.seeingWeatherHostAddress,
+            },
             'relay': {
                 'hostaddress': self.ui.relayHostAddress,
                 'user': self.ui.relayUser,
@@ -135,16 +136,15 @@ class DevicePopup(toolsQtWidget.MWidget):
         self.ui.selectAstrometryAppPath.clicked.connect(self.selectAstrometryAppPath)
         self.ui.selectAstapIndexPath.clicked.connect(self.selectAstapIndexPath)
         self.ui.selectAstapAppPath.clicked.connect(self.selectAstapAppPath)
+        self.ui.selectWatneyIndexPath.clicked.connect(self.selectWatneyIndexPath)
+        self.ui.selectWatneyAppPath.clicked.connect(self.selectWatneyAppPath)
         self.ui.ascomSelector.clicked.connect(self.selectAscomDriver)
-
         self.initConfig()
         self.show()
 
     def selectTabs(self):
         """
         show only the tabs needed for available frameworks and properties to be
-        entered as there might be differences in tab text and framework name
-        internally there is a translation table (self.framework2tabs) in between.
         - it selects the tab for the actual framework
         - it hides all tabs, which are not relevant for the available frameworks
 
@@ -155,16 +155,12 @@ class DevicePopup(toolsQtWidget.MWidget):
         if not framework:
             framework = firstFramework
 
-        frameworkTabTextList = [self.framework2tabs[x] for x in self.data['frameworks']]
-        tabWidget = self.ui.tab.findChild(QWidget, framework)
-        tabIndex = self.ui.tab.indexOf(tabWidget)
+        tabIndex = self.getTabIndex(self.ui.tab, framework)
         self.ui.tab.setCurrentIndex(tabIndex)
 
         for index in range(0, self.ui.tab.count()):
-            if self.ui.tab.tabText(index) in frameworkTabTextList:
-                self.ui.tab.setTabEnabled(index, True)
-            else:
-                self.ui.tab.setTabEnabled(index, False)
+            isVisible = self.ui.tab.widget(index).objectName() in self.data['frameworks']
+            self.ui.tab.setTabVisible(index, isVisible)
         return True
 
     def populateTabs(self):
@@ -206,8 +202,10 @@ class DevicePopup(toolsQtWidget.MWidget):
         :return: True for test purpose
         """
         self.setWindowTitle(f'Setup driver for {self.deviceType}')
-        self.selectTabs()
         self.populateTabs()
+        self.selectTabs()
+        if self.data.get('framework') in ['astrometry', 'watney', 'astap']:
+            self.updatePlateSolverStatus()
         return True
 
     def readTabs(self):
@@ -253,10 +251,9 @@ class DevicePopup(toolsQtWidget.MWidget):
 
         :return: True for test purpose
         """
-        reversedDict = dict([(value, key) for key, value in self.framework2tabs.items()])
         index = self.ui.tab.currentIndex()
-        currentSelectionText = self.ui.tab.tabText(index)
-        self.data['framework'] = reversedDict[currentSelectionText]
+        framework = self.ui.tab.widget(index).objectName()
+        self.data['framework'] = framework
         return True
 
     def storeConfig(self):
@@ -272,7 +269,7 @@ class DevicePopup(toolsQtWidget.MWidget):
         self.close()
         return True
 
-    def updateIndiDeviceNameList(self, deviceNames=[]):
+    def updateIndiDeviceNameList(self, deviceNames):
         """
         updateIndiDeviceNameList updates the indi device name selectors combobox
         with the discovered entries. therefore it deletes the old list and
@@ -295,7 +292,7 @@ class DevicePopup(toolsQtWidget.MWidget):
 
         :return: success
         """
-        indi = IndiClass()
+        indi = IndiClass(app=self.app)
         indi.hostaddress = self.ui.indiHostAddress.text()
         indi.port = self.ui.indiPort.text()
 
@@ -304,16 +301,16 @@ class DevicePopup(toolsQtWidget.MWidget):
         self.changeStyleDynamic(self.ui.indiDiscover, 'running', False)
 
         if not deviceNames:
-            self.message.emit('Indi no devices found', 2)
+            self.msg.emit(2, 'INDI', 'Device', 'No devices found')
             return False
 
         for deviceName in deviceNames:
-            self.message.emit(f'Indi discovered:     [{deviceName}]', 0)
+            self.msg.emit(0, 'INDI', 'Device discovered', f'{deviceName}')
 
         self.updateIndiDeviceNameList(deviceNames=deviceNames)
         return True
 
-    def updateAlpacaDeviceNameList(self, deviceNames=[]):
+    def updateAlpacaDeviceNameList(self, deviceNames):
         """
         updateAlpacaDeviceNameList updates the indi device name selectors
         combobox with the discovered entries. therefore it deletes the old list
@@ -334,7 +331,7 @@ class DevicePopup(toolsQtWidget.MWidget):
 
         :return: success
         """
-        alpaca = AlpacaClass()
+        alpaca = AlpacaClass(app=self.app)
         alpaca.hostaddress = self.ui.alpacaHostAddress.text()
         alpaca.port = self.ui.alpacaPort.text()
         alpaca.apiVersion = 1
@@ -344,16 +341,16 @@ class DevicePopup(toolsQtWidget.MWidget):
         self.changeStyleDynamic(self.ui.alpacaDiscover, 'running', False)
 
         if not deviceNames:
-            self.message.emit('Alpaca no devices found', 2)
+            self.msg.emit(2, 'ALPACA', 'Device', 'No devices found')
             return False
 
         for deviceName in deviceNames:
-            self.message.emit(f'Alpaca discovered:   [{deviceName}]', 0)
+            self.msg.emit(0, 'ALPACA', 'Device discovered', f'{deviceName}')
 
         self.updateAlpacaDeviceNameList(deviceNames=deviceNames)
         return True
 
-    def updateSGProDeviceNameList(self, deviceNames=[]):
+    def updateSGProDeviceNameList(self, deviceNames):
         """
         updateSGProDeviceNameList updates the indi device name selectors
         combobox with the discovered entries. therefore it deletes the old list
@@ -374,24 +371,24 @@ class DevicePopup(toolsQtWidget.MWidget):
 
         :return: success
         """
-        sgpro = SGProClass()
+        sgpro = SGProClass(app=self.app)
         sgpro.DEVICE_TYPE = 'Camera'
 
         self.changeStyleDynamic(self.ui.sgproDiscover, 'running', True)
         deviceNames = sgpro.discoverDevices()
         if not deviceNames:
-            self.message.emit('SGPro no devices found', 2)
+            self.msg.emit(2, 'SGPRO', 'Device', 'No devices found')
 
         deviceNames.insert(0, 'SGPro controlled')
         self.changeStyleDynamic(self.ui.sgproDiscover, 'running', False)
 
         for deviceName in deviceNames:
-            self.message.emit(f'SGPro discovered:    [{deviceName}]', 0)
+            self.msg.emit(0, 'SGPRO', 'Device discovered', f'{deviceName}')
 
         self.updateSGProDeviceNameList(deviceNames=deviceNames)
         return True
 
-    def updateNINADeviceNameList(self, deviceNames=[]):
+    def updateNINADeviceNameList(self, deviceNames):
         """
         updateSGProDeviceNameList updates the indi device name selectors
         combobox with the discovered entries. therefore it deletes the old list
@@ -412,53 +409,76 @@ class DevicePopup(toolsQtWidget.MWidget):
 
         :return: success
         """
-        nina = NINAClass()
+        nina = NINAClass(app=self.app)
         nina.DEVICE_TYPE = 'Camera'
 
         self.changeStyleDynamic(self.ui.ninaDiscover, 'running', True)
         deviceNames = nina.discoverDevices()
         if not deviceNames:
-            self.message.emit('N.I.N.A. no devices found', 2)
+            self.msg.emit(2, 'N.I.N.A.', 'Device', 'No devices found')
 
         deviceNames.insert(0, 'N.I.N.A. controlled')
         self.changeStyleDynamic(self.ui.ninaDiscover, 'running', False)
 
         for deviceName in deviceNames:
-            self.message.emit(f'N.I.N.A. discovered:[{deviceName}]', 0)
+            self.msg.emit(0, 'N.I.N.A.', 'Device discovered', f'{deviceName}')
 
         self.updateNINADeviceNameList(deviceNames=deviceNames)
         return True
 
-    def checkAstrometryAvailability(self, framework):
+    def checkPlateSolveAvailability(self, framework, appPath, indexPath):
         """
         checkAvailability looks the presence of the binaries and indexes up and
         reports the result back to the gui.
 
         :return: success
         """
-        sucApp, sucIndex = self.app.astrometry.run[framework].checkAvailability()
+        sucApp, sucIndex = self.app.plateSolve.run[framework].checkAvailability(
+            appPath=appPath, indexPath=indexPath)
+
         if framework == 'astap':
             color = 'green' if sucApp else 'red'
             self.changeStyleDynamic(self.ui.astapAppPath, 'color', color)
             color = 'green' if sucIndex else 'red'
             self.changeStyleDynamic(self.ui.astapIndexPath, 'color', color)
 
-        else:
+        elif framework == 'watney':
+            color = 'green' if sucApp else 'red'
+            self.changeStyleDynamic(self.ui.watneyAppPath, 'color', color)
+            color = 'green' if sucIndex else 'red'
+            self.changeStyleDynamic(self.ui.watneyIndexPath, 'color', color)
+
+        elif framework == 'astrometry':
             color = 'green' if sucApp else 'red'
             self.changeStyleDynamic(self.ui.astrometryAppPath, 'color', color)
             color = 'green' if sucIndex else 'red'
             self.changeStyleDynamic(self.ui.astrometryIndexPath, 'color', color)
         return True
 
+    def updatePlateSolverStatus(self):
+        """
+        :return:
+        """
+        self.checkPlateSolveAvailability('astrometry',
+                                         self.ui.astrometryAppPath.text(),
+                                         self.ui.astrometryIndexPath.text())
+        self.checkPlateSolveAvailability('watney',
+                                         self.ui.watneyAppPath.text(),
+                                         self.ui.watneyIndexPath.text())
+        self.checkPlateSolveAvailability('astap',
+                                         self.ui.astapAppPath.text(),
+                                         self.ui.astapIndexPath.text())
+        return True
+
     def selectAstrometryAppPath(self):
         """
         :return:
         """
         folder = self.ui.astrometryAppPath.text()
+        folder = folder if folder else '/'
         saveFilePath, name, ext = self.openDir(self,
                                                'Select Astrometry App Path',
-                                               folder,
-                                               )
+                                               folder)
         if not name:
             return False
 
@@ -469,8 +489,10 @@ class DevicePopup(toolsQtWidget.MWidget):
             else:
                 saveFilePath += '/Contents/MacOS/astrometry/bin'
 
-        if self.checkAstrometryAvailability('astrometry'):
-            self.ui.astrometryAppPath.setText(saveFilePath)
+        self.checkPlateSolveAvailability('astrometry',
+                                         saveFilePath,
+                                         self.ui.astrometryIndexPath.text())
+        self.ui.astrometryAppPath.setText(saveFilePath)
         return True
 
     def selectAstrometryIndexPath(self):
@@ -478,15 +500,17 @@ class DevicePopup(toolsQtWidget.MWidget):
         :return:
         """
         folder = self.ui.astrometryIndexPath.text()
+        folder = folder if folder else '/'
         saveFilePath, name, ext = self.openDir(self,
                                                'Select Astrometry Index Path',
-                                               folder,
-                                               )
+                                               folder)
         if not name:
             return False
 
-        if self.checkAstrometryAvailability('astrometry'):
-            self.ui.astrometryIndexPath.setText(saveFilePath)
+        self.checkPlateSolveAvailability('astrometry',
+                                         self.ui.astrometryAppPath.text(),
+                                         saveFilePath)
+        self.ui.astrometryIndexPath.setText(saveFilePath)
         return True
 
     def selectAstapAppPath(self):
@@ -494,18 +518,20 @@ class DevicePopup(toolsQtWidget.MWidget):
         :return:
         """
         folder = self.ui.astapAppPath.text()
+        folder = folder if folder else '/'
         saveFilePath, name, ext = self.openDir(self,
                                                'Select ASTAP App Path',
-                                               folder,
-                                               )
+                                               folder)
         if not name:
             return False
 
         if platform.system() == 'Darwin' and ext == '.app':
             saveFilePath += '/Contents/MacOS'
 
-        if self.checkAstrometryAvailability('astap'):
-            self.ui.astapAppPath.setText(saveFilePath)
+        self.checkPlateSolveAvailability('astap',
+                                         saveFilePath,
+                                         self.ui.astapIndexPath.text())
+        self.ui.astapAppPath.setText(saveFilePath)
         return True
 
     def selectAstapIndexPath(self):
@@ -513,15 +539,53 @@ class DevicePopup(toolsQtWidget.MWidget):
         :return:
         """
         folder = self.ui.astapIndexPath.text()
+        folder = folder if folder else '/'
         saveFilePath, name, ext = self.openDir(self,
                                                'Select ASTAP Index Path',
-                                               folder,
-                                               )
+                                               folder)
         if not name:
             return False
 
-        if self.checkAstrometryAvailability('astap'):
-            self.ui.astapIndexPath.setText(saveFilePath)
+        self.checkPlateSolveAvailability('astap',
+                                         self.ui.astapAppPath.text(),
+                                         saveFilePath)
+        self.ui.astapIndexPath.setText(saveFilePath)
+        return True
+
+    def selectWatneyAppPath(self):
+        """
+        :return:
+        """
+        folder = self.ui.watneyAppPath.text()
+        folder = folder if folder else '/'
+        saveFilePath, name, ext = self.openDir(self,
+                                               'Select Watney App Path',
+                                               folder)
+        if not name:
+            return False
+
+        self.checkPlateSolveAvailability('watney',
+                                         saveFilePath,
+                                         self.ui.watneyIndexPath.text())
+        self.ui.watneyAppPath.setText(saveFilePath)
+        return True
+
+    def selectWatneyIndexPath(self):
+        """
+        :return:
+        """
+        folder = self.ui.watneyIndexPath.text()
+        folder = folder if folder else '/'
+        saveFilePath, name, ext = self.openDir(self,
+                                               'Select Watney Index Path',
+                                               folder)
+        if not name:
+            return False
+
+        self.checkPlateSolveAvailability('watney',
+                                         self.ui.watneyAppPath.text(),
+                                         saveFilePath)
+        self.ui.watneyIndexPath.setText(saveFilePath)
         return True
 
     def selectAscomDriver(self):
