@@ -25,8 +25,8 @@ from skyfield.api import wgs84
 import pyqtgraph as pg
 
 # local import
-from gui.utilities import toolsQtWidget
-from gui.widgets import satellite_ui
+from mw4.gui.utilities import toolsQtWidget
+from mw4.gui.widgets import satellite_ui
 
 
 class SatelliteWindowSignals(QObject):
@@ -190,6 +190,8 @@ class SatelliteWindow(toolsQtWidget.MWidget):
         :param thresh:
         :return:
         """
+        if np.ndim(dat) == 0:
+            return []
         jump = np.nonzero(np.abs(np.diff(dat)) > ((limits[1] - limits[0]) * thresh))[0]
         lastIndex = 0
         for ind in jump:
