@@ -21,8 +21,8 @@ from PyQt5.QtGui import QVector3D
 from PyQt5.Qt3DCore import QEntity
 
 # local import
-from gui.extWindows.simulator.materials import Materials
-from gui.extWindows.simulator import tools
+from mw4.gui.extWindows.simulator.materials import Materials
+from mw4.gui.extWindows.simulator import tools
 
 
 class SimulatorDome:
