@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -23,7 +23,7 @@ from PyQt5.Qt3DExtras import QCuboidMesh
 from PyQt5.Qt3DCore import QEntity, QTransform
 
 # local import
-from gui.extWindows.simulator.materials import Materials
+from mw4.gui.extWindows.simulator.materials import Materials
 
 
 class SimulatorHorizon:
