@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -24,8 +24,8 @@ from skyfield import functions
 import numpy as np
 
 # local import
-from gui.extWindows.simulator.materials import Materials
-from gui.extWindows.simulator import tools
+from mw4.gui.extWindows.simulator.materials import Materials
+from mw4.gui.extWindows.simulator import tools
 
 
 class SimulatorLaser:
