@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -27,16 +27,16 @@ from PyQt5.Qt3DRender import QPointLight
 from PyQt5.Qt3DCore import QEntity, QTransform
 
 # local import
-from gui.utilities import toolsQtWidget
-from gui.widgets import simulator_ui
-from gui.extWindows.simulator.materials import Materials
-from gui.extWindows.simulator import tools
-from gui.extWindows.simulator.dome import SimulatorDome
-from gui.extWindows.simulator.telescope import SimulatorTelescope
-from gui.extWindows.simulator.horizon import SimulatorHorizon
-from gui.extWindows.simulator.points import SimulatorBuildPoints
-from gui.extWindows.simulator.pointer import SimulatorPointer
-from gui.extWindows.simulator.laser import SimulatorLaser
+from mw4.gui.utilities import toolsQtWidget
+from mw4.gui.widgets import simulator_ui
+from mw4.gui.extWindows.simulator.materials import Materials
+from mw4.gui.extWindows.simulator import tools
+from mw4.gui.extWindows.simulator.dome import SimulatorDome
+from mw4.gui.extWindows.simulator.telescope import SimulatorTelescope
+from mw4.gui.extWindows.simulator.horizon import SimulatorHorizon
+from mw4.gui.extWindows.simulator.points import SimulatorBuildPoints
+from mw4.gui.extWindows.simulator.pointer import SimulatorPointer
+from mw4.gui.extWindows.simulator.laser import SimulatorLaser
 
 
 class SimulatorWindow(toolsQtWidget.MWidget):
@@ -50,31 +50,9 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         self.ui = simulator_ui.Ui_SimulatorDialog()
         self.ui.setupUi(self)
         self.createMutex = QMutex()
-
-        self.view = Qt3DWindow()
-        container = QWidget.createWindowContainer(self.view)
-        self.ui.simulator.addWidget(container)
-
-        self.rootEntity = QEntity()
-        self.camera = self.view.camera()
-        self.camera.lens().setPerspectiveProjection(60.0, 16.0 / 9.0, 0.1, 1000.0)
-        self.camera.setViewCenter(QVector3D(0.0, 1.5, 0.0))
-        self.camera.setPosition(QVector3D(5.0, 15.0, 3.0))
-        self.camera.setUpVector(QVector3D(0.0, 1.0, 0.0))
-        self.camController = QOrbitCameraController(self.rootEntity)
-        self.camController.setCamera(self.camera)
-        self.camController.setLinearSpeed(5.0)
-        self.camController.setLookSpeed(90)
-        self.view.setRootEntity(self.rootEntity)
-        self.view.defaultFrameGraph().setClearColor(QColor(self.M_BACK))
-
-        self.pL0E = QEntity(self.rootEntity)
-        self.pL0 = QPointLight(self.pL0E)
-        self.pL0.setIntensity(1.5)
-        self.pL0ETransform = QTransform()
-        self.pL0ETransform.setTranslation(QVector3D(5, 20, 5))
-        self.pL0E.addComponent(self.pL0)
-        self.pL0E.addComponent(self.pL0ETransform)
+        self.rootEntity = None
+        self.pL0E = None
+        self.camController = None
 
         self.dome = SimulatorDome(self.app)
         self.telescope = SimulatorTelescope(self.app)
@@ -84,6 +62,21 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         self.laser = SimulatorLaser(self.app)
         self.world = None
 
+        self.view = Qt3DWindow()
+        self.view.defaultFrameGraph().setClearColor(QColor(self.M_BACK))
+        container = QWidget.createWindowContainer(self.view)
+        self.ui.simulator.addWidget(container)
+
+        self.camera = self.view.camera()
+        self.camera.lens().setPerspectiveProjection(60.0, 16.0 / 9.0, 0.1, 1000.0)
+        self.camera.setViewCenter(QVector3D(0.0, 1.5, 0.0))
+        self.camera.setPosition(QVector3D(5.0, 15.0, 3.0))
+        self.camera.setUpVector(QVector3D(0.0, 1.0, 0.0))
+
+        self.pL0 = QPointLight(self.pL0E)
+        self.pL0.setIntensity(1.5)
+        self.setRootEntity()
+
     def initConfig(self):
         """
         :return: True for test purpose
@@ -91,25 +84,8 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         if 'simulatorW' not in self.app.config:
             self.app.config['simulatorW'] = {}
         config = self.app.config['simulatorW']
-        height = config.get('height', 600)
-        width = config.get('width', 800)
-        self.resize(width, height)
-        x = config.get('winPosX', 0)
-        y = config.get('winPosY', 0)
-        if x > self.screenSizeX - width:
-            x = 0
-        if y > self.screenSizeY - height:
-            y = 0
-        if x != 0 and y != 0:
-            self.move(x, y)
-
-        if 'cameraPositionX' in config:
-            x = config['cameraPositionX']
-            y = config['cameraPositionY']
-            z = config['cameraPositionZ']
-            self.camera.setPosition(QVector3D(x, y, z))
-            self.camera.setUpVector(QVector3D(0.0, 1.0, 0.0))
 
+        self.positionWindow(config)
         self.ui.checkDomeTransparent.setChecked(config.get('checkDomeTransparent', False))
         self.ui.checkShowPointer.setChecked(config.get('checkShowPointer', False))
         self.ui.checkShowLaser.setChecked(config.get('checkShowLaser', False))
@@ -124,10 +100,13 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         """
         :return: True for test purpose
         """
-        if 'simulatorW' not in self.app.config:
-            self.app.config['simulatorW'] = {}
+        config = self.app.config
+        if 'simulatorW' not in config:
+            config['simulatorW'] = {}
+        else:
+            config['simulatorW'].clear()
+        config = config['simulatorW']
 
-        config = self.app.config['simulatorW']
         config['winPosX'] = max(self.pos().x(), 0)
         config['winPosY'] = max(self.pos().y(), 0)
         config['height'] = self.height()
@@ -151,40 +130,12 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         :return:
         """
         self.storeConfig()
-
-        self.app.update1s.disconnect(self.dome.updatePositions)
-        self.ui.checkDomeTransparent.clicked.disconnect(self.createScene)
-        self.ui.checkShowBuildPoints.clicked.disconnect(self.buildPointsCreate)
-        self.ui.checkShowNumbers.clicked.disconnect(self.buildPointsCreate)
-        self.ui.checkShowSlewPath.clicked.disconnect(self.buildPointsCreate)
-        self.app.updatePointMarker.disconnect(self.buildPointsCreate)
-        self.ui.checkShowHorizon.clicked.disconnect(self.createScene)
-        self.ui.checkShowPointer.clicked.disconnect(self.pointerCreate)
-        self.ui.checkShowLaser.clicked.disconnect(self.laserCreate)
-        self.ui.topView.clicked.disconnect(self.topView)
-        self.ui.topEastView.clicked.disconnect(self.topEastView)
-        self.ui.topWestView.clicked.disconnect(self.topWestView)
-        self.ui.eastView.clicked.disconnect(self.eastView)
-        self.ui.westView.clicked.disconnect(self.westView)
-        self.app.updateDomeSettings.disconnect(self.updateSettings)
-        self.app.updateDomeSettings.disconnect(self.telescope.updateSettings)
-        self.app.updateDomeSettings.disconnect(self.dome.updateSettings)
-        self.app.mount.signals.pointDone.disconnect(self.telescope.updatePositions)
-        self.app.mount.signals.pointDone.disconnect(self.pointer.updatePositions)
-        self.app.mount.signals.pointDone.disconnect(self.laser.updatePositions)
-        self.app.mount.signals.pointDone.disconnect(self.buildPoints.updatePositions)
-        self.app.drawBuildPoints.disconnect(self.buildPointsCreate)
-        self.app.drawHorizonPoints.disconnect(self.horizonCreate)
-        self.app.switchHemisphere.disconnect(self.createScene)
-        self.camera.positionChanged.disconnect(self.limitPositionZ)
-        self.app.colorChange.disconnect(self.colorChange)
         super().closeEvent(closeEvent)
 
     def showWindow(self):
         """
         :return: True for test purpose
         """
-        self.createScene()
         self.ui.checkDomeTransparent.clicked.connect(self.createScene)
         self.ui.checkShowBuildPoints.clicked.connect(self.buildPointsCreate)
         self.ui.checkShowNumbers.clicked.connect(self.buildPointsCreate)
@@ -199,6 +150,8 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         self.ui.eastView.clicked.connect(self.eastView)
         self.ui.westView.clicked.connect(self.westView)
         self.app.update1s.connect(self.dome.updatePositions)
+        self.app.dome.signals.deviceConnected.connect(self.createScene)
+        self.app.dome.signals.deviceDisconnected.connect(self.createScene)
         self.app.updateDomeSettings.connect(self.updateSettings)
         self.app.updateDomeSettings.connect(self.telescope.updateSettings)
         self.app.updateDomeSettings.connect(self.dome.updateSettings)
@@ -208,9 +161,9 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         self.app.mount.signals.pointDone.connect(self.buildPoints.updatePositions)
         self.app.drawBuildPoints.connect(self.buildPointsCreate)
         self.app.drawHorizonPoints.connect(self.horizonCreate)
-        self.app.switchHemisphere.connect(self.createScene)
         self.camera.positionChanged.connect(self.limitPositionZ)
         self.app.colorChange.connect(self.colorChange)
+        self.createScene()
         self.show()
         return True
 
@@ -223,6 +176,24 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         self.createScene()
         return True
 
+    def setRootEntity(self):
+        """
+        :return:
+        """
+        self.rootEntity = None
+        self.rootEntity = QEntity()
+        self.view.setRootEntity(self.rootEntity)
+        self.pL0E = QEntity(self.rootEntity)
+        self.camController = QOrbitCameraController(self.rootEntity)
+        self.camController.setCamera(self.camera)
+        self.camController.setLinearSpeed(5.0)
+        self.camController.setLookSpeed(90)
+        pL0ETransform = QTransform()
+        pL0ETransform.setTranslation(QVector3D(5, 20, 5))
+        self.pL0E.addComponent(self.pL0)
+        self.pL0E.addComponent(pL0ETransform)
+        return True
+
     def limitPositionZ(self):
         """
         :return:
@@ -339,7 +310,7 @@ class SimulatorWindow(toolsQtWidget.MWidget):
 
         'ref' is the fusion360 coordinate system, please be aware that rotations
         around the z axis for azimuth is clockwise and not counterclockwise as a
-        right handed coordinate system would propose.
+        right-handed coordinate system would propose.
 
         for the sake of simplifying there is another reference, which only has
         the corrections in coordinates and not for scaling, this is called 'ref1000'
@@ -388,7 +359,7 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         for name in self.world:
             tools.linkModel(self.world, name, rEntity)
 
-    def createScene(self, lat=0):
+    def createScene(self):
         """
         createScene initially builds all 3d models and collects them to a scene.
         please look closely which references are used-
@@ -402,20 +373,15 @@ class SimulatorWindow(toolsQtWidget.MWidget):
         path = self.ui.checkShowSlewPath.isChecked()
         pointer = self.ui.checkShowPointer.isChecked()
         laser = self.ui.checkShowLaser.isChecked()
-        dome = self.app.deviceStat.get('dome', False)
+        dome = bool(self.app.deviceStat.get('dome'))
         horizon = self.ui.checkShowHorizon.isChecked()
         points = self.ui.checkShowBuildPoints.isChecked()
         isDomeTransparent = self.ui.checkDomeTransparent.isChecked()
 
-        if dome:
-            self.ui.checkDomeTransparent.setEnabled(True)
-            self.ui.checkShowPointer.setEnabled(True)
-        else:
-            self.ui.checkDomeTransparent.setEnabled(False)
-            self.ui.checkDomeTransparent.setChecked(False)
-            self.ui.checkShowPointer.setEnabled(False)
-            self.ui.checkShowPointer.setChecked(False)
+        self.ui.checkDomeTransparent.setEnabled(dome)
+        self.ui.checkShowPointer.setEnabled(dome)
 
+        lat = self.app.mount.obsSite.location.latitude.degrees
         self.createWorld(self.rootEntity)
         self.telescope.create(self.world['ref']['e'], True, lat)
         self.dome.create(self.world['ref']['e'], dome, isDomeTransparent)
