@@ -19,12 +19,13 @@ import queue
 import shutil
 import os
 
+
 # external packages
-from mountcontrol.convert import convertToHMS, convertToDMS
+from mw4.mountcontrol.convert import convertToHMS, convertToDMS
 
 # local import
-from base.transform import JNowToJ2000, J2000ToJNow
-from gui.utilities.toolsQtWidget import QMultiWait, sleepAndEvents
+from mw4.base.transform import JNowToJ2000, J2000ToJNow
+from mw4.gui.utilities.toolsQtWidget import QMultiWait, sleepAndEvents
 
 
 class BasicRun:
@@ -79,10 +80,7 @@ class BasicRun:
             self.cancelRun()
             return False
 
-        self.log.debug('Processing plate solving result')
         mPoint = self.resultQueue.get()
-        self.log.debug(f'Result from queue [{mPoint["countSequence"]:03d}]: [{mPoint}]')
-
         lenSequence = mPoint["lenSequence"]
         count = mPoint["countSequence"]
         pointNumber = mPoint["pointNumber"]
@@ -100,10 +98,11 @@ class BasicRun:
                                             mPoint['julianDate'])
             mPoint['raJNowS'] = raJNowS
             mPoint['decJNowS'] = decJNowS
+            self.app.data.setStatusBuildP(pointNumber - 1, 0)
+            self.app.showImage.emit(mPoint["imagePath"])
+            self.modelQueue.put(mPoint)
             t = f'Queued to model [{mPoint["countSequence"]:03d}]: [{mPoint}]'
             self.log.debug(t)
-            self.modelQueue.put(mPoint)
-            self.app.data.setStatusBuildP(pointNumber - 1, 0)
 
             text = f'RA: {convertToHMS(mPoint["raJ2000S"])} '
             text += f'({result["raJ2000S"].hours:4.3f}), '
@@ -119,10 +118,10 @@ class BasicRun:
             self.msg.emit(0, '', '', text)
 
         else:
+            self.app.data.setStatusBuildP(pointNumber - 1, 2)
+            self.retryQueue.put(mPoint)
             text = f'Solving failed for image-{count:03d}'
             self.msg.emit(2, self.runType, 'Solving error', text)
-            self.retryQueue.put(mPoint)
-            self.app.data.setStatusBuildP(pointNumber - 1, 2)
 
         self.app.updatePointMarker.emit()
         self.runProgressCB(mPoint)
@@ -153,19 +152,26 @@ class BasicRun:
 
         if noSolvesLeft and stillToWork:
             t = f'Slews left: [{self.slewQueue.qsize()}] '
-            t += f'Images left: [{self.imageQueue.qsize()}] '
+            t += f' Images left: [{self.imageQueue.qsize()}] '
+            t += f' Solves left: [{self.solveQueue.qsize()}] '
             self.log.error(f'Empty solve queue: {t}')
             self.msg.emit(2, self.runType, 'Build error', 'Out of sync exception')
             self.cancelRun()
             return False
 
-        self.log.info('Solving started')
         mPoint = self.solveQueue.get()
-        self.app.showImage.emit(mPoint["imagePath"])
+        text = f'Solving image-{mPoint["countSequence"]:03d}:'
+        self.log.info(text)
+
         self.resultQueue.put(mPoint)
+        suc = self.app.plateSolve.solveThreading(fitsPath=mPoint['imagePath'])
+        if not suc:
+            self.log.error('Cannot start solving')
+            text = f'image-{mPoint["countSequence"]:03d} not solved'
+            self.msg.emit(2, self.runType, 'Solving error', text)
+            return False
+
         self.log.debug(f'Queued to result [{mPoint["countSequence"]:03d}]: [{mPoint}]')
-        self.app.plateSolve.solveThreading(fitsPath=mPoint['imagePath'],
-                                           updateFits=False)
         text = f'Solving  image-{mPoint["countSequence"]:03d}:'
         self.msg.emit(0, self.runType, 'Solving', text)
         return True
@@ -192,14 +198,17 @@ class BasicRun:
         slewsLeft = not self.slewQueue.empty()
 
         if noImagesLeft and slewsLeft:
-            t = f'Slews left: [{self.slewQueue.qsize()}] '
+            t = f'Slews left: [{self.slewQueue.qsize()}]'
+            t += f' Images left:[{self.imageQueue.qsize()}]'
             self.log.error(f'Empty image queue: {t}')
             self.msg.emit(2, self.runType, 'Build error', 'Out of sync exception')
             self.cancelRun()
             return False
 
-        self.log.info('Imaging started')
         mPoint = self.imageQueue.get()
+        text = f'Exposing image-{mPoint["countSequence"]:03d}'
+        self.log.info(text)
+
         self.collector.resetSignals()
         waitTime = 2 * mPoint.get('waitTime', 0)
         self.log.info(f'Waiting time is {mPoint.get("waitTime", 0)}')
@@ -208,6 +217,7 @@ class BasicRun:
             color = '' if waitTime % 2 else 'yellow'
             self.changeStyleDynamic(self.ui.pauseModel, 'color', color)
             sleepAndEvents(500)
+            self.app.camera.signals.message.emit(f'wait {waitTime / 2:1.1f} s')
             waitTime -= 1
 
         mPoint['raJNowM'] = self.app.mount.obsSite.raJNow
@@ -221,16 +231,22 @@ class BasicRun:
                                                               mPoint['decJNowM'],
                                                               mPoint['julianDate'])
 
-        self.app.camera.expose(imagePath=mPoint['imagePath'],
-                               expTime=mPoint['exposureTime'],
-                               binning=mPoint['binning'],
-                               subFrame=mPoint['subFrame'],
-                               fastReadout=mPoint['fastReadout'],
-                               focalLength=mPoint['focalLength'])
-
         self.solveQueue.put(mPoint)
-        self.log.debug(f'Queued to solve [{mPoint["countSequence"]:03d}]: [{mPoint}]')
+        suc = self.app.camera.expose(imagePath=mPoint['imagePath'],
+                                     expTime=mPoint['exposureTime'],
+                                     binning=mPoint['binning'],
+                                     subFrame=mPoint['subFrame'],
+                                     fastReadout=mPoint['fastReadout'],
+                                     focalLength=mPoint['focalLength'],
+                                     ra=mPoint['raJ2000M'],
+                                     dec=mPoint['decJ2000M'])
+        if not suc:
+            self.log.error('Cannot start imaging')
+            text = f'image-{mPoint["countSequence"]:03d} not taken'
+            self.msg.emit(2, self.runType, 'Imaging error', text)
+            return False
 
+        self.log.debug(f'Queued to solve [{mPoint["countSequence"]:03d}]: [{mPoint}]')
         text = f'Exposing image-{mPoint["countSequence"]:03d}'
         self.msg.emit(0, self.runType, 'Imaging', text)
         return True
@@ -249,7 +265,7 @@ class BasicRun:
 
         """
         if self.slewQueue.empty():
-            self.log.info('Empty slew queue- model sequence finished')
+            self.log.info('Empty slew queue - model sequence finished')
             return False
 
         self.log.info('Slew started')
@@ -269,10 +285,9 @@ class BasicRun:
             text += ', az: {azimuthT:3.1f} delta: {delta:3.1f}'
             self.msg.emit(0, self.runType, 'Slewing dome', text)
 
-        self.app.mount.obsSite.startSlewing()
         self.imageQueue.put(mPoint)
+        self.app.mount.obsSite.startSlewing()
         self.log.debug(f'Queued to image [{mPoint["countSequence"]:03d}]: [{mPoint}]')
-
         text = f'Point: {mPoint["countSequence"]:03d}, '
         text += f'altitude: {mPoint["altitude"]:3.0f}, '
         text += f'azimuth: {mPoint["azimuth"]:3.0f}'
