@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -21,47 +20,30 @@ from dateutil.tz import tzlocal
 # external packages
 from PyQt5.QtGui import QPixmap, QPainter, QPen, QColor
 from PyQt5.QtCore import Qt, QPointF
-from PyQt5.QtWidgets import QApplication
+import pyqtgraph as pg
 from skyfield import almanac
 from skyfield.trigonometry import position_angle_of
 import numpy as np
+from range_key_dict import RangeKeyDict
 
 # local import
-from base.tpool import Worker
+from mw4.base.tpool import Worker
 
 
 class Almanac:
     """
     """
-    phasesText = {
-        'New moon': {
-            'range': (0, 1),
-        },
-        'Waxing crescent': {
-            'range': (1, 23),
-        },
-        'First Quarter': {
-            'range': (23, 27),
-        },
-        'Waxing Gibbous': {
-            'range': (27, 48),
-        },
-        'Full moon': {
-            'range': (48, 52),
-        },
-        'Waning Gibbous': {
-            'range': (52, 73),
-        },
-        'Third quarter': {
-            'range': (73, 77),
-        },
-        'Waning crescent': {
-            'range': (77, 99),
-        },
-        'New moon ': {
-            'range': (99, 100),
-        },
-    }
+    phasesText = RangeKeyDict({
+        (0, 1): 'New moon',
+        (1, 23): 'Waxing crescent',
+        (23, 27): 'First quarter',
+        (27, 48): 'Waxing gibbous',
+        (48, 52): 'Full moon',
+        (52, 73): 'Waning gibbous',
+        (73, 77): 'Third quarter',
+        (77, 99): 'Waning crescent',
+        (99, 100): 'New moon '
+    })
 
     def __init__(self):
         self.civil = None
@@ -71,11 +53,11 @@ class Almanac:
         self.twilightEvents = None
         self.colors = None
         self.setColors()
-        self.app.start1s.connect(self.searchTwilightList)
-        self.app.start5s.connect(self.searchTwilightPlot)
-        self.app.update1s.connect(self.updateMoonPhase)
+        self.app.update1h.connect(self.showMoonPhase)
         self.app.colorChange.connect(self.colorChangeAlmanac)
-        self.ui.almanacDark.clicked.connect(self.updateMoonPhase)
+        self.ui.unitTimeUTC.toggled.connect(self.showTwilightDataList)
+        self.ui.unitTimeUTC.toggled.connect(self.showTwilightDataPlot)
+        self.ui.unitTimeUTC.toggled.connect(self.showMoonPhase)
 
     def initConfig(self):
         """
@@ -83,9 +65,7 @@ class Almanac:
         """
         config = self.app.config['mainW']
         self.ui.almanacPrediction.setCurrentIndex(config.get('almanacPrediction', 0))
-        self.ui.almanacPrediction.currentIndexChanged.connect(self.searchTwilightPlot)
-        self.updateMoonPhase()
-        self.lunarNodes()
+        self.ui.almanacPrediction.currentIndexChanged.connect(self.showTwilightDataPlot)
         return True
 
     def storeConfig(self):
@@ -113,8 +93,10 @@ class Almanac:
         :return:
         """
         self.setColors()
-        self.searchTwilightPlot()
-        self.updateMoonPhase()
+        self.ui.twilight.colorChange()
+        self.showTwilightDataList()
+        self.showTwilightDataPlot()
+        self.showMoonPhase()
         return True
 
     def plotTwilightData(self, result):
@@ -123,44 +105,63 @@ class Almanac:
         :return: true for test purpose
         """
         ts, t, e = result
-        minLim = int(t[0].tt) + 1
-        maxLim = int(t[-1].tt) - 1
-        midLim = minLim + (maxLim - minLim) / 2
+        xMin = int(t[0].tt) + 1
+        xMax = int(t[-1].tt) - 1
+        xNow = (xMax - xMin) / 2 + xMin
 
-        axe, fig = self.generateFlat(widget=self.twilight)
         yTicks = [0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24]
-        yLabels = ['12', '14', '16', '18', '20', '22', '24',
-                   '02', '04', '06', '08', '10', '12']
-        axe.set_yticks(yTicks)
-        axe.set_yticklabels(yLabels, fontsize=10)
-        xTicks = np.arange(minLim, maxLim, (maxLim - minLim) / 11)
+        yLabels = ['', '14', '16', '18', '20', '22', '24',
+                   '02', '04', '06', '08', '10', '']
+        xTicks = np.arange(xMin, xMax, (xMax - xMin) / 9)
         xLabels = ts.tt_jd(xTicks).utc_strftime('%d%b')
         xLabels[0] = ''
-        axe.set_xlim(minLim, maxLim)
-        axe.set_xticks(xTicks)
-        axe.set_xticklabels(xLabels, fontsize=10)
-        axe.grid(color=self.M_GREY, alpha=0.5)
-        axe.set_ylim(0, 24)
+        xTicks = [(x, y) for x, y in zip(xTicks, xLabels)]
+        yTicks = [(x, y) for x, y in zip(yTicks, yLabels)]
+        penLine = pg.mkPen(color=self.M_PINK + '80', width=2)
+        plotItem = self.ui.twilight.p[0]
+        plotItem.getViewBox().setMouseMode(pg.ViewBox().RectMode)
+        plotItem.getViewBox().xRange = (0, 360)
+        plotItem.getViewBox().yRange = (0, 90)
+        plotItem.showAxes(True, showValues=True)
+        plotItem.getAxis('bottom').setTicks([xTicks])
+        plotItem.getAxis('left').setTicks([yTicks])
+        plotItem.getAxis('top').setTicks([xTicks])
+        plotItem.getAxis('right').setTicks([yTicks])
+        plotItem.setLimits(xMin=xMin, xMax=xMax, yMin=0, yMax=24)
+        plotItem.setYRange(0, 24)
+        plotItem.setXRange(xMin, xMax)
 
-        for ti, event in zip(t, e):
-            QApplication.processEvents()
-            if self.closing:
-                break
-            hour = int(ti.astimezone(tzlocal()).strftime('%H'))
-            minute = int(ti.astimezone(tzlocal()).strftime('%M'))
-            y = (hour + 12 + minute / 60) % 24
-            day = round(ti.tt + 0.5, 0)
-            axe.bar(day, height=24 - y, bottom=y, width=1,
-                    color=self.colors[event])
-        else:
-            x = [midLim - 1, midLim - 1, midLim + 1, midLim + 1]
-            y = [0, 24, 24, 0]
-            axe.fill(x, y, self.M_GREY, alpha=0.5)
-            axe.figure.canvas.draw()
-            return True
-        return False
+        pens = []
+        brushes = []
+        for i in range(5):
+            pens.append(pg.mkPen(color=self.colors[i]))
+            brushes.append(pg.mkBrush(color=self.colors[i]))
+        penBar = [pens[x] for x in e]
+        brushBar = [brushes[x] for x in e]
 
-    def displayTwilightData(self, timeEvents, events):
+        tLoc = t.astimezone(tzlocal())
+        refDay = [x.replace(hour=0, minute=0, second=0, microsecond=0) for x in tLoc]
+        dayLoc = tLoc - refDay
+        yH = [x.total_seconds() / 3600 for x in dayLoc]
+        xD = np.array([int(x) for x in t.tt])
+
+        plotItem.clear()
+        for i in range(len(t)):
+            if yH[i] > 12:
+                rect = pg.QtWidgets.QGraphicsRectItem(
+                    xD[i], yH[i] - 12, 1, 24 - (yH[i] - 12))
+            else:
+                rect = pg.QtWidgets.QGraphicsRectItem(
+                    xD[i], 12 + yH[i], 1, 24 - (12 + yH[i]))
+            rect.setPen(penBar[i])
+            rect.setBrush(brushBar[i])
+            plotItem.addItem(rect)
+        plotItem.addLine(x=xNow, pen=penLine)
+
+        self.changeStyleDynamic(self.ui.almanacGroup, 'running', False)
+        return True
+
+    def listTwilightData(self, timeEvents, events):
         """
         :param timeEvents:
         :param events:
@@ -168,12 +169,15 @@ class Almanac:
         """
         text = ''
         self.ui.twilightEvents.clear()
+        self.ui.twilightEvents.setTextColor(QColor(self.M_BLUE))
 
         for timeEvent, event in zip(timeEvents, events):
-            text += f'{timeEvent.astimezone(tzlocal()).strftime("%H:%M:%S")} '
+            text += f'{self.convertTime(timeEvent,"%H:%M:%S")} '
             text += f'{almanac.TWILIGHTS[event]}'
             self.ui.twilightEvents.insertPlainText(text)
             text = '\n'
+        title = 'Sun ' + self.timeZoneString()
+        self.ui.sunAlmanacGroup.setTitle(title)
         return True
 
     def calcTwilightData(self, ts, location, tWinL=0, tWinH=0):
@@ -192,7 +196,7 @@ class Almanac:
         twilightTime, twilightEvents = almanac.find_discrete(t0, t1, f)
         return twilightTime, twilightEvents
 
-    def searchTwilightWorker(self, ts, location, timeWindow):
+    def workerCalcTwilightDataPlot(self, ts, location, timeWindow):
         """
         :param ts:
         :param location:
@@ -204,7 +208,7 @@ class Almanac:
                                      tWinH=timeWindow)
         return ts, t, e
 
-    def searchTwilightPlot(self):
+    def showTwilightDataPlot(self):
         """
         :return: true for test purpose
         """
@@ -216,15 +220,18 @@ class Almanac:
         index = self.ui.almanacPrediction.currentIndex()
         text = self.ui.almanacPrediction.currentText()
         timeWindow = timeWindowParam[index]
-        self.ui.almanacGroup.setTitle(f'Twilight passes for: {text}')
+
+        t = f'Twilight passes for: {text} {self.timeZoneString()}'
+        self.ui.almanacGroup.setTitle(t)
 
         ts = self.app.mount.obsSite.ts
-        worker = Worker(self.searchTwilightWorker, ts, location, timeWindow)
+        self.changeStyleDynamic(self.ui.almanacGroup, 'running', True)
+        worker = Worker(self.workerCalcTwilightDataPlot, ts, location, timeWindow)
         worker.signals.result.connect(self.plotTwilightData)
         self.threadPool.start(worker)
         return True
 
-    def searchTwilightList(self):
+    def showTwilightDataList(self):
         """
         :return: true for test purpose
         """
@@ -235,7 +242,7 @@ class Almanac:
         ts = self.app.mount.obsSite.ts
         result = self.calcTwilightData(ts, location, tWinL=0, tWinH=1)
         self.twilightTime, self.twilightEvents = result
-        self.displayTwilightData(self.twilightTime[:8], self.twilightEvents[:8])
+        self.listTwilightData(self.twilightTime[:8], self.twilightEvents[:8])
         return True
 
     def calcMoonPhase(self):
@@ -245,27 +252,53 @@ class Almanac:
 
         :return: fraction of illumination, degree phase and percent phase
         """
-        sun = self.app.ephemeris['sun']
-        moon = self.app.ephemeris['moon']
-        earth = self.app.ephemeris['earth']
+        ephemeris = self.app.ephemeris
+        sun = ephemeris['sun']
+        moon = ephemeris['moon']
+        earth = ephemeris['earth']
         now = self.app.mount.obsSite.ts.now()
-        loc = self.app.mount.obsSite.location + earth
+        loc = self.app.mount.obsSite.location
+        ts = self.app.mount.obsSite.ts
+        timeJD = self.app.mount.obsSite.timeJD
+        e = earth.at(timeJD)
 
-        e = earth.at(self.app.mount.obsSite.timeJD)
+        # calc phases for obstruction
         _, sunLon, _ = e.observe(sun).apparent().ecliptic_latlon()
         _, moonLon, _ = e.observe(moon).apparent().ecliptic_latlon()
 
-        mpIllumination = almanac.fraction_illuminated(self.app.ephemeris,
-                                                      'moon', now)
+        mpIllumination = almanac.fraction_illuminated(ephemeris, 'moon', now)
         mpDegree = (moonLon.degrees - sunLon.degrees) % 360.0
-        mpPercent = mpDegree / 360
+        mpPercent = mpDegree / 360 * 100
+        retVal = [mpIllumination, mpDegree, mpPercent]
 
-        locObserver = loc.at(self.app.mount.obsSite.timeJD)
+        locObserver = (loc + earth).at(timeJD)
         moonApparent = locObserver.observe(moon).apparent()
         sunApparent = locObserver.observe(sun).apparent()
         moonAngle = position_angle_of(moonApparent.altaz(), sunApparent.altaz())
+        retVal.append(moonAngle)
 
-        return mpIllumination, mpDegree, mpPercent, moonAngle
+        # calc rise and set times
+        t0 = ts.tt_jd(int(timeJD.tt))
+        t1 = ts.tt_jd(int(timeJD.tt) + 2)
+
+        f = almanac.risings_and_settings(ephemeris, ephemeris['moon'], loc)
+        moonTimes, moonEvents = almanac.find_discrete(t0, t1, f)
+        moonTimes = moonTimes[0:3]
+        moonEvents = moonEvents[0:3]
+        retVal.append(moonTimes)
+        retVal.append(moonEvents)
+
+        # calc nodes
+        t0 = ts.tt_jd(int(timeJD.tt))
+        t1 = ts.tt_jd(int(timeJD.tt) + 29)
+        f = almanac.moon_nodes(ephemeris)
+        nodeTimes, nodeEvents = almanac.find_discrete(t0, t1, f)
+        nodeTimes = nodeTimes[0:2]
+        nodeEvents = nodeEvents[0:2]
+        retVal.append(nodeTimes)
+        retVal.append(nodeEvents)
+
+        return retVal
 
     def generateMoonMask(self, pixmap, mpDegree):
         """
@@ -276,12 +309,10 @@ class Almanac:
         colCover = QColor(self.M_BACK)
         colFree = QColor('transparent')
         colFrame = QColor(self.M_GREY1)
-        colRed = QColor(self.M_RED)
 
         penCov = QPen(colCover, 0)
         penFree = QPen(colFree, 0)
         penFrame = QPen(colFrame, 3)
-        penRed = QPen(colRed, 3)
 
         height = pixmap.height()
         width = pixmap.width()
@@ -297,11 +328,9 @@ class Almanac:
         maskPainter.setPen(penFrame)
 
         if 0 <= mpDegree <= 90:
-            # left half covered
             maskPainter.setBrush(colCover)
             maskPainter.drawPie(0, 0, width, height, 90 * 16, 180 * 16)
 
-            # right half opens up
             r = np.cos(np.radians(mpDegree)) * w2
             maskPainter.setBrush(colCover)
             maskPainter.setPen(penCov)
@@ -339,22 +368,45 @@ class Almanac:
         maskPainter.end()
         return moonMask
 
-    def updateMoonPhase(self):
+    def showMoonPhase(self):
         """
-        It will also write some description for the moon phase. In addition I
+        It will also write some description for the moon phase. In addition, I
         will show an image of the moon showing the moon phase as picture.
 
         :return: true for test purpose
         """
-        mpIllumination, mpDegree, mpPercent, mAngle = self.calcMoonPhase()
-        self.ui.moonPhaseIllumination.setText(f'{mpIllumination * 100:3.2f}')
-        self.ui.moonPhasePercent.setText(f'{100* mpPercent:3.0f}')
+        calcMoon = self.calcMoonPhase()
+
+        mpIllumination, mpDegree, mpPercent, moonAngle = calcMoon[0:4]
+        self.ui.moonPhaseIllumination.setText(f'{mpIllumination * 100:3.1f}')
+        self.ui.moonPhasePercent.setText(f'{mpPercent:3.0f}')
         self.ui.moonPhaseDegree.setText(f'{mpDegree:3.0f}')
 
-        for phase in self.phasesText:
-            if int(mpPercent * 100) not in range(*self.phasesText[phase]['range']):
-                continue
-            self.ui.moonPhaseText.setText(phase)
+        moonTimes, moonEvents = calcMoon[4:6]
+        text = ''
+        self.ui.riseSetEventsMoon.clear()
+        self.ui.riseSetEventsMoon.setTextColor(QColor(self.M_BLUE))
+        moon = ['set', 'rise']
+        for moonTime, moonEvent in zip(moonTimes, moonEvents):
+            textTime = self.convertTime(moonTime, '%d.%m. %H:%M')
+            text += f'{textTime} {moon[moonEvent]}'
+            self.ui.riseSetEventsMoon.insertPlainText(text)
+            text = '\n'
+        title = 'Moon ' + self.timeZoneString()
+        self.ui.moonAlmanacGroup.setTitle(title)
+
+        self.ui.moonPhaseText.setText(self.phasesText[mpPercent])
+
+        nodeTimes, nodeEvents = calcMoon[6:8]
+        text = ''
+        self.ui.nodeEvents.clear()
+        self.ui.nodeEvents.setTextColor(QColor(self.M_BLUE))
+        node = ['ascending', 'descending']
+        for nodeTime, nodeEvent in zip(nodeTimes, nodeEvents):
+            textTime = self.convertTime(nodeTime, '%d.%m. %H:%M')
+            text += f'{textTime} {node[nodeEvent]}'
+            self.ui.nodeEvents.insertPlainText(text)
+            text = '\n'
 
         moon = QPixmap(':/pics/moon.png')
         moonMask = self.generateMoonMask(moon, mpDegree)
@@ -368,17 +420,3 @@ class Almanac:
         height = self.ui.moonPic.height()
         self.ui.moonPic.setPixmap(moon.scaled(width, height))
         return True
-
-    def lunarNodes(self):
-        """
-        :return: true for test purpose
-        """
-        ts = self.app.mount.obsSite.ts
-        timeJD = self.app.mount.obsSite.timeJD
-
-        t0 = ts.tt_jd(int(timeJD.tt))
-        t1 = ts.tt_jd(int(timeJD.tt) + 29)
-        t, y = almanac.find_discrete(t0, t1, almanac.moon_nodes(self.app.ephemeris))
-        text = 'descending' if y[0] else 'ascending'
-        self.ui.lunarNodes.setText(f'{text}')
-        return True
