@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -19,12 +19,11 @@
 # external packages
 from PyQt5.QtCore import QMutex
 from astroquery.simbad import Simbad
-from skyfield.api import Angle
 
 # local import
-from base.tpool import Worker
-from mountcontrol.convert import convertRaToAngle, convertDecToAngle
-from mountcontrol.convert import formatHstrToText, formatDstrToText
+from mw4.base.tpool import Worker
+from mw4.mountcontrol.convert import convertRaToAngle, convertDecToAngle
+from mw4.mountcontrol.convert import formatHstrToText, formatDstrToText
 
 
 class BuildPoints:
@@ -46,6 +45,7 @@ class BuildPoints:
             'min': self.genBuildMin,
             'dso': self.genBuildDSO,
             'file': self.genBuildFile,
+            'model': self.genModel,
         }
         self.simbadRa = None
         self.simbadDec = None
@@ -65,23 +65,20 @@ class BuildPoints:
         self.ui.genBuildMin.clicked.connect(self.genBuildMin)
         self.ui.genBuildFile.clicked.connect(self.genBuildFile)
         self.ui.genBuildDSO.clicked.connect(self.genBuildDSO)
+        self.ui.genModel.clicked.connect(self.genModel)
         self.ui.numberDSOPoints.valueChanged.connect(self.genBuildDSO)
-        self.ui.durationDSO.valueChanged.connect(self.genBuildDSO)
-        self.ui.timeShiftDSO.valueChanged.connect(self.genBuildDSO)
         self.ui.saveBuildPoints.clicked.connect(self.saveBuildFile)
         self.ui.saveBuildPointsAs.clicked.connect(self.saveBuildFileAs)
         self.ui.loadBuildPoints.clicked.connect(self.loadBuildFile)
-        self.ui.genBuildSpiralMax.clicked.connect(self.genBuildSpiralMax)
-        self.ui.genBuildSpiralMed.clicked.connect(self.genBuildSpiralMed)
-        self.ui.genBuildSpiralNorm.clicked.connect(self.genBuildSpiralNorm)
-        self.ui.genBuildSpiralMin.clicked.connect(self.genBuildSpiralMin)
+        self.ui.genBuildSpiral.clicked.connect(self.genBuildGoldenSpiral)
         self.ui.clearBuildP.clicked.connect(self.clearBuildP)
-        self.ui.checkSortNothing.clicked.connect(self.rebuildPoints)
-        self.ui.checkSortEW.clicked.connect(self.rebuildPoints)
-        self.ui.checkSortHL.clicked.connect(self.rebuildPoints)
-        self.ui.checkAvoidFlip.clicked.connect(self.rebuildPoints)
-        self.ui.checkAutoDeleteMeridian.clicked.connect(self.rebuildPoints)
-        self.ui.checkAutoDeleteHorizon.clicked.connect(self.rebuildPoints)
+        self.ui.sortNothing.clicked.connect(self.rebuildPoints)
+        self.ui.sortEW.clicked.connect(self.rebuildPoints)
+        self.ui.sortHL.clicked.connect(self.rebuildPoints)
+        self.ui.ditherBuildPoints.clicked.connect(self.rebuildPoints)
+        self.ui.avoidFlip.clicked.connect(self.rebuildPoints)
+        self.ui.autoDeleteMeridian.clicked.connect(self.rebuildPoints)
+        self.ui.autoDeleteHorizon.clicked.connect(self.rebuildPoints)
         self.app.buildPointsChanged.connect(self.buildPointsChanged)
         self.ui.generateQuery.editingFinished.connect(self.querySimbad)
         self.ui.isOnline.stateChanged.connect(self.setupDsoGui)
@@ -97,8 +94,6 @@ class BuildPoints:
         self.ui.altitudeMin.valueChanged.disconnect(self.genBuildGrid)
         self.ui.altitudeMax.valueChanged.disconnect(self.genBuildGrid)
         self.ui.numberDSOPoints.valueChanged.disconnect(self.genBuildDSO)
-        self.ui.durationDSO.valueChanged.disconnect(self.genBuildDSO)
-        self.ui.timeShiftDSO.valueChanged.disconnect(self.genBuildDSO)
 
         self.ui.buildPFileName.setText(config.get('buildPFileName', ''))
         self.ui.numberGridPointsRow.setValue(config.get('numberGridPointsRow', 5))
@@ -106,28 +101,25 @@ class BuildPoints:
         self.ui.altitudeMin.setValue(config.get('altitudeMin', 30))
         self.ui.altitudeMax.setValue(config.get('altitudeMax', 75))
         self.ui.numberDSOPoints.setValue(config.get('numberDSOPoints', 15))
-        self.ui.durationDSO.setValue(config.get('durationDSO', 7))
-        self.ui.timeShiftDSO.setValue(config.get('timeShiftDSO', 0))
+        self.ui.numberSpiral.setValue(config.get('numberSpiral', 30))
 
-        self.ui.checkAutoDeleteMeridian.setChecked(config.get('checkAutoDeleteMeridian', False))
-        self.ui.checkAutoDeleteHorizon.setChecked(config.get('checkAutoDeleteHorizon', True))
-        self.ui.checkSafetyMarginHorizon.setChecked(config.get('checkSafetyMarginHorizon',
-                                                               False))
-        self.ui.safetyMarginHorizon.setValue(config.get('safetyMarginHorizon', 0))
-        self.ui.checkAvoidFlip.setChecked(config.get('checkAvoidFlip', False))
-        self.ui.checkSortNothing.setChecked(config.get('checkSortNothing', True))
-        self.ui.checkSortEW.setChecked(config.get('checkSortEW', False))
+        self.ui.autoDeleteMeridian.setChecked(config.get('autoDeleteMeridian', False))
+        self.ui.autoDeleteHorizon.setChecked(config.get('autoDeleteHorizon', True))
+        self.ui.useSafetyMargin.setChecked(config.get('useSafetyMargin', False))
+        self.ui.safetyMarginValue.setValue(config.get('safetyMarginValue', 0))
+        self.ui.avoidFlip.setChecked(config.get('avoidFlip', False))
+        self.ui.sortNothing.setChecked(config.get('sortNothing', True))
+        self.ui.sortEW.setChecked(config.get('sortEW', False))
         self.ui.useDomeAz.setChecked(config.get('useDomeAz', False))
-        self.ui.checkSortHL.setChecked(config.get('checkSortHL', False))
+        self.ui.sortHL.setChecked(config.get('sortHL', False))
         self.ui.keepGeneratedPoints.setChecked(config.get('keepGeneratedPoints', False))
+        self.ui.ditherBuildPoints.setChecked(config.get('ditherBuildPoints', False))
 
         self.ui.numberGridPointsCol.valueChanged.connect(self.genBuildGrid)
         self.ui.numberGridPointsRow.valueChanged.connect(self.genBuildGrid)
         self.ui.altitudeMin.valueChanged.connect(self.genBuildGrid)
         self.ui.altitudeMax.valueChanged.connect(self.genBuildGrid)
         self.ui.numberDSOPoints.valueChanged.connect(self.genBuildDSO)
-        self.ui.durationDSO.valueChanged.connect(self.genBuildDSO)
-        self.ui.timeShiftDSO.valueChanged.connect(self.genBuildDSO)
         self.setupDsoGui()
         return True
 
@@ -142,18 +134,18 @@ class BuildPoints:
         config['altitudeMin'] = self.ui.altitudeMin.value()
         config['altitudeMax'] = self.ui.altitudeMax.value()
         config['numberDSOPoints'] = self.ui.numberDSOPoints.value()
-        config['durationDSO'] = self.ui.durationDSO.value()
-        config['timeShiftDSO'] = self.ui.timeShiftDSO.value()
-        config['checkAutoDeleteMeridian'] = self.ui.checkAutoDeleteMeridian.isChecked()
-        config['checkAutoDeleteHorizon'] = self.ui.checkAutoDeleteHorizon.isChecked()
-        config['checkSafetyMarginHorizon'] = self.ui.checkSafetyMarginHorizon.isChecked()
-        config['safetyMarginHorizon'] = self.ui.safetyMarginHorizon.value()
-        config['checkAvoidFlip'] = self.ui.checkAvoidFlip.isChecked()
-        config['checkSortNothing'] = self.ui.checkSortNothing.isChecked()
-        config['checkSortEW'] = self.ui.checkSortEW.isChecked()
+        config['numberSpiral'] = self.ui.numberSpiral.value()
+        config['autoDeleteMeridian'] = self.ui.autoDeleteMeridian.isChecked()
+        config['autoDeleteHorizon'] = self.ui.autoDeleteHorizon.isChecked()
+        config['useSafetyMargin'] = self.ui.useSafetyMargin.isChecked()
+        config['safetyMarginValue'] = self.ui.safetyMarginValue.value()
+        config['avoidFlip'] = self.ui.avoidFlip.isChecked()
+        config['sortNothing'] = self.ui.sortNothing.isChecked()
+        config['sortEW'] = self.ui.sortEW.isChecked()
         config['useDomeAz'] = self.ui.useDomeAz.isChecked()
-        config['checkSortHL'] = self.ui.checkSortHL.isChecked()
+        config['sortHL'] = self.ui.sortHL.isChecked()
         config['keepGeneratedPoints'] = self.ui.keepGeneratedPoints.isChecked()
+        config['ditherBuildPoints'] = self.ui.ditherBuildPoints.isChecked()
 
         return True
 
@@ -190,7 +182,8 @@ class BuildPoints:
             self.ui.numberGridPointsCol.setEnabled(True)
             self.ui.altitudeMin.setEnabled(True)
             self.ui.altitudeMax.setEnabled(True)
-            self.app.message.emit('Could not generate grid', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Could not generate grid')
             return False
 
         self.processPoints()
@@ -214,7 +207,8 @@ class BuildPoints:
                                      numberBase=3,
                                      keep=keep)
         if not suc:
-            self.app.message.emit('Could not generate 3 align stars', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Could not generate 3 align stars')
             return False
 
         self.processPoints()
@@ -234,7 +228,8 @@ class BuildPoints:
                                      numberBase=6,
                                      keep=keep)
         if not suc:
-            self.app.message.emit('Could not generate 6 align stars', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Could not generate 6 align stars')
             return False
 
         self.processPoints()
@@ -254,7 +249,8 @@ class BuildPoints:
                                      numberBase=9,
                                      keep=keep)
         if not suc:
-            self.app.message.emit('Could not generate 9 align stars', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Could not generate 9 align stars')
             return False
 
         self.processPoints()
@@ -274,7 +270,8 @@ class BuildPoints:
                                      numberBase=12,
                                      keep=keep)
         if not suc:
-            self.app.message.emit('Could not generate 12 align stars', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Could not generate 12 align stars')
             return False
 
         self.processPoints()
@@ -292,9 +289,12 @@ class BuildPoints:
         keep = self.ui.keepGeneratedPoints.isChecked()
         suc = self.app.data.genGreaterCircle(selection='max', keep=keep)
         if not suc:
-            self.app.message.emit('Build points [max] cannot be generated', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Build points [max] cannot be generated')
             return False
 
+        if self.ui.ditherBuildPoints.isChecked():
+            self.app.data.ditherPoints()
         self.processPoints()
         return True
 
@@ -310,9 +310,12 @@ class BuildPoints:
         keep = self.ui.keepGeneratedPoints.isChecked()
         suc = self.app.data.genGreaterCircle(selection='med', keep=keep)
         if not suc:
-            self.app.message.emit('Build points [med] cannot be generated', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Build points [med] cannot be generated')
             return False
 
+        if self.ui.ditherBuildPoints.isChecked():
+            self.app.data.ditherPoints()
         self.processPoints()
         return True
 
@@ -328,9 +331,12 @@ class BuildPoints:
         keep = self.ui.keepGeneratedPoints.isChecked()
         suc = self.app.data.genGreaterCircle(selection='norm', keep=keep)
         if not suc:
-            self.app.message.emit('Build points [norm] cannot be generated', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Build points [norm] cannot be generated')
             return False
 
+        if self.ui.ditherBuildPoints.isChecked():
+            self.app.data.ditherPoints()
         self.processPoints()
         return True
 
@@ -346,9 +352,12 @@ class BuildPoints:
         keep = self.ui.keepGeneratedPoints.isChecked()
         suc = self.app.data.genGreaterCircle(selection='min', keep=keep)
         if not suc:
-            self.app.message.emit('Build points [min] cannot be generated', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Build points [min] cannot be generated')
             return False
 
+        if self.ui.ditherBuildPoints.isChecked():
+            self.app.data.ditherPoints()
         self.processPoints()
         return True
 
@@ -359,53 +368,43 @@ class BuildPoints:
         :return: success
         """
         self.lastGenerator = 'dso'
-        ra = self.app.mount.obsSite.raJNow
+        ha = self.app.mount.obsSite.raJNow
         dec = self.app.mount.obsSite.decJNow
         lst = self.app.mount.obsSite.timeSidereal
         timeJD = self.app.mount.obsSite.timeJD
         location = self.app.mount.obsSite.location
 
-        if ra is None or dec is None or location is None or lst is None:
-            self.app.message.emit('DSO Path cannot be generated', 2)
+        if ha is None or dec is None or location is None or lst is None:
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'DSO Path cannot be generated - mount off')
             return False
 
         if self.simbadRa and self.simbadDec:
-            ra = Angle(hours=self.simbadRa.hours - lst.hours)
+            ha = self.simbadRa
             dec = self.simbadDec
 
         self.ui.numberDSOPoints.setEnabled(False)
-        self.ui.durationDSO.setEnabled(False)
-        self.ui.timeShiftDSO.setEnabled(False)
-
         numberPoints = self.ui.numberDSOPoints.value()
-        duration = self.ui.durationDSO.value()
-        timeShift = self.ui.timeShiftDSO.value()
-
         keep = self.ui.keepGeneratedPoints.isChecked()
-        suc = self.app.data.generateDSOPath(ra=ra,
+        suc = self.app.data.generateDSOPath(ha=ha,
                                             dec=dec,
                                             timeJD=timeJD,
                                             location=location,
                                             numberPoints=numberPoints,
-                                            duration=duration,
-                                            timeShift=timeShift,
-                                            keep=keep,
-                                            )
-
+                                            keep=keep)
         if not suc:
             self.ui.numberDSOPoints.setEnabled(True)
-            self.ui.durationDSO.setEnabled(True)
-            self.ui.timeShiftDSO.setEnabled(True)
-            self.app.message.emit('DSO Path cannot be generated', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'DSO Path cannot be generated - calc error')
             return False
 
+        if self.ui.ditherBuildPoints.isChecked():
+            self.app.data.ditherPoints()
         self.processPoints()
         self.ui.numberDSOPoints.setEnabled(True)
-        self.ui.durationDSO.setEnabled(True)
-        self.ui.timeShiftDSO.setEnabled(True)
         return True
 
-    def genBuildSpiralMax(self):
+    def genBuildGoldenSpiral(self):
         """
         genBuildGoldenSpiral generates points along the actual tracking path
         as the processing might take to long (at least on ubuntu), we have to
@@ -415,54 +414,38 @@ class BuildPoints:
 
         :return: success
         """
-        self.lastGenerator = 'spiralMax'
-        keep = self.ui.keepGeneratedPoints.isChecked()
-        suc = self.app.data.generateGoldenSpiral(numberPoints=350, keep=keep)
+        self.lastGenerator = 'spiral'
+        numberTarget = int(self.ui.numberSpiral.value())
+        self.changeStyleDynamic(self.ui.genBuildSpiral, 'running', True)
+        numberPoints = 0
+        numberFilter = 0
+        while numberFilter < numberTarget:
+            numberPoints = numberPoints + numberTarget - numberFilter
+            suc = self.app.data.generateGoldenSpiral(numberPoints=numberPoints)
+            if not suc:
+                break
+            self.processPoints()
+            numberFilter = len(self.app.data.buildP)
+        self.changeStyleDynamic(self.ui.genBuildSpiral, 'running', False)
         if not suc:
-            self.app.message.emit('Golden spiral cannot be generated', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Golden spiral cannot be generated')
             return False
-
-        self.processPoints()
         return True
 
-    def genBuildSpiralMed(self):
+    def genModel(self):
         """
         :return: success
         """
-        self.lastGenerator = 'spiralMed'
+        self.lastGenerator = 'model'
+
         keep = self.ui.keepGeneratedPoints.isChecked()
-        suc = self.app.data.generateGoldenSpiral(numberPoints=250, keep=keep)
-        if not suc:
-            self.app.message.emit('Golden spiral cannot be generated', 2)
-            return False
+        if not keep:
+            self.app.data.clearBuildP()
 
-        self.processPoints()
-        return True
-
-    def genBuildSpiralNorm(self):
-        """
-        :return: success
-        """
-        self.lastGenerator = 'spiralNorm'
-        keep = self.ui.keepGeneratedPoints.isChecked()
-        suc = self.app.data.generateGoldenSpiral(numberPoints=150, keep=keep)
-        if not suc:
-            self.app.message.emit('Golden spiral cannot be generated', 2)
-            return False
-
-        self.processPoints()
-        return True
-
-    def genBuildSpiralMin(self):
-        """
-        :return: success
-        """
-        self.lastGenerator = 'spiralMin'
-        keep = self.ui.keepGeneratedPoints.isChecked()
-        suc = self.app.data.generateGoldenSpiral(numberPoints=75, keep=keep)
-        if not suc:
-            self.app.message.emit('Golden spiral cannot be generated', 2)
-            return False
+        model = self.app.mount.model
+        for star in model.starList:
+            self.app.data.addBuildP((star.alt.degrees, star.az.degrees, True))
 
         self.processPoints()
         return True
@@ -476,15 +459,17 @@ class BuildPoints:
         self.lastGenerator = 'file'
         fileName = self.ui.buildPFileName.text()
         if not fileName:
-            self.app.message.emit('Build points file name not given', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          'Build points file name not given')
             return False
 
         keep = self.ui.keepGeneratedPoints.isChecked()
-        suc = self.app.data.loadBuildP(fileName=fileName, keep=keep)
+        fullFileName = self.app.mwGlob['configDir'] + '/' + fileName + '.bpts'
+        suc = self.app.data.loadBuildP(fullFileName=fullFileName, keep=keep)
 
         if not suc:
-            text = 'Build points file [{0}] could not be loaded'.format(fileName)
-            self.app.message.emit(text, 2)
+            text = f'Build points file [{fileName}] could not be loaded'
+            self.msg.emit(2, 'Model', 'Buildpoints', text)
             return False
 
         self.processPoints()
@@ -495,22 +480,23 @@ class BuildPoints:
         :return: success
         """
         folder = self.app.mwGlob['configDir']
-        fileTypes = 'Build Point Files (*.bpts);; CSV Files (*.csv)'
-        loadFilePath, fileName, ext = self.openFile(self,
-                                                    'Open build point file',
-                                                    folder,
-                                                    fileTypes)
-        if not loadFilePath:
+        fileTypes = 'Build Point Files (*.bpts)'
+        fileTypes += ';; CSV Files (*.csv)'
+        fileTypes += ';; Model Files (*.model)'
+        fullFileName, fileName, ext = self.openFile(
+            self, 'Open build point file', folder, fileTypes)
+        if not fullFileName:
             return False
 
         keep = self.ui.keepGeneratedPoints.isChecked()
-        suc = self.app.data.loadBuildP(fileName=fileName, ext=ext, keep=keep)
+        suc = self.app.data.loadBuildP(fullFileName=fullFileName, ext=ext, keep=keep)
         if suc:
             self.ui.buildPFileName.setText(fileName)
-            self.app.message.emit(f'Build file [{fileName}] loaded', 0)
+            self.msg.emit(0, 'Model', 'Buildpoints',
+                          f'Build file [{fileName}] loaded')
         else:
-            self.app.message.emit(f'Build file [{fileName}] cannot no be loaded', 2)
-
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          f'Build file [{fileName}] cannot be loaded')
         self.genBuildFile()
         return True
 
@@ -520,21 +506,22 @@ class BuildPoints:
         """
         fileName = self.ui.buildPFileName.text()
         if not fileName:
-            self.app.message.emit('Build points file name not given', 2)
+            self.msg.emit(0, 'Model', 'Buildpoints',
+                          'Build points file name not given')
             return False
 
         suc = self.app.data.saveBuildP(fileName=fileName)
         if suc:
-            self.app.message.emit(f'Build file [{fileName}] saved', 0)
+            self.msg.emit(0, 'Model', 'Buildpoints',
+                          f'Build file [{fileName}] saved')
         else:
-            self.app.message.emit(f'Build file [{fileName}] cannot no be saved', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          f'Build file [{fileName}] cannot be saved')
 
         return True
 
     def saveBuildFileAs(self):
         """
-        saveBuildFileAs calls a file selector box and selects the filename to be save
-
         :return: success
         """
         folder = self.app.mwGlob['configDir']
@@ -549,9 +536,11 @@ class BuildPoints:
         suc = self.app.data.saveBuildP(fileName=fileName)
         if suc:
             self.ui.buildPFileName.setText(fileName)
-            self.app.message.emit(f'Build file [{fileName}] saved', 0)
+            self.msg.emit(0, 'Model', 'Buildpoints',
+                          f'Build file [{fileName}] saved')
         else:
-            self.app.message.emit(f'Build file [{fileName}] cannot no be saved', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          f'Build file [{fileName}] cannot be saved')
 
         return True
 
@@ -564,7 +553,7 @@ class BuildPoints:
         if not self.app.uiWindows['showHemisphereW']['classObj']:
             return False
 
-        self.app.uiWindows['showHemisphereW']['classObj'].clearHemisphere()
+        self.app.redrawHemisphere.emit()
         return True
 
     def autoDeletePoints(self):
@@ -575,12 +564,12 @@ class BuildPoints:
 
         :return: True for test purpose
         """
-        if self.ui.checkAutoDeleteHorizon.isChecked():
+        if self.ui.autoDeleteHorizon.isChecked():
             self.app.data.deleteBelowHorizon()
-        if self.ui.checkAutoDeleteMeridian.isChecked():
+        if self.ui.autoDeleteMeridian.isChecked():
             self.app.data.deleteCloseMeridian()
-        if self.ui.checkSafetyMarginHorizon.isChecked():
-            value = self.ui.safetyMarginHorizon.value()
+        if self.ui.useSafetyMargin.isChecked():
+            value = self.ui.safetyMarginValue.value()
             self.app.data.deleteCloseHorizonLine(value)
         return True
 
@@ -655,17 +644,17 @@ class BuildPoints:
     def autoSortPoints(self):
         """
         autoSortPoints sort the given build point first to east and west and
-        than based on the decision high altitude to low altitude or east to west
+        then based on the decision high altitude to low altitude or east to west
         in each hemisphere
 
         :return: success if sorted
         """
-        eastwest = self.ui.checkSortEW.isChecked()
-        highlow = self.ui.checkSortHL.isChecked()
-        avoidFlip = self.ui.checkAvoidFlip.isChecked()
+        eastwest = self.ui.sortEW.isChecked()
+        highlow = self.ui.sortHL.isChecked()
+        avoidFlip = self.ui.avoidFlip.isChecked()
         useDomeAz = self.ui.useDomeAz.isChecked()
         enableDomeAz = self.ui.useDomeAz.isEnabled()
-        noSort = self.ui.checkSortNothing.isChecked()
+        noSort = self.ui.sortNothing.isChecked()
         pierside = self.app.mount.obsSite.pierside
 
         if not avoidFlip:
@@ -727,12 +716,12 @@ class BuildPoints:
         :return:
         """
         if not self.ui.isOnline.isChecked():
-            self.app.message.emit('MW4 is offline', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints', 'MW4 is offline')
             return False
 
         ident = self.ui.generateQuery.text().strip()
         if not ident:
-            self.app.message.emit('No query data given', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints', 'No query data given')
             self.ui.generateRa.setText('')
             self.ui.generateDec.setText('')
             self.simbadRa = None
@@ -742,7 +731,8 @@ class BuildPoints:
         result = Simbad.query_object(ident)
 
         if not result:
-            self.app.message.emit(f'No response from SIMBAD for {ident}', 2)
+            self.msg.emit(2, 'Model', 'Buildpoints',
+                          f'No response from SIMBAD for {ident}')
             self.ui.generateRa.setText('')
             self.ui.generateDec.setText('')
             self.simbadRa = None
