@@ -15,6 +15,7 @@
 #
 ###########################################################
 # standard libraries
+import platform
 import webbrowser
 
 # external packages
@@ -38,6 +39,7 @@ class Environ:
         self.refractionSource = ''
         self.filteredTemperature = None
         self.filteredPressure = None
+        self.seeingEnabled = False
 
         signals = self.app.sensorWeather.signals
         signals.deviceDisconnected.connect(self.clearSensorWeatherGui)
@@ -64,7 +66,7 @@ class Environ:
         self.ui.refracManual.clicked.connect(self.setRefractionUpdateType)
         self.ui.refracCont.clicked.connect(self.setRefractionUpdateType)
         self.ui.refracNoTrack.clicked.connect(self.setRefractionUpdateType)
-        self.ui.unitTimeUTC.clicked.connect(self.updateSeeingEntries)
+        self.ui.unitTimeUTC.toggled.connect(self.updateSeeingEntries)
         self.app.seeingWeather.signals.update.connect(self.prepareSeeingTable)
         self.clickable(self.ui.meteoblueIcon).connect(self.openMeteoblue)
         # cyclic functions
@@ -75,8 +77,9 @@ class Environ:
         self.app.update1s.connect(self.updatePowerWeatherGui)
         self.app.update1s.connect(self.updateSensorWeatherGui)
         self.app.update1s.connect(self.updateOnlineWeatherGui)
+        self.app.start3s.connect(self.enableSeeingEntries)
         self.app.update30m.connect(self.updateSeeingEntries)
-        self.app.colorChange.connect(self.updateSeeingEntries)
+        self.app.colorChange.connect(self.prepareSeeingTable)
 
     def initConfig(self):
         """
@@ -159,6 +162,9 @@ class Environ:
             suc = self.app.mount.setting.setDirectWeatherUpdateType(0)
             return suc
 
+        if self.app.mount.setting.weatherStatus == 0:
+            self.ui.refracCont.setChecked(True)
+
         # otherwise, we have to switch it on or off
         if self.ui.refracManual.isChecked():
             suc = self.app.mount.setting.setDirectWeatherUpdateType(0)
@@ -223,11 +229,13 @@ class Environ:
             temp = self.app.sensorWeather.data.get(key)
             key = 'WEATHER_PARAMETERS.WEATHER_PRESSURE'
             press = self.app.sensorWeather.data.get(key)
+
         elif self.refractionSource == 'onlineWeather':
             key = 'WEATHER_PARAMETERS.WEATHER_TEMPERATURE'
             temp = self.app.onlineWeather.data.get(key)
             key = 'WEATHER_PARAMETERS.WEATHER_PRESSURE'
             press = self.app.onlineWeather.data.get(key)
+
         else:
             temp = None
             press = None
@@ -303,15 +311,19 @@ class Environ:
         value = self.app.sensorWeather.data.get(
             'WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
         self.guiSetText(self.ui.sensorWeatherTemp, '4.1f', value)
+
         value = self.app.sensorWeather.data.get(
             'WEATHER_PARAMETERS.WEATHER_PRESSURE')
         self.guiSetText(self.ui.sensorWeatherPress, '4.1f', value)
+
         value = self.app.sensorWeather.data.get(
             'WEATHER_PARAMETERS.WEATHER_DEWPOINT')
         self.guiSetText(self.ui.sensorWeatherDewPoint, '4.1f', value)
+
         value = self.app.sensorWeather.data.get(
             'WEATHER_PARAMETERS.WEATHER_HUMIDITY')
         self.guiSetText(self.ui.sensorWeatherHumidity, '3.0f', value)
+
         return True
 
     def clearSensorWeatherGui(self, deviceName=''):
@@ -320,6 +332,8 @@ class Environ:
         :return: true for test purpose
         """
         self.app.sensorWeather.data.clear()
+        self.ui.meteoblueIcon.setVisible(False)
+        self.ui.meteoblueSeeing.setVisible(False)
         self.updateSensorWeatherGui()
         return True
 
@@ -329,8 +343,10 @@ class Environ:
         """
         value = self.app.skymeter.data.get('SKY_QUALITY.SKY_BRIGHTNESS')
         self.guiSetText(self.ui.skymeterSQR, '5.2f', value)
+
         value = self.app.skymeter.data.get('SKY_QUALITY.SKY_TEMPERATURE')
         self.guiSetText(self.ui.skymeterTemp, '4.1f', value)
+
         return True
 
     def clearSkymeterGui(self, deviceName=''):
@@ -351,10 +367,16 @@ class Environ:
         """
         value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
         self.guiSetText(self.ui.powerTemp, '4.1f', value)
+
+        value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_PRESSURE')
+        self.guiSetText(self.ui.powerPress, '4.1f', value)
+
         value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_HUMIDITY')
         self.guiSetText(self.ui.powerHumidity, '3.0f', value)
+
         value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_DEWPOINT')
         self.guiSetText(self.ui.powerDewPoint, '4.1f', value)
+
         return True
 
     def clearPowerWeatherGui(self):
@@ -373,16 +395,22 @@ class Environ:
         """
         value = self.app.onlineWeather.data.get('temperature')
         self.guiSetText(self.ui.onlineWeatherTemp, '4.1f', value)
+
         value = self.app.onlineWeather.data.get('pressure')
         self.guiSetText(self.ui.onlineWeatherPress, '5.1f', value)
+
         value = self.app.onlineWeather.data.get('humidity')
         self.guiSetText(self.ui.onlineWeatherHumidity, '3.0f', value)
+
         value = self.app.onlineWeather.data.get('dewPoint')
         self.guiSetText(self.ui.onlineWeatherDewPoint, '4.1f', value)
+
         value = self.app.onlineWeather.data.get('cloudCover')
         self.guiSetText(self.ui.onlineWeatherCloudCover, '3.0f', value)
+
         value = self.app.onlineWeather.data.get('rain')
         self.guiSetText(self.ui.onlineWeatherRainVol, '5.2f', value)
+
         return True
 
     def clearOnlineWeatherGui(self):
@@ -402,15 +430,19 @@ class Environ:
         value = self.app.directWeather.data.get(
             'WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
         self.guiSetText(self.ui.directWeatherTemp, '4.1f', value)
+
         value = self.app.directWeather.data.get(
             'WEATHER_PARAMETERS.WEATHER_PRESSURE')
         self.guiSetText(self.ui.directWeatherPress, '4.1f', value)
+
         value = self.app.directWeather.data.get(
             'WEATHER_PARAMETERS.WEATHER_DEWPOINT')
         self.guiSetText(self.ui.directWeatherDewPoint, '4.1f', value)
+
         value = self.app.directWeather.data.get(
             'WEATHER_PARAMETERS.WEATHER_HUMIDITY')
         self.guiSetText(self.ui.directWeatherHumidity, '3.0f', value)
+
         return True
 
     def clearDirectWeatherGui(self):
@@ -452,7 +484,7 @@ class Environ:
         colorMain = self.cs['M_BLUE'][0]
         colorBlack = self.cs['M_BLACK'][0]
         colorWhite = self.cs['M_WHITE'][0]
-        seeTab = self.ui.tableSeeing
+        seeTab = self.ui.meteoblueSeeing
         data = self.app.seeingWeather.data['hourly']
         self.addSkyfieldTimeObject(data)
 
@@ -505,7 +537,21 @@ class Environ:
         """
         :return:
         """
-        self.ui.tableSeeing.clear()
+        self.ui.meteoblueSeeing.clear()
+        self.ui.meteoblueIcon.setVisible(False)
+        self.ui.meteoblueSeeing.setVisible(False)
+        self.seeingEnabled = False
+        return True
+
+    def enableSeeingEntries(self):
+        """
+        :return:
+        """
+        if not self.seeingEnabled:
+            return False
+
+        self.ui.meteoblueIcon.setVisible(True)
+        self.ui.meteoblueSeeing.setVisible(True)
         return True
 
     def prepareSeeingTable(self):
@@ -514,9 +560,9 @@ class Environ:
         """
         vl = ['Date [dd mon]',
               'Hour [hh:mm]',
-              'Low clouds  [%]',
+              'High clouds  [%]',
               'Mid clouds  [%]',
-              'High clouds [%]',
+              'Low clouds [%]',
               'Seeing [arcsec]',
               'Seeing index 1',
               'Seeing index 2',
@@ -526,12 +572,19 @@ class Environ:
               'Bad Layers Bot [km]',
               'Bad Layers [K/100m]',
               'Jet stream [m/s]',
+              '',
               ]
 
-        seeTab = self.ui.tableSeeing
-        seeTab.setRowCount(14)
+        self.seeingEnabled = True
+        self.enableSeeingEntries()
+        seeTab = self.ui.meteoblueSeeing
+        if platform.system() == 'Darwin':
+            seeTab.setRowCount(15)
+        else:
+            seeTab.setRowCount(14)
         seeTab.setColumnCount(96)
         seeTab.setVerticalHeaderLabels(vl)
+        seeTab.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
         seeTab.verticalHeader().setDefaultSectionSize(18)
         self.updateSeeingEntries()
         seeTab.resizeColumnsToContents()
