@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -21,15 +20,15 @@ import json
 import os
 
 # external packages
-from PyQt5.QtWidgets import QMessageBox, QLineEdit, QInputDialog
+from PyQt5.QtWidgets import QLineEdit, QInputDialog
+from PyQt5.QtCore import Qt
 import numpy as np
-import matplotlib.pyplot
 
 # local import
-from logic.modeldata.modelHandling import writeRetrofitData
+from mw4.logic.modeldata.modelHandling import writeRetrofitData
 
 
-class ManageModel(object):
+class ManageModel:
     """
     """
 
@@ -45,9 +44,6 @@ class ManageModel(object):
         ms.alignDone.connect(self.showErrorDistribution)
         ms.namesDone.connect(self.setNameList)
 
-        self.ui.showErrorValues.clicked.connect(self.showModelPosition)
-        self.ui.showNumbers.clicked.connect(self.showModelPosition)
-        self.ui.showNoAnnotation.clicked.connect(self.showModelPosition)
         self.ui.refreshName.clicked.connect(self.refreshName)
         self.ui.refreshModel.clicked.connect(self.refreshModel)
         self.ui.clearModel.clicked.connect(self.clearModel)
@@ -70,9 +66,6 @@ class ManageModel(object):
         :return: True for test purpose
         """
         config = self.app.config['mainW']
-        self.ui.showErrorValues.setChecked(config.get('showErrorValues', False))
-        self.ui.showNumbers.setChecked(config.get('showNumbers', False))
-        self.ui.showNoAnnotation.setChecked(config.get('showNoAnnotation', True))
         self.ui.targetRMS.setValue(config.get('targetRMS', 10))
         self.ui.optimizeOverall.setChecked(config.get('optimizeOverall', True))
         self.ui.optimizeSingle.setChecked(config.get('optimizeSingle', True))
@@ -87,9 +80,6 @@ class ManageModel(object):
         :return: True for test purpose
         """
         config = self.app.config['mainW']
-        config['showErrorValues'] = self.ui.showErrorValues.isChecked()
-        config['showNumbers'] = self.ui.showNumbers.isChecked()
-        config['showNoAnnotation'] = self.ui.showNoAnnotation.isChecked()
         config['targetRMS'] = self.ui.targetRMS.value()
         config['optimizeOverall'] = self.ui.optimizeOverall.isChecked()
         config['optimizeSingle'] = self.ui.optimizeSingle.isChecked()
@@ -100,6 +90,9 @@ class ManageModel(object):
         """
         :return:
         """
+        for plot in [self.ui.modelPositions, self.ui.errorDistribution,
+                     self.ui.errorAscending]:
+            plot.colorChange()
         self.showModelPosition()
         self.showErrorAscending()
         self.showErrorDistribution()
@@ -176,7 +169,8 @@ class ManageModel(object):
             mountModel[star.number] = {'ha': star.coord.ra.hours,
                                        'dec': star.coord.dec.degrees}
 
-        modelFileList = glob.glob(self.app.mwGlob['modelDir'] + '/*.model')
+        searchPath = os.path.normpath(self.app.mwGlob['modelDir'] + '/*.model')
+        modelFileList = glob.glob(searchPath)
 
         for modelFilePath in modelFileList:
             if 'opt' in modelFilePath:
@@ -185,13 +179,11 @@ class ManageModel(object):
             with open(modelFilePath, 'r') as inFile:
                 try:
                     buildModelData = json.load(inFile)
-
                 except Exception as e:
                     self.log.warning(f'Cannot load model file: {[inFile]}, error: {e}')
                     continue
 
             pointsIn, pointsOut = self.compareModel(buildModelData, mountModel)
-
             if len(pointsIn) > 2:
                 self.fittedModelPoints = pointsIn
                 self.fittedModelPath = modelFilePath
@@ -207,167 +199,60 @@ class ManageModel(object):
 
     def showModelPosition(self):
         """
-        showModelPosition draws a polar plot of the align model stars and their
-        errors in color. the basic setup of the plot is taking place in the
-        central widget class. which is instantiated from there. important: the
-        coordinate in model is in HA and DEC  and not in RA and DEC. using
-        skyfield is a little bit misleading, because you address the hour angle
-         as .ra.hours
-
         :return:    True if ok for testing
         """
         model = self.app.mount.model
-        if model is None:
-            hasNoStars = True
-        else:
-            hasNoStars = model.starList is None or not model.starList
-
-        axe, fig = self.generatePolar(widget=self.modelPositionPlot)
-
-        axe.set_yticks(range(0, 90, 10))
-        axe.set_ylim(0, 90)
-        yLabel = ['', '', '', '', '', '', '', '', '']
-        axe.set_yticklabels(yLabel)
-
-        if hasNoStars:
-            axe.figure.canvas.draw()
+        altitude = np.array([x.alt.degrees for x in model.starList])
+        if len(altitude) == 0:
+            self.ui.modelPositions.p[0].clear()
             return False
-
-        altitude = np.asarray([x.alt.degrees for x in model.starList])
-        azimuth = np.asarray([x.az.degrees for x in model.starList])
-        error = np.asarray([x.errorRMS for x in model.starList])
-        self.plane = [(alt, az) for alt, az in zip(altitude, azimuth)]
-
-        # and plot it
-        cm = matplotlib.pyplot.cm.get_cmap('RdYlGn_r')
-        colors = np.asarray(error)
-        scaleErrorMax = max(colors)
-        scaleErrorMin = min(colors)
-        area = [200 if x >= max(colors) else 60 for x in error]
-        theta = azimuth / 180.0 * np.pi
-        r = 90 - altitude
-        scatter = axe.scatter(theta,
-                              r,
-                              c=colors,
-                              vmin=scaleErrorMin,
-                              vmax=scaleErrorMax,
-                              s=area,
-                              cmap=cm,
-                              zorder=0,
-                              )
-
-        if self.ui.showErrorValues.isChecked():
-            for star in model.starList:
-                text = f'{star.errorRMS:3.1f}'
-                axe.annotate(text,
-                             xy=(theta[star.number - 1],
-                                 r[star.number - 1]),
-                             color=self.M_BLUE,
-                             fontsize=9,
-                             fontweight='bold',
-                             zorder=1,
-                             )
-
-        elif self.ui.showNumbers.isChecked():
-            for star in model.starList:
-                text = f'{star.number:3.0f}'
-                axe.annotate(text,
-                             xy=(theta[star.number - 1],
-                                 r[star.number - 1]),
-                             color=self.M_BLUE,
-                             fontsize=9,
-                             fontweight='bold',
-                             zorder=1,
-                             )
-        self.generateColorbar(scatter=scatter, figure=fig, label='Error [arcsec]')
-        axe.figure.canvas.draw()
+        azimuth = np.array([x.az.degrees for x in model.starList])
+        error = np.array([x.errorRMS for x in model.starList])
+        errorAngle = np.array([x.errorAngle.degrees for x in model.starList])
+        index = np.array([star.number for star in model.starList])
+        self.ui.modelPositions.barItem.setLabel('right', 'Error [RMS]')
+        self.ui.modelPositions.plot(
+            azimuth, altitude, z=error, ang=errorAngle,
+            range={'xMin': -91, 'yMin': -91, 'xMax': 91, 'yMax': 91},
+            bar=True, data=list(zip(index, error)), reverse=True,
+            tip='PointNo: {data[0]}\nErrorRMS: {data[1]:0.1f}'.format)
+        self.ui.modelPositions.plotLoc(
+            self.app.mount.obsSite.location.latitude.degrees)
+        self.ui.modelPositions.scatterItem.sigClicked.connect(self.pointClicked)
         return True
 
     def showErrorAscending(self):
         """
-        showErrorAscending draws a plot of the align model stars and their
-        errors in ascending order.
-
         :return:    True if ok for testing
         """
         model = self.app.mount.model
-        if model is None:
-            hasNoStars = True
-        else:
-            hasNoStars = model.starList is None or not model.starList
-
-        axe, _ = self.generateFlat(widget=self.errorAscendingPlot,
-                                   title='Model Point Errors in ascending order')
-        if hasNoStars:
-            axe.figure.canvas.draw()
+        error = np.array([star.errorRMS for star in model.starList])
+        if len(error) == 0:
+            self.ui.errorAscending.p[0].clear()
             return False
-
-        axe.set_xlabel('Star',
-                       color=self.M_BLUE,
-                       fontweight='bold',
-                       fontsize=12)
-        axe.set_ylabel('Error per Star [RMS]',
-                       color=self.M_BLUE,
-                       fontweight='bold',
-                       fontsize=12)
-        errors = [star.errorRMS for star in model.starList]
-        errors.sort()
-        index = range(0, len(errors))
-        axe.plot(index,
-                 errors,
-                 marker='.',
-                 markersize=5,
-                 linestyle='none',
-                 color=self.M_GREEN)
-
-        value = self.ui.targetRMS.value()
-        axe.plot([0, len(index) - 1],
-                 [value, value],
-                 lw=3,
-                 color=self.M_PINK)
-        axe.figure.canvas.draw()
+        index = np.array([star.number for star in model.starList])
+        self.ui.errorAscending.p[0].setLabel('bottom', 'Starcount')
+        self.ui.errorAscending.p[0].setLabel('left', 'Error per Star [arcsec]')
+        temp = sorted(zip(error))
+        y = [x[0] for x in temp]
+        self.ui.errorAscending.plot(
+            index, y, color=self.M_GREEN,
+            tip='ErrorRMS: {y:0.1f}'.format)
         return True
 
     def showErrorDistribution(self):
         """
-        showErrorDistribution draws a polar plot of the align model stars and
-        their errors in color. the basic setup of the plot is taking place in the
-        central widget class. which is instantiated from there. important: the
-        coordinate in model is in HA and DEC  and not in RA and DEC. using
-        skyfield is a little bit misleading, because you address the hour
-        angle as ra.hours
-
         :return:    True if ok for testing
         """
-
         model = self.app.mount.model
-        if model is None:
-            hasNoStars = True
-        else:
-            hasNoStars = model.starList is None or not model.starList
-
-        axe, _ = self.generatePolar(widget=self.errorDistributionPlot,
-                                    title='Error Distribution')
-        if hasNoStars:
-            axe.figure.canvas.draw()
+        error = np.array([x.errorRMS for x in model.starList])
+        if len(error) == 0:
+            self.ui.errorDistribution.p[0].clear()
             return False
-
-        angles = [star.errorAngle.degrees / 180.0 * np.pi for star in model.starList]
-        errors = [star.errorRMS for star in model.starList]
-        axe.plot(angles,
-                 errors,
-                 marker='.',
-                 markersize=5,
-                 linestyle='none',
-                 color=self.M_GREEN)
-
-        values = [self.ui.targetRMS.value()] * 73
-        angles = np.arange(0, 365 / 180.0 * np.pi, 5 / 180.0 * np.pi)
-        axe.plot(angles,
-                 values,
-                 lw=3,
-                 color=self.M_PINK)
-        axe.figure.canvas.draw()
+        errorAngle = np.array([x.errorAngle.degrees for x in model.starList])
+        self.ui.errorDistribution.plot(
+            errorAngle, error, color=self.M_GREEN,
+            tip='ErrorRMS: {y:0.1f}'.format)
         return True
 
     def clearRefreshName(self):
@@ -380,7 +265,7 @@ class ManageModel(object):
         self.ui.saveName.setEnabled(True)
         self.ui.loadName.setEnabled(True)
         self.app.mount.signals.namesDone.disconnect(self.clearRefreshName)
-        self.app.message.emit('Model names refreshed', 0)
+        self.msg.emit(0, 'Model', 'Manage', 'Model names refreshed')
         return True
 
     def refreshName(self):
@@ -411,102 +296,104 @@ class ManageModel(object):
         :return: success
         """
         if self.ui.nameList.currentItem() is None:
-            self.app.message.emit('No model name selected', 2)
+            self.msg.emit(2, 'Model', 'Manage error',
+                          'No model name selected')
             return False
         modelName = self.ui.nameList.currentItem().text()
         suc = self.app.mount.model.loadName(modelName)
         if not suc:
-            self.app.message.emit(f'Model load failed:   [{modelName}]', 2)
+            self.msg.emit(2, 'Model', 'Manage error',
+                          f'Model load failed: [{modelName}]')
             return False
         else:
-            self.app.message.emit(f'Model loaded:        [{modelName}]', 0)
+            self.msg.emit(0, 'Model', 'Manage',
+                          f'Model loaded: [{modelName}]')
             self.refreshModel()
             return True
 
     def saveName(self):
         """
-        saveName take the given name and saves the actual alignment model to the model
-        database in the mount computer. after that it refreshes the list of the alignment
-        model names in mountwizzard.
+        saveName take the given name and saves the actual alignment model to the
+        model database in the mount computer. after that it refreshes the list of
+        the alignment model names in mountwizzard.
 
         :return: success
         """
         dlg = QInputDialog()
         modelName, ok = dlg.getText(self,
-                                    'Save model',
-                                    'New model name',
-                                    QLineEdit.Normal,
-                                    '',
-                                    )
+                                    'Save model', 'New model name',
+                                    QLineEdit.Normal, '')
         if modelName is None or not modelName:
-            self.app.message.emit('No model name given', 2)
+            self.msg.emit(2, 'Model', 'Manage error',
+                          'No model name given')
             return False
         if not ok:
             return False
 
         suc = self.app.mount.model.storeName(modelName)
         if not suc:
-            self.app.message.emit('Model [{0}] cannot be saved'.format(modelName), 2)
+            self.msg.emit(2, 'Model', 'Manage error',
+                          f'Model cannot be saved [{modelName}]')
             return False
         else:
-            self.app.message.emit('Model [{0}] saved'.format(modelName), 0)
+            self.msg.emit(0, 'Model', 'Manage',
+                          f'Model saved: [{modelName}]')
             self.refreshName()
             return True
 
     def deleteName(self):
         """
-        deleteName take the given name and deletes it from the model database in the
-        mount computer. after that it refreshes the list of the alignment model names in
-        mountwizzard.
+        deleteName take the given name and deletes it from the model database in
+        the mount computer. after that it refreshes the list of the alignment
+        model names in mountwizzard.
 
         :return: success
         """
         if self.ui.nameList.currentItem() is None:
-            self.app.message.emit('No model name selected', 2)
+            self.msg.emit(2, 'Model', 'Manage error',
+                          'No model name selected')
             return False
 
         modelName = self.ui.nameList.currentItem().text()
-        msg = QMessageBox
-        reply = msg.question(self,
-                             'Delete model',
-                             f'Delete model [{modelName}] from database?',
-                             msg.Yes | msg.No,
-                             msg.No,
-                             )
-        if reply != msg.Yes:
+        suc = self.messageDialog(
+            self, 'Delete model', f'Delete model [{modelName}] from database?')
+        if not suc:
             return False
 
         suc = self.app.mount.model.deleteName(modelName)
         if not suc:
-            self.app.message.emit('Model [{0}] cannot be deleted'.format(modelName), 2)
+            self.msg.emit(2, 'Model', 'Manage error',
+                          f'Model cannot be deleted [{modelName}]')
             return False
         else:
-            self.app.message.emit('Model [{0}] deleted'.format(modelName), 0)
+            self.msg.emit(0, 'Model', 'Manage',
+                          f'Model deleted: [{modelName}]')
             self.refreshName()
             return True
 
-    def writeBuildModelOptimized(self, foundModel, pointsIn, pointsOut):
+    def writeBuildModelOptimized(self, foundModel, pointsOut):
         """
         :param foundModel:
-        :param pointsIn:
         :param pointsOut:
         :return: true for test purpose
         """
         actPath = self.app.mwGlob['modelDir'] + '/' + foundModel + '.model'
         newPath = self.app.mwGlob['modelDir'] + '/' + foundModel + '-opt.model'
 
-        with open(actPath) as actFile:
-            actModel = json.load(actFile)
+        try:
+            with open(actPath) as actFile:
+                actModel = json.load(actFile)
+        except Exception as e:
+            self.log.warning(f'Cannot load model file: {[actFile]}, error: {e}')
+            return False
 
         newModel = []
-
         for element in actModel:
             if element['errorIndex'] in pointsOut:
                 continue
             newModel.append(element)
 
         newModel = writeRetrofitData(self.app.mount.model, newModel)
-
         with open(newPath, 'w+') as newFile:
             json.dump(newModel, newFile, sort_keys=True, indent=4)
 
@@ -520,17 +407,16 @@ class ManageModel(object):
         self.changeStyleDynamic(self.ui.modelGroup, 'running', False)
         self.ui.deleteWorstPoint.setEnabled(True)
         self.ui.runOptimize.setEnabled(True)
-        self.ui.cancelOptimize.setEnabled(True)
         self.ui.clearModel.setEnabled(True)
         self.app.mount.signals.alignDone.disconnect(self.clearRefreshModel)
-        self.app.message.emit('Align model data refreshed', 0)
-
-        foundModel, pointsIn, pointsOut = self.findFittingModel()
+        self.msg.emit(0, 'Model', 'Manage', 'Align model data refreshed')
+        foundModel, _, pointsOut = self.findFittingModel()
 
         if foundModel:
-            self.app.message.emit(f'Found stored model:  [{foundModel}]', 0)
+            self.msg.emit(0, 'Model', 'Manage',
+                          f'Found stored model:  [{foundModel}]')
             self.ui.originalModel.setText(foundModel)
-            self.writeBuildModelOptimized(foundModel, pointsIn, pointsOut)
+            self.writeBuildModelOptimized(foundModel, pointsOut)
 
         else:
             self.ui.originalModel.setText('No fitting model file found')
@@ -542,11 +428,11 @@ class ManageModel(object):
 
     def refreshModel(self):
         """
-        refreshModel disables interfering functions in gui and start reloading the
-        alignment model from the mount computer. it connects a link to clearRefreshModel
-        which enables the former disabled gui buttons and removes the link to the method.
-        after it triggers the refresh of names, it finished, because behaviour is event
-        driven
+        refreshModel disables interfering functions in gui and start reloading
+        the alignment model from the mount computer. it connects a link to
+        clearRefreshModel which enables the former disabled gui buttons and
+        removes the link to the method. after it triggers the refresh of names,
+        it finished, because behaviour is event driven
 
         :return: True for test purpose
         """
@@ -555,7 +441,6 @@ class ManageModel(object):
         self.app.mount.signals.alignDone.connect(self.clearRefreshModel)
         self.ui.deleteWorstPoint.setEnabled(False)
         self.ui.runOptimize.setEnabled(False)
-        self.ui.cancelOptimize.setEnabled(False)
         self.ui.clearModel.setEnabled(False)
         self.app.mount.getAlign()
 
@@ -565,23 +450,19 @@ class ManageModel(object):
         """
         :return:
         """
-        msg = QMessageBox
-        reply = msg.question(self,
-                             'Clear model',
-                             'Clear actual alignment model?',
-                             msg.Yes | msg.No,
-                             msg.No,
-                             )
-        if reply == msg.No:
+        suc = self.messageDialog(
+            self, 'Clear model', 'Clear actual alignment model')
+        if not suc:
             return False
 
         suc = self.app.mount.model.clearAlign()
         if not suc:
-            self.app.message.emit('Actual model cannot be cleared', 2)
+            self.msg.emit(2, 'Model', 'Manage error',
+                          'Actual model cannot be cleared')
             return False
-
         else:
-            self.app.message.emit('Actual model cleared', 0)
+            self.msg.emit(0, 'Model', 'Manage',
+                          'Actual model cleared')
             self.refreshModel()
             return True
 
@@ -598,13 +479,13 @@ class ManageModel(object):
         error = wStar.errorRMS
         suc = model.deletePoint(wStar.number)
         if not suc:
-            self.app.message.emit('Worst point cannot be deleted', 2)
+            self.msg.emit(2, 'Model', 'Manage error',
+                          'Worst point cannot be deleted')
             return False
-
         else:
             text = f'Point: {wIndex + 1:3.0f}, RMS of {error:5.1f}'
             text += ' arcsec deleted.'
-            self.app.message.emit(text, 0)
+            self.msg.emit(0, 'Model', 'Manage', text)
             self.refreshModel()
 
         return True
@@ -616,10 +497,8 @@ class ManageModel(object):
         mount = self.app.mount
         if mount.model.errorRMS < self.ui.targetRMS.value():
             self.runningOptimize = False
-
         if mount.model.numberStars is None:
             numberStars = 0
-
         else:
             numberStars = mount.model.numberStars
 
@@ -629,13 +508,13 @@ class ManageModel(object):
             suc = mount.model.deletePoint(wStar.number)
             if not suc:
                 self.runningOptimize = False
-                self.app.message.emit(f'Star [{wStar.number + 1:3.0f}] cannot be deleted', 2)
-
+                self.msg.emit(2, 'Model', 'Manage error',
+                              f'Star [{wStar.number + 1:3.0f}] cannot be '
+                              f'deleted')
             else:
                 text = f'Point: {wStar.number + 1:3.0f}: '
                 text += f'RMS of {wStar.errorRMS:5.1f} arcsec deleted.'
-                self.app.message.emit(text, 0)
-
+                self.msg.emit(0, 'Model', 'Manage', text)
             mount.getAlign()
 
         else:
@@ -649,10 +528,8 @@ class ManageModel(object):
         mount = self.app.mount
         if all([star.errorRMS < self.ui.targetRMS.value() for star in mount.model.starList]):
             self.runningOptimize = False
-
         if mount.model.numberStars is None:
             numberStars = 0
-
         else:
             numberStars = mount.model.numberStars
 
@@ -662,15 +539,13 @@ class ManageModel(object):
             suc = mount.model.deletePoint(wStar.number)
             if not suc:
                 self.runningOptimize = False
-                self.app.message.emit(f'Point {wStar.number + 1:3.0f} cannot be deleted', 2)
-
+                self.msg.emit(2, 'Model', 'Manage error',
+                              f'Point [{wStar.number + 1:3.0f}] cannot be deleted')
             else:
                 text = f'Point: {wStar.number + 1:3.0f}, RMS of {wStar.errorRMS:5.1f}'
                 text += ' arcsec deleted.'
-                self.app.message.emit(text, 0)
-
+                self.msg.emit(0, 'Model', 'Manage', text)
             mount.getAlign()
-
         else:
             self.finishOptimize()
         return True
@@ -679,18 +554,17 @@ class ManageModel(object):
         """
         :return: true for test purpose
         """
-        self.app.message.emit('Start optimizing model', 2)
+        self.msg.emit(1, 'Model', 'Manage', 'Start optimizing model')
         self.runningOptimize = True
         self.ui.deleteWorstPoint.setEnabled(False)
         self.ui.clearModel.setEnabled(False)
         self.ui.refreshModel.setEnabled(False)
+        self.ui.cancelOptimize.setEnabled(True)
         self.changeStyleDynamic(self.ui.runOptimize, 'running', True)
-        self.changeStyleDynamic(self.ui.cancelOptimize, 'cancel', True)
 
         if self.ui.optimizeOverall.isChecked():
             self.app.mount.signals.alignDone.connect(self.runTargetRMS)
             self.runTargetRMS()
-
         else:
             self.app.mount.signals.alignDone.connect(self.runSingleRMS)
             self.runSingleRMS()
@@ -702,7 +576,6 @@ class ManageModel(object):
         """
         if self.ui.optimizeOverall.isChecked():
             self.app.mount.signals.alignDone.disconnect(self.runTargetRMS)
-
         else:
             self.app.mount.signals.alignDone.disconnect(self.runSingleRMS)
 
@@ -710,8 +583,8 @@ class ManageModel(object):
         self.ui.deleteWorstPoint.setEnabled(True)
         self.ui.clearModel.setEnabled(True)
         self.ui.refreshModel.setEnabled(True)
-        self.changeStyleDynamic(self.ui.cancelOptimize, 'cancel', False)
-        self.app.message.emit('Optimizing done', 2)
+        self.ui.cancelOptimize.setEnabled(False)
+        self.msg.emit(0, 'Model', 'Manage', 'Optimizing done')
 
         return True
 
@@ -728,7 +601,6 @@ class ManageModel(object):
         """
         if not self.fittedModelPath:
             return False
-
         if not os.path.isfile(self.fittedModelPath):
             return False
 
@@ -743,65 +615,43 @@ class ManageModel(object):
             return False
 
         temp = os.path.splitext(self.fittedModelPath)
-        actualPath = temp[0] + '-opt' + temp[1]
+        actualPath = os.path.normpath(temp[0] + '-opt' + temp[1])
         if not os.path.isfile(actualPath):
             return False
 
         self.app.showAnalyse.emit(actualPath)
         return True
 
-    def deleteDialog(self, question):
+    def pointClicked(self, scatterPlotItem, points, event):
         """
-        :param question:
-        :return: OK
-        """
-        msg = QMessageBox
-        reply = msg.question(self, 'Deleting point', question, msg.Yes | msg.No, msg.No)
-        if reply != msg.Yes:
-            return False
-
-        else:
-            return True
-
-    def onMouseEdit(self, event):
-        """
-        onMouseEdit handles the mouse event in normal mode. this means depending on the
-        edit mode (horizon or model points) a left click adds a new point and right click
-        deletes the selected point.
-
+        :param scatterPlotItem:
+        :param points:
         :param event: mouse events
         :return: success
         """
-        if not event.inaxes:
+        if event.double():
             return False
-
-        if not self.plane:
+        if event.button() != Qt.MouseButton.LeftButton:
             return False
-
-        if not event.dblclick:
-            return False
-
-        event.xdata = (np.degrees(event.xdata) + 360) % 360
-        event.ydata = 90 - event.ydata
-        index = self.getIndexPoint(event=event, plane=self.plane, epsilon=5)
-        if index is None:
+        if len(points[0].data()) == 0:
             return False
+        index = points[0].data()[0]
 
         error = self.app.mount.model.starList[index].errorRMS
         text = f'Do you want to delete \npoint {index + 1:3.0f}'
         text += f'\nRMS of {error:5.1f} arcsec'
-        isYes = self.deleteDialog(text)
+        isYes = self.messageDialog(self, 'Deleting point', text)
         if not isYes:
             return False
 
         suc = self.app.mount.model.deletePoint(index)
         if not suc:
-            self.app.message.emit(f'Point {index + 1:3.0f} cannot be deleted', 2)
+            self.msg.emit(2, 'Model', 'Manage error',
+                          f'Point {index + 1:3.0f} cannot be deleted')
             return False
 
         text = f'Point: {index + 1:3.0f}, RMS of {error:5.1f}'
         text += ' arcsec deleted.'
-        self.app.message.emit(text, 0)
+        self.msg.emit(0, 'Model', 'Manage', text)
         self.refreshModel()
-
         return True
