@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -28,14 +28,6 @@ class Relay(object):
     def __init__(self):
         self.app.relay.signals.statusReady.connect(self.updateRelayGui)
 
-    def initConfig(self):
-        # config = self.app.config['mainW']
-        return True
-
-    def storeConfig(self):
-        # config = self.app.config['mainW']
-        return True
-
     def updateRelayGui(self):
         """
         updateRelayGui changes the style of the button related to the state of the relay
