@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -19,11 +18,14 @@
 import os
 import logging
 import datetime
+import platform
+from dateutil.tz import tzlocal
 
 # external packages
 from PyQt5.QtWidgets import QWidget, QDesktopWidget, QFileDialog, QMessageBox
-from PyQt5.QtWidgets import QTableWidgetItem, QPushButton
+from PyQt5.QtWidgets import QTableWidgetItem
 from PyQt5.QtGui import QPalette, QIcon, QPixmap, QColor, QPainter, QImage
+from PyQt5.QtGui import QPainterPath, QTransform
 from PyQt5.QtCore import QSortFilterProxyModel, QDir, QObject, pyqtSignal
 from PyQt5.QtCore import Qt, QSize, QEvent
 from PyQt5.QtTest import QTest
@@ -31,9 +33,8 @@ import numpy as np
 from qimage2ndarray import rgb_view, array2qimage
 
 # local imports
-from gui.utilities.stylesQtCss import Styles
-from gui.utilities.toolsMatplotlib import ToolsMatplotlib
-from mountcontrol.convert import formatHstrToText, formatDstrToText
+from mw4.gui.utilities.stylesQtCss import Styles
+from mw4.mountcontrol.convert import formatHstrToText, formatDstrToText
 
 __all__ = [
     'MWidget',
@@ -56,7 +57,7 @@ class FileSortProxyModel(QSortFilterProxyModel):
     """
     FileSortProxyModel enables a proxy solution for reversing the order of all
     file dialogues. The sorting is now Descending meaning the last added files
-    will be on top. This is don by just overwriting the sort method
+    will be on top. This is done by just overwriting the sort method
     """
     def sort(self, column, order):
         self.sourceModel().sort(0, Qt.DescendingOrder)
@@ -70,7 +71,7 @@ class QMultiWait(QObject):
 
     https://stackoverflow.com/questions/21108407/qt-how-to-wait-for-multiple-signals
 
-    in addition all received signals could be reset
+    in addition, all received signals could be reset
     """
     ready = pyqtSignal()
     log = logging.getLogger(__name__)
@@ -130,7 +131,7 @@ class QCustomTableWidgetItem(QTableWidgetItem):
             return QTableWidgetItem.__lt__(self, other)
 
 
-class MWidget(QWidget, Styles, ToolsMatplotlib):
+class MWidget(QWidget, Styles):
     """
     MWidget defines the common parts for all windows used in MountWizzard 4 and
     extends the standard widgets. All widgets configs which are used mor than
@@ -145,8 +146,8 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
     but except for the main one are sizable.
     """
 
-    __all__ = ['MWidget',
-               ]
+    __all__ = ['MWidget']
+    log = logging.getLogger(__name__)
 
     def __init__(self):
         super().__init__()
@@ -161,6 +162,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         newFlag = newFlag | Qt.WindowMinimizeButtonHint | Qt.WindowMaximizeButtonHint
         self.setWindowFlags(self.windowFlags() | newFlag)
         self.setWindowIcon(QIcon(':/icon/mw4.png'))
+        self.setFocusPolicy(Qt.NoFocus)
 
     @staticmethod
     def findIndexValue(ui, searchString, relaxed=False):
@@ -268,7 +270,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
     def wIcon(self, gui=None, name=''):
         """
-        widget icon adds an icon to a gui element like an button.
+        widget icon adds an icon to a gui element like a button.
 
         :param      gui:        gui element, which will be expanded by an icon
         :param      name:       icon to be added
@@ -279,7 +281,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         if not name:
             return False
 
-        icon = self.svg2icon(f':/icon/{name}.svg', self.M_BLUE)
+        icon = self.svg2icon(f':/icon/{name}.svg', self.M_WHITE)
         gui.setIcon(icon)
         gui.setIconSize(QSize(16, 16))
         gui.setProperty('alignLeft', True)
@@ -287,26 +289,11 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         gui.style().polish(gui)
         return True
 
-    @staticmethod
-    def changeIconColor(widget, color):
-        """
-        :param widget:
-        :param color:
-        :return:
-        """
-        icon = widget.icon()
-        pixmap = icon.pixmap(icon.actualSize(QSize(64, 64)))
-        mask = pixmap.createMaskFromColor(QColor('transparent'), Qt.MaskInColor)
-        pixmap.fill(QColor(color))
-        pixmap.setMask(mask)
-        widget.setIcon(QIcon(pixmap))
-        return True
-
     def initUI(self):
         """
-        init_UI makes the basic initialisation of the GUI. is sets the window
+        init_UI makes the basic initialisation of the GUI. it sets the window
         flags and sets the handling of the window. is as well fixes the windows
-        size (unless a windows will be scalable later on. in addition the
+        size, unless a windows will be scalable later on. in addition, the
         appropriate style sheet for mac and non mac will be selected and used.
 
         :return:    true for test purpose
@@ -316,7 +303,8 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         self.setWindowIcon(QIcon(':/mw4.ico'))
         return True
 
-    def changeStyleDynamic(self, widget=None, widgetProperty=None, value=None):
+    @staticmethod
+    def changeStyleDynamic(widget=None, widgetProperty=None, value=None):
         """
         changeStyleDynamic changes the stylesheet of a given ui element and
         makes it visible. therefore the element has to be unpolished and
@@ -325,7 +313,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         :param      widget: widget element, where the stylesheet has to
                             be changed
         :param      widgetProperty: stylesheet attribute which has to be
-                                    changes
+                                    changed
         :param      value:  new value of the attribute
         :return:    true for test purpose
         """
@@ -338,12 +326,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         if widget.property(widgetProperty) == value:
             return True
 
-        if isinstance(widget, QPushButton):
-            if widgetProperty == 'running' and value:
-                self.changeIconColor(widget, self.M_BACK)
-            elif widgetProperty == 'running' and not value:
-                self.changeIconColor(widget, self.M_BLUE)
-
         widget.style().unpolish(widget)
         widget.setProperty(widgetProperty, value)
         widget.style().polish(widget)
@@ -388,7 +370,8 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         else:
             return nameList, shortList, extList
 
-    def prepareFileDialog(self, window=None, enableDir=False, reverseOrder=False):
+    def prepareFileDialog(self, window=None, enableDir=False,
+                          reverseOrder=False):
         """
         prepareFileDialog does some tweaking of the standard file dialogue
         widget for geometry and general settings. it also removes some parts and
@@ -437,11 +420,13 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         """
         return dlg.exec_()
 
-    def messageDialog(self, parentWidget, title, question):
+    def messageDialog(self, parentWidget, title, question, buttons=None, iconType=0):
         """
         :param parentWidget:
         :param title:
         :param question:
+        :param buttons:
+        :param iconType:
         :return: OK
         """
         msg = QMessageBox()
@@ -449,21 +434,31 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         msg.setStyleSheet(self.mw4Style)
         msg.setTextFormat(Qt.AutoText)
         msg.setWindowTitle(title)
-        pixmap = QPixmap(':/icon/question.svg').scaled(64, 64)
+        icons = [':/icon/question.svg', ':/icon/information.svg',
+                 ':/icon/warning.svg', ':/icon/question.svg']
+        pixmap = QPixmap(icons[iconType]).scaled(64, 64)
         msg.setIconPixmap(pixmap)
         msg.setText(question)
-        msg.setStandardButtons(msg.Yes | msg.No)
-        msg.setDefaultButton(msg.No)
+        if buttons is None:
+            msg.setStandardButtons(msg.Yes | msg.No)
+            msg.setDefaultButton(msg.No)
+        else:
+            for button in buttons:
+                msg.addButton(button, QMessageBox.AcceptRole)
+            msg.setDefaultButton(QMessageBox.Cancel)
         msg.show()
         x = parentWidget.x() + int((parentWidget.width() - msg.width()) / 2)
         y = parentWidget.y() + int((parentWidget.height() - msg.height()) / 2)
         msg.move(x, y)
         reply = self.runDialog(msg)
 
-        if reply != msg.Yes:
-            return False
+        if buttons is None:
+            if reply != msg.Yes:
+                return False
+            else:
+                return True
         else:
-            return True
+            return reply
 
     def openFile(self,
                  window=None,
@@ -474,7 +469,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
                  multiple=False,
                  reverseOrder=False):
         """
-        openFile handles a single file select with filter in a non native format.
+        openFile handles a single file select with filter in a non-native format.
 
         :param window:      parent window class
         :param title:       title for the file dialog
@@ -500,7 +495,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
                                      enableDir=enableDir,
                                      reverseOrder=reverseOrder)
         dlg.setAcceptMode(QFileDialog.AcceptOpen)
-
         dlg.setWindowTitle(title)
         dlg.setNameFilter(filterSet)
         dlg.setDirectory(folder)
@@ -525,7 +519,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
                  filterSet=None,
                  enableDir=False):
         """
-        saveFile handles a single file save with filter in a non native format.
+        saveFile handles a single file save with filter in a non-native format.
 
         :param window:      parent window class
         :param title:       title for the file dialog
@@ -690,42 +684,159 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         self.changeStyleDynamic(ui, pStyle, pVal)
         return True
 
-    @staticmethod
-    def returnDriver(sender, searchDict, addKey=''):
-        """
-        returnDriver takes the sender widget from a gui interaction and compares
-        is to the widget objects of a search dicts to retrieve is original name.
-        therefore we need to swap key value pais in the search dict as we make a
-        reverse search.
-        in addition to make it more usable the search dict might have some sub
-        dicts where to find the gui elements. if given, the will be extracted on
-        the forehand.
-
-        :param sender:
-        :param searchDict:
-        :param addKey:
-        :return:
-        """
-        if addKey:
-            searchD = dict([(key, value[addKey]) for key, value in searchDict.items()])
-        else:
-            searchD = searchDict
-
-        searchD = dict([(value, key) for key, value in searchD.items()])
-        driver = searchD.get(sender, '')
-        return driver
-
     def checkUpdaterOK(self):
         """
         :return:
         """
+        if platform.system() != 'Windows':
+            self.app.msg.emit(2, 'System', 'Automation',
+                              'Automation only on windows - upload not possible')
+            return ''
+
         if not self.app.automation:
-            self.app.message.emit('No automation enabled - upload not possible', 2)
+            self.app.msg.emit(2, 'System', 'Automation',
+                              'No automation enabled - upload not possible')
             return ''
 
         if not self.app.automation.installPath:
-            t = 'No 10micron updater available - upload not possible'
-            self.app.message.emit(t, 2)
+            self.app.msg.emit(2, 'System', 'Automation',
+                              'No 10micron updater available - upload not possible')
             return ''
 
         return self.app.automation.updaterApp
+
+    def convertTime(self, value, fString):
+        """
+        :return:
+        """
+        isUTC = self.ui.unitTimeUTC.isChecked()
+        if isUTC:
+            return value.utc_strftime(fString)
+        else:
+            return value.astimezone(tzlocal()).strftime(fString)
+
+    def timeZoneString(self):
+        """
+        :return:
+        """
+        if self.ui.unitTimeUTC.isChecked():
+            return '(time is UTC)'
+        else:
+            return '(time is local)'
+
+    def mwSuper(self, func):
+        """
+        mwSuper is a replacement for super() to manage the mixin style of
+        implementation it's not an ideal way to do it, but mwSuper() call the
+        method of every ! parent class if they exist.
+
+        :param func:
+        :return: true for test purpose
+        """
+        for base in self.__class__.__bases__:
+            if base.__name__ == "MWidget":
+                continue
+
+            if hasattr(base, func):
+                funcAttrib = getattr(base, func)
+                funcAttrib(self)
+        return True
+
+    @staticmethod
+    def makePointer():
+        """
+        :return:
+        """
+        path = QPainterPath()
+        path.moveTo(0, -1)
+        path.lineTo(0, 1)
+        path.moveTo(-1, 0)
+        path.lineTo(1, 0)
+        path.addEllipse(-0.1, -0.1, 0.2, 0.2)
+        path.addEllipse(-0.3, -0.3, 0.6, 0.6)
+        return path
+
+    @staticmethod
+    def makeSat():
+        """
+        :return:
+        """
+        path = QPainterPath()
+        tr = QTransform()
+        path.addRect(-0.35, -0.15, 0.1, 0.3)
+        path.addRect(-0.2, -0.15, 0.1, 0.3)
+        path.moveTo(-0.1, -0.15)
+        path.lineTo(-0.1, -0.15)
+        path.lineTo(0, 0)
+        path.lineTo(-0.1, 0.15)
+        path.lineTo(-0.1, 0.15)
+        tr.rotate(180)
+        path.addPath(tr.map(path))
+        tr.rotate(45)
+        path = tr.map(path)
+        path.addEllipse(-0.05, -0.05, 0.1, 0.1)
+        return path
+
+    def positionWindow(self, config):
+        """
+        :return:
+        """
+        height = config.get('height', 600)
+        width = config.get('width', 800)
+        self.resize(width, height)
+        x = config.get('winPosX', 0)
+        y = config.get('winPosY', 0)
+        if x > self.screenSizeX - width:
+            x = 0
+        if y > self.screenSizeY - height:
+            y = 0
+        x = max(x, 0)
+        y = max(y, 0)
+        if x != 0 and y != 0:
+            self.move(x, y)
+        return True
+
+    @staticmethod
+    def getTabIndex(tab, name):
+        """
+        :param tab:
+        :param name:
+        :return:
+        """
+        tabWidget = tab.findChild(QWidget, name)
+        tabIndex = tab.indexOf(tabWidget)
+        return tabIndex
+
+    @staticmethod
+    def getTabAndIndex(tab, config, name):
+        """
+        :param tab:
+        :param config:
+        :param name:
+        :return:
+        """
+        config[name] = {
+            'index': tab.currentIndex()
+        }
+        for index in range(tab.count()):
+            config[name][f'{index:02d}'] = tab.widget(index).objectName()
+        return True
+
+    def setTabAndIndex(self, tab, config, name):
+        """
+        :param tab:
+        :param config:
+        :param name:
+        :return:
+        """
+        config = config.get(name, {})
+        if not isinstance(config, dict):
+            config = {}
+        for index in reversed(range(tab.count())):
+            nameTab = config.get(f'{index:02d}', None)
+            if nameTab is None:
+                continue
+            tabIndex = self.getTabIndex(tab, nameTab)
+            tab.tabBar().moveTab(tabIndex, index)
+        tab.setCurrentIndex(config.get('index', 0))
+        return True
