@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -20,11 +20,11 @@ import logging
 # external packages
 import PyQt5
 from PyQt5.QtCore import pyqtSignal, QObject
-from PyQt5.QtNetwork import QTcpSocket, QAbstractSocket
+from PyQt5.QtNetwork import QTcpSocket
 import xml.etree.ElementTree as ETree
 
 # local import
-from indibase import indiXML
+from mw4.indibase import indiXML
 
 
 class INDISignals(QObject):
@@ -63,25 +63,12 @@ class INDISignals(QObject):
 
 class Device(object):
     """
-    Device implements an INDI Device. it rely on PyQt5 and it's signalling scheme.
+    Device implements an INDI Device. it relies on PyQt5 and it's signalling scheme.
     there might be not all capabilities implemented right now. all the data, properties
-    and attributes are stored in a the devices dict.
-
-        >>> indiDevice = Device(
-        >>>                     name=''
-        >>>                     )
-
+    and attributes are stored in a device dict.
     """
 
-    __all__ = ['Device',
-               'version',
-               'getNumber',
-               'getText',
-               'getSwitch',
-               'getLight',
-               'getBlob',
-               ]
-
+    __all__ = ['Device']
     log = logging.getLogger(__name__)
 
     def __init__(self, name=''):
@@ -212,44 +199,14 @@ class Device(object):
 
 class Client(QObject):
     """
-    Client implements an INDI Base Client for INDI servers. it rely on PyQt5 and it's
-    signalling scheme. there might be not all capabilities implemented right now. all
-    the data, properties and attributes are stored in a the devices dict.
-    The reading and parsing of the XML data is done in a streaming way, so for xml the
-    xml.parse.feed() mechanism is used.
-
-        >>> indiClient = Client(
-        >>>                     host=host
-        >>>                     )
-
+    Client implements an INDI Base Client for INDI servers. it relies on PyQt5
+    and it's signalling scheme. there might be not all capabilities implemented
+    right now. all the data, properties and attributes are stored in a device
+    dict. The reading and parsing of the XML data is done in a streaming way,
+    so for xml the xml.parse.feed() mechanism is used.
     """
 
-    __all__ = ['Client',
-               'version',
-               'setServer',
-               'watchDevice',
-               'connectServer',
-               'disconnectServer',
-               'isServerConnected',
-               'connectDevice',
-               'disconnectDevice',
-               'getDevice',
-               'getDevices',
-               'setBlobMode',
-               'getBlobMode',
-               'getHost',
-               'getPort',
-               'sendNewText',
-               'sendNewNumber',
-               'sendNewSwitch',
-               'startBlob',
-               'sendOneBlob',
-               'finishBlob',
-               'setVerbose',
-               'isVerbose',
-               'setConnectionTimeout',
-               ]
-
+    __all__ = ['Client']
     log = logging.getLogger(__name__)
 
     GENERAL_INTERFACE = 0
@@ -268,11 +225,9 @@ class Client(QObject):
     AUX_INTERFACE = (1 << 15)
 
     DEFAULT_PORT = 7624
-    CONNECTION_TIMEOUT = 3000
+    CONNECTION_TIMEOUT = 1000
 
-    def __init__(self,
-                 host=None,
-                 ):
+    def __init__(self, host=None):
         super().__init__()
 
         self.host = host
@@ -283,9 +238,10 @@ class Client(QObject):
         self.curDepth = 0
         self.parser = None
         self.socket = QTcpSocket()
-        self.socket.readyRead.connect(self._handleReadyRead)
-        self.socket.error.connect(self._handleError)
+        self.socket.readyRead.connect(self.handleReadyRead)
+        self.socket.errorOccurred.connect(self.handleError)
         self.socket.disconnected.connect(self.handleDisconnected)
+        self.socket.connected.connect(self.handleConnected)
         self.clearParser()
 
     @property
@@ -369,17 +325,14 @@ class Client(QObject):
         """
         if self._host is None:
             return False
-
         if self.connected:
-            return True
-
-        self.socket.connectToHost(*self._host)
-        if not self.socket.waitForConnected(self.CONNECTION_TIMEOUT):
-            self.connected = False
             return False
 
-        self.connected = True
-        self.signals.serverConnected.emit()
+        self.connected = False
+        if self.socket.state() != QTcpSocket.UnconnectedState:
+            self.socket.abort()
+
+        self.socket.connectToHost(*self._host)
         return True
 
     def clearDevices(self, deviceName=''):
@@ -394,6 +347,7 @@ class Client(QObject):
             if not device == deviceName and deviceName:
                 continue
 
+            self.signals.deviceDisconnected.emit(device)
             self.signals.removeDevice.emit(device)
             self.log.info(f'Remove device [{device}]')
 
@@ -410,20 +364,11 @@ class Client(QObject):
         """
         self.connected = False
         self.clearParser()
-        self.signals.serverDisconnected.emit(self.devices)
         self.clearDevices(deviceName)
+        self.signals.serverDisconnected.emit(self.devices)
         self.socket.abort()
         return True
 
-    @PyQt5.QtCore.pyqtSlot()
-    def handleDisconnected(self):
-        """
-        :return: nothing
-        """
-        self.connected = False
-        self.log.info('INDI client disconnected')
-        return True
-
     def isServerConnected(self):
         """
         Part of BASE CLIENT API of EKOS
@@ -581,10 +526,8 @@ class Client(QObject):
         """
         if deviceName not in self.devices:
             return False
-
-        if not hasattr(self.devices[deviceName], propertyName):
-            return False
-
+        # if not hasattr(self.devices[deviceName], propertyName):
+        #     return False
         if not isinstance(elements, dict):
             elements = {elements: text}
 
@@ -614,10 +557,8 @@ class Client(QObject):
         """
         if deviceName not in self.devices:
             return False
-
-        if not hasattr(self.devices[deviceName], propertyName):
-            return False
-
+        # if not hasattr(self.devices[deviceName], propertyName):
+        #     return False
         if not isinstance(elements, dict):
             elements = {elements: number}
 
@@ -646,10 +587,8 @@ class Client(QObject):
         """
         if deviceName not in self.devices:
             return False
-
-        if not hasattr(self.devices[deviceName], propertyName):
-            return False
-
+        # if not hasattr(self.devices[deviceName], propertyName):
+        #     return False
         if not isinstance(elements, dict):
             elements = {elements: 'On'}
 
@@ -852,6 +791,10 @@ class Client(QObject):
             return False
 
         iProperty = chunk.attr['name']
+
+        self.log.trace(f'DEL: Device:{device.name}, '
+                       f'Property: {iProperty}')
+
         if hasattr(device, iProperty):
             delattr(device, iProperty)
             self.signals.removeProperty.emit(deviceName, iProperty)
@@ -876,6 +819,10 @@ class Client(QObject):
                              elementList=elementList,
                              defVector=False)
 
+        self.log.trace(f'SET: Device:{device.name}, '
+                       f'Property: {iProperty}, '
+                       f'Elements: {elementList}')
+
         if isinstance(chunk, indiXML.SetBLOBVector):
             self.signals.newBLOB.emit(deviceName, iProperty)
         elif isinstance(chunk, indiXML.SetSwitchVector):
@@ -905,7 +852,9 @@ class Client(QObject):
                              chunk=chunk,
                              elementList=elementList,
                              defVector=True)
-
+        self.log.trace(f'DEF: Device:{device.name}, '
+                       f'Property: {iProperty}, '
+                       f'Elements: {elementList}')
         self.signals.newProperty.emit(deviceName, iProperty)
         if isinstance(chunk, indiXML.DefBLOBVector):
             self.signals.defBLOB.emit(deviceName, iProperty)
@@ -919,16 +868,14 @@ class Client(QObject):
             self.signals.defLight.emit(deviceName, iProperty)
         return True
 
-    @staticmethod
-    def _getProperty(chunk=None, device=None, deviceName=None):
+    def _getProperty(self, chunk=None, device=None, deviceName=None):
         """
         :param chunk:   xml element from INDI
         :param device:  device class
         :param deviceName: device name
         :return: success
         """
-        # todo: there is actually no implementation for this type. check if it
-        #  is relevant get property is for snooping other devices
+        self.log.trace(f'GET: Device:{device.name}')
         return True
 
     def _message(self, chunk=None, deviceName=None):
@@ -950,7 +897,6 @@ class Client(QObject):
         :param chunk: raw indi XML element
         :return: success if it could be parsed
         """
-        self.log.trace(f'ReceiveCommand: [{chunk}]')
         if not self.connected:
             return False
 
@@ -1019,8 +965,7 @@ class Client(QObject):
         self.log.error(f'Unknown vectors: [{chunk}]')
         return False
 
-    @PyQt5.QtCore.pyqtSlot()
-    def _handleReadyRead(self):
+    def handleReadyRead(self):
         """
         _handleReadyRead gets the date in buffer signal and starts to read data
         from the network. as long as data is streaming, it feeds to the xml
@@ -1059,15 +1004,29 @@ class Client(QObject):
 
         return True
 
-    @PyQt5.QtCore.pyqtSlot(QAbstractSocket.SocketError)
-    def _handleError(self, socketError):
+    def handleConnected(self):
+        """
+        :return:
+        """
+        self.connected = True
+        self.signals.serverConnected.emit()
+        return True
+
+    def handleDisconnected(self):
+        """
+        :return: nothing
+        """
+        self.connected = False
+        self.signals.serverDisconnected.emit(self.devices)
+        self.log.info('INDI client disconnected')
+        return True
+
+    def handleError(self, socketError):
         """
         :param socketError: the error from socket library
         :return: nothing
         """
-        if not self.connected:
-            return False
-
-        self.log.error(f'INDI connection fault, error: [{socketError}]')
+        if socketError != QTcpSocket.UnknownSocketError:
+            self.log.error(f'INDI error: [{socketError}]')
         self.disconnectServer()
         return True
