@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -26,34 +25,32 @@ import socket
 import sys
 import traceback
 import warnings
-#
+
 # the following lines should avoid errors messages from OLE Automation with PyQt5
 # see
 # https://stackoverflow.com/questions/51284268/
 #         windowscontext-oleinitialize-failed-com-error-0x80010106-rpc-e-changed-mode
 # and https://github.com/pywinauto/pywinauto/issues/472
 # order is important to set sys.coinit_flags = 2 before import pywinauto
-#
-warnings.simplefilter('ignore', UserWarning)
+warnings.filterwarnings('ignore', category=Warning, append=True)
 sys.coinit_flags = 2
 
 # external packages
 import astropy
-import matplotlib
 from PyQt5.QtCore import QFile, QEvent, Qt, QObject, PYQT_VERSION_STR, QT_VERSION_STR
 from PyQt5.QtGui import QMouseEvent, QIcon
 from PyQt5.QtWidgets import QRadioButton, QGroupBox, QCheckBox, QLineEdit
 from PyQt5.QtWidgets import QWidget, QApplication, QTabBar, QComboBox, QPushButton
+import pyqtgraph as pg
 from importlib_metadata import version
 
 # local import
-from base.loggerMW import setupLogging
+from mw4.base.loggerMW import setupLogging
 setupLogging()
-from gui.utilities.splashScreen import SplashScreen
-from mainApp import MountWizzard4
-import resource.resources as res
+from mw4.gui.utilities.splashScreen import SplashScreen
+from mw4.mainApp import MountWizzard4
+import mw4.resource.resources as res
 res.qInitResources()
-matplotlib.use('Qt5Agg')
 astropy.utils.iers.conf.auto_download = False
 astropy.utils.data.conf.allow_internet = False
 log = logging.getLogger()
@@ -108,7 +105,10 @@ class QAwesomeTooltipEventFilter(QObject):
         """
         Tooltip-specific event filter handling the passed Qt object and event.
         """
-        if event.type() == QEvent.ToolTipChange:
+        if event.type() in [QEvent.ToolTipChange, QEvent.ToolTip]:
+            if isinstance(widget, pg.ViewBox):
+                return True
+
             if not isinstance(widget, QWidget):
                 self.log.warning('QObject "{}" not a widget.'.format(widget))
                 return False
@@ -124,18 +124,6 @@ class QAwesomeTooltipEventFilter(QObject):
                 widget.setToolTip(tooltip)
 
                 return True
-
-        elif event.type() == QEvent.ToolTip:
-            if not isinstance(widget, QWidget):
-                self.log.warning('QObject "{}" not a widget.'.format(widget))
-                return False
-
-            tooltip = widget.toolTip()
-
-            if tooltip == '<html><head/><body><p><br/></p></body></html>':
-                widget.setToolTip(None)
-                return True
-
         return super().eventFilter(widget, event)
 
 
@@ -255,12 +243,12 @@ def setupWorkDirs(mwGlob):
     """
     mwGlob['modeldata'] = '4.0'
     mwGlob['workDir'] = os.getcwd()
-    mwGlob['configDir'] = mwGlob['workDir'] + '/config'
-    mwGlob['dataDir'] = mwGlob['workDir'] + '/data'
-    mwGlob['imageDir'] = mwGlob['workDir'] + '/image'
-    mwGlob['tempDir'] = mwGlob['workDir'] + '/temp'
-    mwGlob['modelDir'] = mwGlob['workDir'] + '/model'
-    mwGlob['measureDir'] = mwGlob['workDir'] + '/measure'
+    mwGlob['configDir'] = os.path.normpath(mwGlob['workDir'] + '/config')
+    mwGlob['dataDir'] = os.path.normpath(mwGlob['workDir'] + '/data')
+    mwGlob['imageDir'] = os.path.normpath(mwGlob['workDir'] + '/image')
+    mwGlob['tempDir'] = os.path.normpath(mwGlob['workDir'] + '/temp')
+    mwGlob['modelDir'] = os.path.normpath(mwGlob['workDir'] + '/model')
+    mwGlob['measureDir'] = os.path.normpath(mwGlob['workDir'] + '/measure')
 
     for dirPath in ['workDir', 'configDir', 'imageDir', 'dataDir',
                     'tempDir', 'modelDir', 'measureDir']:
@@ -360,12 +348,13 @@ def extractDataFiles(mwGlob=None, splashW=None):
         return False
 
     files = {
-        'de421_23.bsp': 0,
+        'de440_mw4.bsp': 0,
         'visual.txt': 0,
         'CDFLeapSeconds.txt': 0,
         'tai-utc.dat': 0,
         'finals2000A.all': 0,
         'finals.data': 0,
+        'mountwizzard4.pdf': 0,
     }
 
     content = QFile(':/data/content.txt')
@@ -391,7 +380,7 @@ def getWindowPos():
     :return:
     """
     configDir = os.getcwd() + '/config'
-    profile = configDir + '/profile'
+    profile = os.path.normpath(configDir + '/profile')
     if not os.path.isfile(profile):
         return 0, 0
 
@@ -399,6 +388,7 @@ def getWindowPos():
         configName = f.readline()
 
     configFile = configDir + '/' + configName + '.cfg'
+    configFile = os.path.normpath(configFile)
     if not os.path.isfile(configFile):
         return 0, 0
 
@@ -413,15 +403,6 @@ def getWindowPos():
             return x, y
 
 
-def minimizeStartTerminal():
-    """
-    :return:
-    """
-    if platform.system() == 'Windows':
-        import ctypes
-        ctypes.windll.user32.ShowWindow(ctypes.windll.kernel32.GetConsoleWindow(), 6)
-
-
 def main():
     """
     main prepares the loading of mountwizzard application. it prepares a
@@ -435,8 +416,6 @@ def main():
     app = MyApp(sys.argv)
     # app = QApplication(sys.argv)
 
-    minimizeStartTerminal()
-
     x, y = getWindowPos()
     splashW = SplashScreen(application=app, x=x, y=y)
     splashW.showMessage('Start initialising')
