@@ -19,8 +19,8 @@
 # external packages
 
 # local imports
-from base.ascomClass import AscomClass
-from logic.camera.cameraSupport import CameraSupport
+from mw4.base.ascomClass import AscomClass
+from mw4.logic.camera.cameraSupport import CameraSupport
 
 
 class CameraAscom(AscomClass, CameraSupport):
@@ -127,7 +127,7 @@ class CameraAscom(AscomClass, CameraSupport):
         self.setAscomProperty('NumY', int(height / binning))
 
         self.client.StartExposure(expTime, True)
-        self.waitExposed(self.getAscomProperty, 'ImageReady', expTime)
+        self.waitExposedAscom(expTime)
         self.signals.exposed.emit()
         data = self.retrieveFits(self.getAscomProperty, 'ImageArray')
         self.signals.downloaded.emit()
