@@ -19,9 +19,10 @@
 # external packages
 
 # local imports
-from base.ninaClass import NINAClass
-from base.tpool import Worker
-from logic.camera.cameraSupport import CameraSupport
+from mw4.base.ninaClass import NINAClass
+from mw4.base.tpool import Worker
+from mw4.logic.camera.cameraSupport import CameraSupport
+from mw4.gui.utilities.toolsQtWidget import sleepAndEvents
 
 
 class CameraNINA(NINAClass, CameraSupport):
@@ -204,10 +205,12 @@ class CameraNINA(NINAClass, CameraSupport):
 
         suc, response = self.captureImage(params=params)
         if not suc:
+            self.log.debug(f'No capture image. {response}')
             return False
 
         receipt = response.get('Receipt', '')
         if not receipt:
+            self.log.debug(f'No receipt received. {response}')
             return False
 
         self.waitStart()
@@ -219,6 +222,9 @@ class CameraNINA(NINAClass, CameraSupport):
 
         if self.abortExpose:
             imagePath = ''
+        else:
+            sleepAndEvents(500)
+            self.updateFits(imagePath)
 
         self.signals.saved.emit(imagePath)
         self.signals.exposeReady.emit()
@@ -242,6 +248,7 @@ class CameraNINA(NINAClass, CameraSupport):
         :return: success
         """
         if not self.deviceConnected:
+            self.log.warning('No camera connected')
             return False
         self.raJ2000 = ra
         self.decJ2000 = dec
