@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -21,9 +20,10 @@ import os
 # external packages
 
 # local imports
-from base.sgproClass import SGProClass
-from base.tpool import Worker
-from logic.camera.cameraSupport import CameraSupport
+from mw4.base.sgproClass import SGProClass
+from mw4.base.tpool import Worker
+from mw4.logic.camera.cameraSupport import CameraSupport
+from mw4.gui.utilities.toolsQtWidget import sleepAndEvents
 
 
 class CameraSGPro(SGProClass, CameraSupport):
@@ -34,9 +34,10 @@ class CameraSGPro(SGProClass, CameraSupport):
     __all__ = ['CameraSGPro']
 
     def __init__(self, app=None, signals=None, data=None, parent=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
+        super().__init__(app=app, data=data)
         self.signals = signals
         self.data = data
+        self.threadPool = app.threadPool
         self.abortExpose = False
         self.parent = parent
 
@@ -49,7 +50,7 @@ class CameraSGPro(SGProClass, CameraSupport):
         if response is None:
             return False, {}
 
-        return response['Success'], response
+        return response.get('Success', ''), response
 
     def sgSetCameraTemp(self, temperature):
         """
@@ -61,7 +62,7 @@ class CameraSGPro(SGProClass, CameraSupport):
         if response is None:
             return False
 
-        return response['Success']
+        return response.get('Success', '')
 
     def sgCaptureImage(self, params):
         """
@@ -72,7 +73,7 @@ class CameraSGPro(SGProClass, CameraSupport):
         if response is None:
             return False, {}
 
-        return response['Success'], response
+        return response.get('Success', ''), response
 
     def sgAbortImage(self):
         """
@@ -82,7 +83,7 @@ class CameraSGPro(SGProClass, CameraSupport):
         if response is None:
             return False
 
-        return response['Success']
+        return response.get('Success', '')
 
     def sgGetImagePath(self, receipt):
         """
@@ -94,7 +95,7 @@ class CameraSGPro(SGProClass, CameraSupport):
         if response is None:
             return False
 
-        return response['Success']
+        return response.get('Success', '')
 
     def sgGetCameraProps(self):
         """
@@ -104,7 +105,7 @@ class CameraSGPro(SGProClass, CameraSupport):
         if response is None:
             return False, {}
 
-        return response['Success'], response
+        return response.get('Success', ''), response
 
     def workerGetInitialConfig(self):
         """
@@ -115,6 +116,7 @@ class CameraSGPro(SGProClass, CameraSupport):
             return False
         suc, response = self.sgGetCameraProps()
         if not suc:
+            self.log.debug('No camera props received')
             return False
 
         self.storePropertyToData(response['Message'],
@@ -205,18 +207,29 @@ class CameraSGPro(SGProClass, CameraSupport):
 
         suc, response = self.sgCaptureImage(params=params)
         if not suc:
+            self.log.debug(f'No capture image. {response}')
             return False
 
         receipt = response.get('Receipt', '')
         if not receipt:
+            self.log.debug(f'No receipt received. {response}')
             return False
 
-        self.waitCombinedSGPro(self.sgGetImagePath, receipt, expTime)
-        if not self.abortExpose:
+        self.waitStart()
+        self.waitExposedApp(expTime)
+        self.signals.exposed.emit()
+        self.waitDownload()
+        self.signals.downloaded.emit()
+        self.waitSave()
+        self.waitFinish(self.sgGetImagePath, receipt)
+
+        if self.abortExpose:
+            imagePath = ''
+        else:
             pre, ext = os.path.splitext(imagePath)
             os.rename(pre + '.fit', imagePath)
-        else:
-            imagePath = ''
+            sleepAndEvents(500)
+            self.updateFits(imagePath)
 
         self.signals.saved.emit(imagePath)
         self.signals.exposeReady.emit()
@@ -240,6 +253,7 @@ class CameraSGPro(SGProClass, CameraSupport):
         :return: success
         """
         if not self.deviceConnected:
+            self.log.warning('No camera connected')
             return False
         self.raJ2000 = ra
         self.decJ2000 = dec
