@@ -10,21 +10,21 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
 # standard libraries
 import logging
+import os
 
 # external packages
 from astropy.io import fits
 import numpy as np
 
 # local imports
-from gui.utilities.toolsQtWidget import sleepAndEvents
-from mountcontrol.convert import formatDstrToText
+from mw4.gui.utilities.toolsQtWidget import sleepAndEvents
+from mw4.mountcontrol.convert import formatDstrToText
 
 
 class CameraSupport:
@@ -35,49 +35,94 @@ class CameraSupport:
     raJ2000 = None
     decJ2000 = None
 
-    def writeHeaderInfo(self, header, obs, expTime, binning, focalLength):
+    @staticmethod
+    def writeHeaderBasic(header):
         """
         :param header:
-        :param obs:
-        :param expTime:
-        :param binning:
-        :param focalLength:
         :return:
         """
         header.append(('OBJECT', 'SKY_OBJECT', 'default name from MW4'))
+        header.append(('AUTHOR', 'MountWizzard4', 'default name from MW4'))
         header.append(('FRAME', 'Light', 'Modeling works with light frames'))
         header.append(('EQUINOX', 2000, 'All data is stored in J2000'))
+        header.append(('OBSERVER', 'MW4'))
+        return True
+
+    def writeHeaderCamera(self, header, expTime, binning):
+        """
+        :param header:
+        :param expTime:
+        :param binning:
+        :return:
+        """
         header.append(('PIXSIZE1', self.data['CCD_INFO.CCD_PIXEL_SIZE_X'] * binning))
         header.append(('PIXSIZE2', self.data['CCD_INFO.CCD_PIXEL_SIZE_Y'] * binning))
         header.append(('XPIXSZ', self.data['CCD_INFO.CCD_PIXEL_SIZE_X'] * binning))
         header.append(('YPIXSZ', self.data['CCD_INFO.CCD_PIXEL_SIZE_Y'] * binning))
-
-        if focalLength:
-            factor = binning / focalLength * 206.265
-            header.append(('FOCALLEN', focalLength,
-                           'Data taken from driver or manual input'))
-        else:
-            factor = 1
-
-        header.append(('SCALE', self.data['CCD_INFO.CCD_PIXEL_SIZE_X'] * factor))
         header.append(('XBINNING', binning, 'MW4 same binning x/y'))
         header.append(('YBINNING', binning, 'MW4 same binning x/y'))
         header.append(('EXPTIME', expTime))
         header.append(('OBSERVER', 'MW4'))
-        timeJD = obs.timeJD
-        header.append(('DATE-OBS', timeJD.tt_strftime('%Y-%m-%dT%H:%M:%S'),
-                       'Time is UTC of mount'))
-        header.append(('MJD-OBS', timeJD.tt - 2400000.5, 'Time is UTC of mount'))
         header.append(('CCD-TEMP',
                        self.data.get('CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE', 0)))
         header.append(('SQM',
                        self.app.skymeter.data.get('SKY_QUALITY.SKY_BRIGHTNESS', 0)))
+        header.append(('FOCPOS',
+                       self.app.focuser.data.get(
+                           'ABS_FOCUS_POSITION.FOCUS_ABSOLUTE_POSITION', 0)))
+        header.append(('FOCTEMP',
+                       self.app.directWeather.data.get(
+                           'WEATHER_PARAMETERS.WEATHER_TEMPERATURE', 0)))
 
+        filterNumber = self.app.filter.data.get('FILTER_SLOT.FILTER_SLOT_VALUE', 1)
+        key = f'FILTER_NAME.FILTER_SLOT_NAME_{filterNumber:1.0f}'
+        filterName = self.app.filter.data.get(key, 'not found')
+        header.append(('FILTER', filterName))
+        return True
+
+    @staticmethod
+    def writeHeaderTime(header, obs):
+        """
+        :param header:
+        :param obs:
+        :return:
+        """
+        timeJD = obs.timeJD
+        header.append(('DATE-OBS', timeJD.tt_strftime('%Y-%m-%dT%H:%M:%S'),
+                       'Time is UTC of mount at end of exposure'))
+        header.append(('MJD-OBS', timeJD.tt - 2400000.5,
+                       'Time is UTC of mount at end of exposure'))
+        return True
+
+    def writeHeaderOptical(self, header, binning, focalLength):
+        """
+        :param header:
+        :param binning:
+        :param focalLength:
+        :return:
+        """
+        if not focalLength:
+            return False
+
+        factor = binning / focalLength * 206.265
+        header.append(('FOCALLEN',
+                       focalLength, 'Data taken from driver or manual input'))
+        header.append(('SCALE',
+                       self.data['CCD_INFO.CCD_PIXEL_SIZE_X'] * factor))
+        return True
+
+    def writeHeaderCoordSite(self, header, obs):
+        """
+        :param header:
+        :param obs:
+        :return:
+        """
         hasCoordinate = self.raJ2000 is not None and self.decJ2000 is not None
-        isMount = obs.location is not None
         if hasCoordinate:
             header.append(('RA', self.raJ2000._degrees, 'Float value in degree'))
             header.append(('DEC', self.decJ2000.degrees, 'Float value in degree'))
+
+        isMount = obs.location is not None
         if isMount:
             header.append(('TELESCOP', self.app.mount.firmware.product,
                            'Mount version from firmware'))
@@ -87,8 +132,35 @@ class CameraSupport:
             header.append(('SITELON', formatDstrToText(lon)))
             elev = obs.location.elevation.m
             header.append(('SITEELEV', elev))
+        return True
 
-        return header
+    @staticmethod
+    def writeHeaderFocus(header, focuser):
+        """
+        :param header:
+        :param focuser:
+        :return:
+        """
+        pos = focuser.data.get('ABS_FOCUS_POSITION.FOCUS_ABSOLUTE_POSITION', 0)
+        header.append(('FOCUSPOS', pos, 'Actual focuser position'))
+        return True
+
+    def updateFits(self, imagePath):
+        """
+        :param imagePath:
+        :return:
+        """
+        hasCoordinate = self.raJ2000 is not None and self.decJ2000 is not None
+        if not os.path.isfile(imagePath):
+            self.log.debug(f'{imagePath}, {self.raJ2000}, {self.decJ2000}')
+            return False
+
+        with fits.open(imagePath, 'update', output_verify='silentfix+warn') as hdu:
+            header = hdu[0].header
+            if hasCoordinate:
+                header.append(('RA', self.raJ2000._degrees, 'Float value in degree'))
+                header.append(('DEC', self.decJ2000.degrees, 'Float value in degree'))
+        return True
 
     def saveFits(self, imagePath, data, expTime, binning, focalLength):
         """
@@ -103,11 +175,14 @@ class CameraSupport:
             return ''
 
         self.signals.message.emit('saving')
-        self.signals.downloaded.emit()
         hdu = fits.PrimaryHDU(data=data)
         obs = self.app.mount.obsSite
-        hdu.header = self.writeHeaderInfo(hdu.header, obs, expTime,
-                                          binning, focalLength)
+        self.writeHeaderBasic(hdu.header)
+        self.writeHeaderCamera(hdu.header, expTime, binning)
+        self.writeHeaderTime(hdu.header, obs)
+        self.writeHeaderOptical(hdu.header, binning, focalLength)
+        self.writeHeaderCoordSite(hdu.header, obs)
+        self.writeHeaderFocus(hdu.header, self.app.focuser)
         hdu.writeto(imagePath, overwrite=True, output_verify='silentfix+warn')
         self.log.info(f'Saved Image: [{imagePath}]')
         return imagePath
@@ -121,7 +196,6 @@ class CameraSupport:
         if self.abortExpose:
             return np.array([], dtype=np.uint16)
 
-        self.signals.exposed.emit()
         self.signals.message.emit('download')
         tmp = function(param)
         if tmp is None:
@@ -131,17 +205,37 @@ class CameraSupport:
             data = np.array(tmp, dtype=np.uint16).transpose()
         return data
 
-    def waitExposed(self, function, param, expTime):
+    def waitExposedAscom(self, expTime):
         """
-        :param function:
-        :param param:
         :param expTime:
         :return:
         """
         timeLeft = expTime
-        while not function(param):
+        while True:
             if self.abortExpose:
                 break
+            if self.getAscomProperty('ImageReady'):
+                break
+            text = f'expose {timeLeft:3.0f} s'
+            sleepAndEvents(100)
+            self.signals.message.emit(text)
+            if timeLeft >= 0.1:
+                timeLeft -= 0.1
+            else:
+                timeLeft = 0
+        return True
+
+    def waitExposedAlpaca(self, expTime):
+        """
+        :param expTime:
+        :return:
+        """
+        timeLeft = expTime
+        while True:
+            if self.abortExpose:
+                break
+            if self.getAlpacaProperty('imageready'):
+                break
             text = f'expose {timeLeft:3.0f} s'
             sleepAndEvents(100)
             self.signals.message.emit(text)
@@ -161,7 +255,7 @@ class CameraSupport:
             sleepAndEvents(100)
         return True
 
-    def waitIntegrate(self, timeLeft):
+    def waitExposedApp(self, timeLeft):
         """
         :param timeLeft:
         :return:
@@ -169,14 +263,13 @@ class CameraSupport:
         while 'integrating' in self.data.get('Device.Message'):
             if self.abortExpose:
                 break
-            text = f'expose {timeLeft:3.0f} s'
             sleepAndEvents(100)
+            text = f'expose {timeLeft:3.0f} s'
             self.signals.message.emit(text)
             if timeLeft >= 0.1:
                 timeLeft -= 0.1
             else:
                 timeLeft = 0
-        self.signals.exposed.emit()
         return True
 
     def waitDownload(self):
@@ -188,7 +281,6 @@ class CameraSupport:
             if self.abortExpose:
                 break
             sleepAndEvents(100)
-        self.signals.downloaded.emit()
         return True
 
     def waitSave(self):
@@ -213,30 +305,3 @@ class CameraSupport:
                 break
             sleepAndEvents(100)
         return True
-
-    def waitCombinedSGPro(self, function, param, expTime):
-        """
-        :param function:
-        :param param:
-        :param expTime:
-        :return:
-        """
-        timeLeft = expTime
-        self.waitStart()
-        self.waitIntegrate(timeLeft)
-        self.waitDownload()
-        self.waitSave()
-        self.waitFinish(function, param)
-        return True
-
-    def waitCombinedNINA(self, expTime):
-        """
-        :param expTime:
-        :return:
-        """
-        timeLeft = expTime
-        self.waitStart()
-        self.waitIntegrate(timeLeft)
-        self.waitDownload()
-        self.waitSave()
-        return True
