@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -45,26 +44,27 @@ class DataWriter:
         :param updaterApp:
         :return:
         """
-        sourceDir = self.app.mwGlob['dataDir'] + '/'
-        destDir = installPath + '/'
+        sourceDir = self.app.mwGlob['dataDir']
+        destDir = installPath
+
         if destDir == sourceDir:
             return False
-
-        if not os.path.isfile(sourceDir + 'CDFLeapSeconds.txt'):
+        if not os.path.isfile(sourceDir + '/CDFLeapSeconds.txt'):
+            return False
+        if not os.path.isfile(sourceDir + '/finals.data'):
+            return False
+        if not os.path.isfile(sourceDir + '/tai-utc.dat'):
             return False
 
-        if not os.path.isfile(sourceDir + 'finals.data'):
-            return False
-
-        if not os.path.isfile(sourceDir + 'tai-utc.dat'):
-            return False
-
-        if updaterApp == 'tenmicron_v2.exe':
-            shutil.copy(sourceDir + 'CDFLeapSeconds.txt', destDir + 'CDFLeapSeconds.txt')
+        if os.path.basename(updaterApp) == 'tenmicron_v2.exe':
+            shutil.copy(os.path.normpath(sourceDir + '/CDFLeapSeconds.txt'),
+                        os.path.normpath(destDir + '/CDFLeapSeconds.txt'))
         else:
-            shutil.copy(sourceDir + 'tai-utc.dat', destDir + 'tai-utc.dat')
+            shutil.copy(os.path.normpath(sourceDir + '/tai-utc.dat'),
+                        os.path.normpath(destDir + '/tai-utc.dat'))
 
-        shutil.copy(sourceDir + 'finals.data', destDir + 'finals.data')
+        shutil.copy(os.path.normpath(sourceDir + '/finals.data'),
+                    os.path.normpath(destDir + '/finals.data'))
         return True
 
     @staticmethod
@@ -83,7 +83,7 @@ class DataWriter:
         if not isinstance(datas, list):
             return False
 
-        dest = installPath + '/minorPlanets.mpc'
+        dest = os.path.normpath(installPath + '/minorPlanets.mpc')
 
         with open(dest, 'w') as f:
             for data in datas:
@@ -279,7 +279,7 @@ class DataWriter:
         if not isinstance(datas, list):
             return False
 
-        dest = installPath + '/minorPlanets.mpc'
+        dest = os.path.normpath(installPath + '/minorPlanets.mpc')
 
         with open(dest, 'w') as f:
             for data in datas:
@@ -380,7 +380,7 @@ class DataWriter:
         if not isinstance(datas, dict):
             return False
 
-        dest = installPath + '/satellites.tle'
+        dest = os.path.normpath(installPath + '/satellites.tle')
 
         with open(dest, 'w') as f:
             for name in datas:
