@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -20,7 +19,7 @@
 # external packages
 
 # local imports
-from base.alpacaClass import AlpacaClass
+from mw4.base.alpacaClass import AlpacaClass
 
 
 class DomeAlpaca(AlpacaClass):
@@ -30,10 +29,8 @@ class DomeAlpaca(AlpacaClass):
     __all__ = ['DomeAlpaca']
 
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-
+        super().__init__(app=app, data=data)
         self.signals = signals
-        self.data = data
 
     def workerGetInitialConfig(self):
         """
@@ -126,6 +123,22 @@ class DomeAlpaca(AlpacaClass):
             self.getAlpacaProperty('closeshutter')
         return True
 
+    def slewCW(self):
+        """
+        :return: success
+        """
+        if not self.deviceConnected:
+            return False
+        return True
+
+    def slewCCW(self):
+        """
+        :return: success
+        """
+        if not self.deviceConnected:
+            return False
+        return True
+
     def abortSlew(self):
         """
         :return: success
