@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -20,7 +19,7 @@
 # external packages
 
 # local imports
-from base.ascomClass import AscomClass
+from mw4.base.ascomClass import AscomClass
 
 
 class DomeAscom(AscomClass):
@@ -32,10 +31,8 @@ class DomeAscom(AscomClass):
     shutterStates = ['Open', 'Closed', 'Opening', 'Closing', 'Error']
 
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-
+        super().__init__(app=app, data=data)
         self.signals = signals
-        self.data = data
 
     def workerGetInitialConfig(self):
         """
@@ -118,12 +115,28 @@ class DomeAscom(AscomClass):
         self.callMethodThreaded(self.client.CloseShutter)
         return True
 
-    def abortSlew(self):
+    def slewCW(self):
         """
         :return: success
         """
         if not self.deviceConnected:
             return False
 
-        self.callMethodThreaded(self.client.AbortSlew)
+        self.callMethodThreaded(self.client.OpenShutter)
+        return True
+
+    def slewCCW(self):
+        """
+        :return: success
+        """
+        if not self.deviceConnected:
+            return False
+        return True
+
+    def abortSlew(self):
+        """
+        :return: success
+        """
+        if not self.deviceConnected:
+            return False
         return True
