@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -20,7 +19,7 @@
 # external packages
 
 # local imports
-from base.indiClass import IndiClass
+from mw4.base.indiClass import IndiClass
 
 
 class DomeIndi(IndiClass):
@@ -31,36 +30,10 @@ class DomeIndi(IndiClass):
 
     def __init__(self, app=None, signals=None, data=None):
         self.signals = signals
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-        self.data = data
+        super().__init__(app=app, data=data)
         self.lastAzimuth = None
-
         self.app.update1s.connect(self.updateStatus)
 
-    def setUpdateConfig(self, deviceName):
-        """
-        setUpdateRate corrects the update rate of dome devices to get an
-        defined setting regardless, what is setup in server side.
-
-        :param deviceName:
-        :return: success
-        """
-        if deviceName != self.deviceName:
-            return False
-        if self.device is None:
-            return False
-
-        update = self.device.getNumber('POLLING_PERIOD')
-        if update.get('PERIOD_MS', 0) == self.UPDATE_RATE:
-            return True
-
-        update['PERIOD_MS'] = self.UPDATE_RATE
-        suc = self.client.sendNewNumber(deviceName=deviceName,
-                                        propertyName='POLLING_PERIOD',
-                                        elements=update,
-                                        )
-        return suc
-
     def updateStatus(self):
         """
         updateStatus emits the actual azimuth status every 3 second in case of
@@ -95,7 +68,6 @@ class DomeIndi(IndiClass):
                 azimuth = self.data.get('ABS_DOME_POSITION.DOME_ABSOLUTE_POSITION',
                                         0)
                 self.signals.azimuth.emit(azimuth)
-
                 slewing = self.device.ABS_DOME_POSITION['state'] == 'Busy'
                 self.data['Slewing'] = slewing
 
@@ -116,21 +88,17 @@ class DomeIndi(IndiClass):
         """
         if self.device is None:
             return False
-
         if self.deviceName is None or not self.deviceName:
             return False
 
         position = self.device.getNumber('ABS_DOME_POSITION')
-
         if 'DOME_ABSOLUTE_POSITION' not in position:
             return False
 
         position['DOME_ABSOLUTE_POSITION'] = azimuth
-
         suc = self.client.sendNewNumber(deviceName=self.deviceName,
                                         propertyName='ABS_DOME_POSITION',
-                                        elements=position,
-                                        )
+                                        elements=position)
         return suc
 
     def openShutter(self):
@@ -139,22 +107,18 @@ class DomeIndi(IndiClass):
         """
         if self.device is None:
             return False
-
         if self.deviceName is None or not self.deviceName:
             return False
 
         position = self.device.getSwitch('DOME_SHUTTER')
-
         if 'SHUTTER_OPEN' not in position:
             return False
 
         position['SHUTTER_OPEN'] = 'On'
         position['SHUTTER_CLOSE'] = 'Off'
-
         suc = self.client.sendNewSwitch(deviceName=self.deviceName,
                                         propertyName='DOME_SHUTTER',
-                                        elements=position,
-                                        )
+                                        elements=position)
         return suc
 
     def closeShutter(self):
@@ -163,22 +127,58 @@ class DomeIndi(IndiClass):
         """
         if self.device is None:
             return False
-
         if self.deviceName is None or not self.deviceName:
             return False
 
         position = self.device.getSwitch('DOME_SHUTTER')
-
         if 'SHUTTER_CLOSE' not in position:
             return False
 
         position['SHUTTER_OPEN'] = 'Off'
         position['SHUTTER_CLOSE'] = 'On'
-
         suc = self.client.sendNewSwitch(deviceName=self.deviceName,
                                         propertyName='DOME_SHUTTER',
-                                        elements=position,
-                                        )
+                                        elements=position)
+        return suc
+
+    def slewCW(self):
+        """
+        :return: success
+        """
+        if self.device is None:
+            return False
+        if self.deviceName is None or not self.deviceName:
+            return False
+
+        position = self.device.getSwitch('DOME_MOTION')
+        if 'DOME_CW' not in position:
+            return False
+
+        position['DOME_CW'] = 'On'
+        position['DOME_CCW'] = 'Off'
+        suc = self.client.sendNewSwitch(deviceName=self.deviceName,
+                                        propertyName='DOME_MOTION',
+                                        elements=position)
+        return suc
+
+    def slewCCW(self):
+        """
+        :return: success
+        """
+        if self.device is None:
+            return False
+        if self.deviceName is None or not self.deviceName:
+            return False
+
+        position = self.device.getSwitch('DOME_MOTION')
+        if 'DOME_CW' not in position:
+            return False
+
+        position['DOME_CW'] = 'Off'
+        position['DOME_CCW'] = 'On'
+        suc = self.client.sendNewSwitch(deviceName=self.deviceName,
+                                        propertyName='DOME_MOTION',
+                                        elements=position)
         return suc
 
     def abortSlew(self):
@@ -187,19 +187,15 @@ class DomeIndi(IndiClass):
         """
         if self.device is None:
             return False
-
         if self.deviceName is None or not self.deviceName:
             return False
 
         position = self.device.getSwitch('DOME_ABORT_MOTION')
-
         if 'ABORT' not in position:
             return False
 
         position['ABORT'] = 'On'
-
         suc = self.client.sendNewSwitch(deviceName=self.deviceName,
                                         propertyName='DOME_ABORT_MOTION',
-                                        elements=position,
-                                        )
+                                        elements=position)
         return suc
