@@ -20,7 +20,7 @@ import logging
 # external packages
 
 # local imports
-from base.driverDataClass import Signals
+from mw4.base.driverDataClass import Signals
 
 
 class DirectWeather:
@@ -84,8 +84,8 @@ class DirectWeather:
 
         value1 = sett.weatherTemperature
         value2 = sett.weatherPressure
-        value3 = sett.weatherHumidity
-        value4 = sett.weatherDewPoint
+        value3 = sett.weatherDewPoint
+        value4 = sett.weatherHumidity
         value5 = sett.weatherAge
         isValid = None not in [value1, value2, value3, value4, value5]
 
