@@ -10,36 +10,25 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
 # standard libraries
 import logging
+import json
+import os
 
 # external packages
-import PyQt5.QtCore
 import numpy as np
 import requests
 
 # local imports
-from base.tpool import Worker
+from mw4.base.tpool import Worker
+from mw4.base.driverDataClass import Signals
 
 
-class WeatherSignals(PyQt5.QtCore.QObject):
-    """
-    """
-
-    __all__ = ['WeatherSignals']
-    dataReceived = PyQt5.QtCore.pyqtSignal(object)
-
-    serverConnected = PyQt5.QtCore.pyqtSignal()
-    serverDisconnected = PyQt5.QtCore.pyqtSignal(object)
-    deviceConnected = PyQt5.QtCore.pyqtSignal(str)
-    deviceDisconnected = PyQt5.QtCore.pyqtSignal(str)
-
-
-class OnlineWeather(PyQt5.QtCore.QObject):
+class OnlineWeather():
     """
     """
 
@@ -51,7 +40,7 @@ class OnlineWeather(PyQt5.QtCore.QObject):
 
         self.app = app
         self.threadPool = app.threadPool
-        self.signals = WeatherSignals()
+        self.signals = Signals()
         self.location = app.mount.obsSite.location
 
         # minimum set for driver package built in
@@ -60,7 +49,6 @@ class OnlineWeather(PyQt5.QtCore.QObject):
             'onlineWeather': self
         }
         self.deviceName = ''
-
         self.data = {}
         self.defaultConfig = {
             'framework': '',
@@ -73,10 +61,11 @@ class OnlineWeather(PyQt5.QtCore.QObject):
             }
         }
         self.running = False
+        self.enabled = False
         self.hostaddress = ''
         self.apiKey = ''
         self._online = False
-        self.app.update10s.connect(self.updateOpenWeatherMapData)
+        self.app.update10s.connect(self.pollOpenWeatherMapData)
 
     @property
     def online(self):
@@ -85,26 +74,21 @@ class OnlineWeather(PyQt5.QtCore.QObject):
     @online.setter
     def online(self, value):
         self._online = value
-        if value:
-            self.updateOpenWeatherMapData()
+        self.pollOpenWeatherMapData()
 
-    def startCommunication(self, loadConfig=False):
+    def startCommunication(self):
         """
-        :param loadConfig:
         :return: success of reconnecting to server
         """
-        if not self.apiKey:
-            return False
-
-        self.running = True
-        self.updateOpenWeatherMapData()
-        self.signals.deviceConnected.emit('OnlineWeather')
+        self.enabled = True
+        self.pollOpenWeatherMapData()
         return True
 
     def stopCommunication(self):
         """
         :return: success of reconnecting to server
         """
+        self.enabled = False
         self.running = False
         self.data.clear()
         self.signals.deviceDisconnected.emit('OnlineWeather')
@@ -130,78 +114,110 @@ class OnlineWeather(PyQt5.QtCore.QObject):
         dewPoint = (B * alpha) / (A - alpha)
         return dewPoint
 
-    def updateOpenWeatherMapDataWorker(self, data=None):
+    def processOpenWeatherMapData(self):
         """
-        :param data:
         :return: success
         """
-        if data is None:
-            self.signals.dataReceived.emit(None)
+        dataFile = self.app.mwGlob['dataDir'] + '/openweathermap.data'
+        dataFile = os.path.normpath(dataFile)
+        if not os.path.isfile(dataFile):
+            self.log.info(f'{dataFile} not available')
             return False
 
-        if 'list' not in data:
-            self.signals.dataReceived.emit(None)
+        try:
+            with open(dataFile, 'r') as f:
+                data = json.load(f)
+        except Exception as e:
+            self.log.warning(f'Cannot load data file, error: {e}')
             return False
 
-        if len(data['list']) == 0:
-            self.signals.dataReceived.emit(None)
-            return False
+        self.log.trace(f'onlineWeatherData:[{data}]')
 
-        val = data['list'][0]
-        self.log.trace(f'onlineWeatherData:[{val}]')
-
-        if 'main' in val:
-            self.data['temperature'] = val['main']['temp'] - 273.15
-            self.data['pressure'] = val['main']['grnd_level']
-            self.data['humidity'] = val['main']['humidity']
+        if 'main' in data:
+            self.data['temperature'] = data['main'].get('temp', 273.15) - 273.15
+            self.data['pressure'] = data['main'].get('pressure', 0)
+            self.data['humidity'] = data['main'].get('humidity', 0)
             self.data['dewPoint'] = self.getDewPoint(self.data['temperature'],
                                                      self.data['humidity'])
-        if 'clouds' in val:
-            self.data['cloudCover'] = val['clouds']['all']
+            self.data['WEATHER_PARAMETERS.WEATHER_TEMPERATURE'] = self.data['temperature']
+            self.data['WEATHER_PARAMETERS.WEATHER_PRESSURE'] = self.data['pressure']
+        else:
+            return False
 
-        if 'wind' in val:
-            self.data['windSpeed'] = val['wind']['speed']
-            self.data['windDir'] = val['wind']['deg']
+        if 'clouds' in data:
+            self.data['cloudCover'] = data['clouds'].get('all', 0)
 
-        if 'rain' in val:
-            self.data['rain'] = val['rain']['3h']
+        if 'wind' in data:
+            self.data['windSpeed'] = data['wind'].get('speed', 0)
+            self.data['windDir'] = data['wind'].get('deg', 0)
 
-        self.signals.dataReceived.emit(self.data)
+        if 'rain' in data:
+            self.data['rain'] = data['rain'].get('3h', 0)
+        else:
+            self.data['rain'] = 0
         return True
 
-    def getOpenWeatherMapDataWorker(self, url=''):
+    def workerGetOpenWeatherMapData(self, url):
         """
         :param url:
         :return: data
         """
-        if not url:
-            return None
-
         try:
             data = requests.get(url, timeout=30)
         except TimeoutError:
             self.log.warning(f'[{url}] not reachable')
-            return None
+            return False
         except Exception as e:
             self.log.critical(f'[{url}] general exception: [{e}]')
-            return None
+            return False
         if data.status_code != 200:
             self.log.warning(f'[{url}] status is not 200')
-            return None
+            return False
 
-        return data.json()
+        with open(self.app.mwGlob['dataDir'] + '/openweathermap.data', 'w+') as f:
+            json.dump(data.json(), f, indent=4)
+            self.log.trace(data.json())
+        return True
+
+    def sendStatus(self, status):
+        """
+        :return:
+        """
+        if not status and self.running:
+            self.signals.deviceDisconnected.emit('OnlineWeather')
+        elif status and not self.running:
+            self.signals.deviceConnected.emit('OnlineWeather')
+        return True
 
     def getOpenWeatherMapData(self, url=''):
         """
         :param url:
         :return: true for test purpose
         """
-        worker = Worker(self.getOpenWeatherMapDataWorker, url)
-        worker.signals.result.connect(self.updateOpenWeatherMapDataWorker)
+        worker = Worker(self.workerGetOpenWeatherMapData, url)
+        worker.signals.finished.connect(self.processOpenWeatherMapData)
+        worker.signals.result.connect(self.sendStatus)
         self.threadPool.start(worker)
         return True
 
-    def updateOpenWeatherMapData(self):
+    def loadingFileNeeded(self, fileName, hours):
+        """
+        :param fileName:
+        :param hours:
+        :return:
+        """
+        filePath = self.app.mwGlob['dataDir'] + '/' + fileName
+        filePath = os.path.normpath(filePath)
+        if not os.path.isfile(filePath):
+            return True
+
+        ageData = self.app.mount.obsSite.loader.days_old(fileName)
+        if ageData < hours / 24:
+            return False
+        else:
+            return True
+
+    def pollOpenWeatherMapData(self):
         """
         updateOpenWeatherMap downloads the actual OpenWeatherMap image and
         displays it in environment tab. it checks first if online is set,
@@ -209,18 +225,28 @@ class OnlineWeather(PyQt5.QtCore.QObject):
 
         :return: success
         """
+        if not self.enabled:
+            return False
+        if not self.apiKey:
+            return False
+
         if not self.online and self.running:
-            self.signals.dataReceived.emit(None)
-            self.stopCommunication()
-            return False
-        if not self.running:
+            self.signals.deviceDisconnected.emit('OnlineWeather')
+            self.running = False
             return False
+        elif self.online and not self.running:
+            self.signals.deviceConnected.emit('OnlineWeather')
+            self.running = True
+
+        if not self.loadingFileNeeded('openweathermap.data', 1):
+            self.processOpenWeatherMapData()
+            return True
 
         lat = self.location.latitude.degrees
         lon = self.location.longitude.degrees
 
-        webSite = f'http://{self.hostaddress}/data/2.5/forecast'
-        url = f'{webSite}?lat={lat:1.2f}&lon={lon:1.2f}&APPID={self.apiKey}'
-        self.getOpenWeatherMapData(url=url)
+        webSite = f'http://{self.hostaddress}/data/2.5/weather'
+        url = f'{webSite}?lat={lat:1.2f}&lon={lon:1.2f}'
+        self.getOpenWeatherMapData(url=url + f'&APPID={self.apiKey}')
         self.log.debug(f'{url}')
         return True
