@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -21,11 +21,11 @@ import platform
 # external packages
 
 # local imports
-from base.driverDataClass import Signals
-from logic.environment.sensorWeatherIndi import SensorWeatherIndi
-from logic.environment.sensorWeatherAlpaca import SensorWeatherAlpaca
+from mw4.base.driverDataClass import Signals
+from mw4.logic.environment.sensorWeatherIndi import SensorWeatherIndi
+from mw4.logic.environment.sensorWeatherAlpaca import SensorWeatherAlpaca
 if platform.system() == 'Windows':
-    from logic.environment.sensorWeatherAscom import SensorWeatherAscom
+    from mw4.logic.environment.sensorWeatherAscom import SensorWeatherAscom
 
 
 class SensorWeather:
@@ -54,15 +54,34 @@ class SensorWeather:
         for fw in self.run:
             self.defaultConfig['frameworks'].update({fw: self.run[fw].defaultConfig})
 
-    def startCommunication(self, loadConfig=False):
+    @property
+    def updateRate(self):
+        return self.run[self.framework].updateRate
+
+    @updateRate.setter
+    def updateRate(self, value):
+        value = int(value)
+        for fw in self.run:
+            self.run[fw].updateRate = value
+
+    @property
+    def loadConfig(self):
+        return self.run[self.framework].loadConfig
+
+    @loadConfig.setter
+    def loadConfig(self, value):
+        value = bool(value)
+        for fw in self.run:
+            self.run[fw].loadConfig = value
+
+    def startCommunication(self):
         """
-        :param loadConfig:
         :return: success
         """
         if self.framework not in self.run.keys():
             return False
 
-        suc = self.run[self.framework].startCommunication(loadConfig=loadConfig)
+        suc = self.run[self.framework].startCommunication()
         return suc
 
     def stopCommunication(self):
