@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -20,7 +19,7 @@
 # external packages
 
 # local imports
-from base.ascomClass import AscomClass
+from mw4.base.ascomClass import AscomClass
 
 
 class FilterAscom(AscomClass):
@@ -34,12 +33,10 @@ class FilterAscom(AscomClass):
     CYCLE_POLL_DATA = 1000
 
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-
+        super().__init__(app=app, data=data)
         # as we have in the base class only the base client there, we will get more
         # specialized with Dome (which is derived from the base class)
         self.signals = signals
-        self.data = data
 
     def workerGetInitialConfig(self):
         """
