@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -20,7 +19,7 @@
 # external packages
 
 # local imports
-from base.ascomClass import AscomClass
+from mw4.base.ascomClass import AscomClass
 
 
 class FocuserAscom(AscomClass):
@@ -30,10 +29,8 @@ class FocuserAscom(AscomClass):
     __all__ = ['FocuserAscom']
 
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-
+        super().__init__(app=app, data=data)
         self.signals = signals
-        self.data = data
 
     def workerPollData(self):
         """
@@ -61,5 +58,5 @@ class FocuserAscom(AscomClass):
         if not self.deviceConnected:
             return False
 
-        self.getAscomProperty('halt')
+        self.getAscomProperty('Halt')
         return True
