@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -22,9 +22,9 @@ from PyQt5.QtCore import QMutex
 import numpy as np
 
 # local imports
-from base.driverDataClass import Signals
-from logic.measure.measureRaw import MeasureDataRaw
-from logic.measure.measureCSV import MeasureDataCSV
+from mw4.base.driverDataClass import Signals
+from mw4.logic.measure.measureRaw import MeasureDataRaw
+from mw4.logic.measure.measureCSV import MeasureDataCSV
 
 
 class MeasureData:
@@ -35,11 +35,12 @@ class MeasureData:
     log = logging.getLogger(__name__)
 
     # maximum size of measurement task
-    MAXSIZE = 24 * 60 * 60
+    MAXSIZE = 48 * 60 * 60
 
     def __init__(self, app):
         super().__init__()
         self.app = app
+        self.msg = app.msg
         self.signals = Signals()
         self.mutexMeasure = QMutex()
 
@@ -47,6 +48,8 @@ class MeasureData:
         self.shorteningStart = True
         self.raRef = None
         self.decRef = None
+        self.angularPosRaRef = None
+        self.angularPosDecRef = None
         self.devices = {}
         self.deviceName = ''
 
@@ -61,9 +64,8 @@ class MeasureData:
             self.defaultConfig['frameworks'].update(self.run[fw].defaultConfig)
         self.framework = ''
 
-    def startCommunication(self, loadConfig=False):
+    def startCommunication(self):
         """
-        :param loadConfig:
         :return: True for test purpose
         """
         deviceStat = self.app.deviceStat
@@ -74,10 +76,10 @@ class MeasureData:
             return False
 
         name = self.run[self.framework].deviceName
-        suc = self.run[self.framework].startCommunication(loadConfig=loadConfig)
+        suc = self.run[self.framework].startCommunication()
         if suc:
             self.signals.deviceConnected.emit(name)
-            self.app.message.emit(f'MEASURE found:       [{name}]', 0)
+            self.msg.emit(0, 'System', 'Measure device found', f'{name}')
 
         return suc
 
@@ -92,7 +94,7 @@ class MeasureData:
         name = self.run[self.framework].deviceName
         self.signals.serverDisconnected.emit({name: 0})
         self.signals.deviceDisconnected.emit(name)
-        self.app.message.emit(f'MEASURE remove:      [{name}]', 0)
+        self.msg.emit(0, 'System', 'Measure device removed', f'{name}')
         return suc
 
     def setEmptyData(self):
@@ -132,6 +134,9 @@ class MeasureData:
         self.data['powTemp'] = np.empty(shape=[0, 1])
         self.data['powDew'] = np.empty(shape=[0, 1])
         self.data['cameraTemp'] = np.empty(shape=[0, 1])
+        self.data['cameraPower'] = np.empty(shape=[0, 1])
+        self.data['timeDiff'] = np.empty(shape=[0, 1])
+
         return True
 
     def calculateReference(self):
@@ -221,7 +226,6 @@ class MeasureData:
         """
         getDirectWeather checks if data is already collected and send 0 in case of missing
         data.
-
         :return: values
         """
         temp = self.app.mount.setting.weatherTemperature
@@ -253,7 +257,7 @@ class MeasureData:
         :return: success
         """
         if not self.mutexMeasure.tryLock():
-            self.log.debug('overrun in measure')
+            self.log.info('overrun in measure')
             return False
 
         lenData = len(self.data['time'])
@@ -329,7 +333,12 @@ class MeasureData:
         ccd = self.app.camera
         temp = ccd.data.get('CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE', 0)
         dat['cameraTemp'] = np.append(dat['cameraTemp'], temp)
+        temp = ccd.data.get('CCD_COOLER_POWER.CCD_COOLER_VALUE', 0)
+        dat['cameraPower'] = np.append(dat['cameraPower'], temp)
+        delta = self.app.mount.obsSite.timeDiff * 1000
+        dat['timeDiff'] = np.append(dat['timeDiff'], delta)
+        if len(dat['timeDiff']) == 31:
+            dat['timeDiff'][0:29].fill(dat['timeDiff'][30])
 
         self.mutexMeasure.unlock()
-
         return True
