@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -54,6 +53,7 @@ class MeasureDataCSV(PyQt5.QtCore.QObject):
         self.parent = parent
         self.data = data
         self.deviceName = 'CSV'
+        self.csvFilename = ''
         self.defaultConfig = {
             'csv': {
                 'deviceName': 'save to file',
@@ -69,14 +69,12 @@ class MeasureDataCSV(PyQt5.QtCore.QObject):
 
     def openCSV(self):
         """
-
         :return: success
         """
-
         nameTime = self.app.mount.obsSite.timeJD.utc_strftime('%Y-%m-%d-%H-%M-%S')
-        csvFilename = f'{self.app.mwGlob["measureDir"]}/measure-{nameTime}.csv'
+        self.csvFilename = f'{self.app.mwGlob["measureDir"]}/measure-{nameTime}.csv'
 
-        self.csvFile = open(csvFilename, 'w+')
+        self.csvFile = open(self.csvFilename, 'w+')
         fieldnames = ['time',
                       'deltaRaJNow',
                       'deltaDecJNow',
@@ -109,6 +107,8 @@ class MeasureDataCSV(PyQt5.QtCore.QObject):
                       'powTemp',
                       'powDew',
                       'cameraTemp',
+                      'cameraPower',
+                      'timeDiff',
                       ]
 
         self.csvWriter = csv.DictWriter(self.csvFile, fieldnames=fieldnames)
@@ -118,7 +118,6 @@ class MeasureDataCSV(PyQt5.QtCore.QObject):
 
     def writeCSV(self):
         """
-
         :return: success for write
         """
         if not self.csvFile or not self.csvWriter:
@@ -129,12 +128,10 @@ class MeasureDataCSV(PyQt5.QtCore.QObject):
             row[key] = self.data[key][0]
 
         self.csvWriter.writerow(row)
-
         return True
 
     def closeCSV(self):
         """
-
         :return: success for close
         """
         if not self.csvFile or not self.csvWriter:
@@ -143,30 +140,23 @@ class MeasureDataCSV(PyQt5.QtCore.QObject):
         self.csvFile.close()
         self.csvWriter = None
         self.csvFile = None
-
         return True
 
-    def startCommunication(self, loadConfig=False):
+    def startCommunication(self):
         """
         startCommunication starts cycling of the polling.
-
-        :param loadConfig:
         :return: True for test purpose
         """
-
         self.parent.setEmptyData()
         self.timerTask.start(self.CYCLE_UPDATE_TASK)
         self.openCSV()
-
         return True
 
     def stopCommunication(self):
         """
         stopCommunication stops the device
-
         :return: true for test purpose
         """
-
         self.closeCSV()
         self.timerTask.stop()
         return True
@@ -184,7 +174,6 @@ class MeasureDataCSV(PyQt5.QtCore.QObject):
 
         :return: success
         """
-
         suc = self.parent.measureTask()
         if suc:
             self.writeCSV()
