@@ -28,7 +28,7 @@ from skyfield import almanac
 from scipy.spatial import distance
 
 # local imports
-from base import transform
+from mw4.base import transform
 
 __all__ = ['HaDecToAltAz',
            'DataPoint',
@@ -603,6 +603,7 @@ class DataPoint(object):
             return False
 
         self.horizonP = value
+        self.horizonP.sort(key=lambda x: x[1])
 
         # backup solution
         if csv:
