@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -25,7 +24,7 @@ from PyQt5.QtCore import pyqtSignal, QMutex, QTimer
 import requests
 
 # local imports
-from base.driverDataClass import Signals
+from mw4.base.driverDataClass import Signals
 
 
 class RelaySignals(Signals):
@@ -77,9 +76,8 @@ class KMRelay:
         self.timerTask.setSingleShot(False)
         self.timerTask.timeout.connect(self.cyclePolling)
 
-    def startCommunication(self, loadConfig=False):
+    def startCommunication(self):
         """
-        :param loadConfig:
         :return: success
         """
         if not self.hostaddress:
