@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -22,10 +21,10 @@ import platform
 # external packages
 
 # local imports
-from base.driverDataClass import Signals
-from logic.powerswitch.pegasusUPBIndi import PegasusUPBIndi
-from logic.powerswitch.pegasusUPBAscom import PegasusUPBAscom
-from logic.powerswitch.pegasusUPBAlpaca import PegasusUPBAlpaca
+from mw4.base.driverDataClass import Signals
+from mw4.logic.powerswitch.pegasusUPBIndi import PegasusUPBIndi
+from mw4.logic.powerswitch.pegasusUPBAscom import PegasusUPBAscom
+from mw4.logic.powerswitch.pegasusUPBAlpaca import PegasusUPBAlpaca
 
 
 class PegasusUPB:
@@ -52,15 +51,34 @@ class PegasusUPB:
         for fw in self.run:
             self.defaultConfig['frameworks'].update({fw: self.run[fw].defaultConfig})
 
-    def startCommunication(self, loadConfig=False):
+    @property
+    def updateRate(self):
+        return self.run[self.framework].updateRate
+
+    @updateRate.setter
+    def updateRate(self, value):
+        value = int(value)
+        for fw in self.run:
+            self.run[fw].updateRate = value
+
+    @property
+    def loadConfig(self):
+        return self.run[self.framework].loadConfig
+
+    @loadConfig.setter
+    def loadConfig(self, value):
+        value = bool(value)
+        for fw in self.run:
+            self.run[fw].loadConfig = value
+
+    def startCommunication(self):
         """
-        :param loadConfig:
         :return: success
         """
         if self.framework not in self.run.keys():
             return False
 
-        suc = self.run[self.framework].startCommunication(loadConfig=loadConfig)
+        suc = self.run[self.framework].startCommunication()
         return suc
 
     def stopCommunication(self):
