@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -20,7 +19,7 @@
 # external packages
 
 # local imports
-from base.indiClass import IndiClass
+from mw4.base.indiClass import IndiClass
 
 
 class PegasusUPBIndi(IndiClass):
@@ -35,8 +34,7 @@ class PegasusUPBIndi(IndiClass):
 
     def __init__(self, app=None, signals=None, data=None):
         self.signals = signals
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-        self.data = data
+        super().__init__(app=app, data=data)
         self.modelVersion = 0
 
     def setUpdateConfig(self, deviceName):
@@ -44,20 +42,15 @@ class PegasusUPBIndi(IndiClass):
         :param deviceName:
         :return: success
         """
-        if deviceName != self.deviceName:
-            return False
-        if self.device is None:
+        if not super().setUpdateConfig(deviceName):
             return False
 
         update = self.device.getNumber('POLLING')
-        if update.get('PERIOD', 0) == self.UPDATE_RATE:
-            return True
-
-        update['PERIOD'] = self.UPDATE_RATE
+        update['PERIOD'] = self.updateRate
         suc = self.client.sendNewNumber(deviceName=deviceName,
                                         propertyName='POLLING',
-                                        elements=update,
-                                        )
+                                        elements=update)
+        self.log.info(f'Polling [{deviceName}] success: [{suc}]')
         return suc
 
     def updateText(self, deviceName, propertyName):
