@@ -19,7 +19,7 @@
 # external packages
 
 # local imports
-from base.ascomClass import AscomClass
+from mw4.base.ascomClass import AscomClass
 
 
 class TelescopeAscom(AscomClass):
