@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -21,8 +21,8 @@ import logging
 import skyfield.api
 
 # local imports
-from mountcontrol.convert import valueToAngle
-from mountcontrol.convert import stringToAngle
+from mw4.mountcontrol.convert import valueToAngle
+from mw4.mountcontrol.convert import stringToAngle
 
 
 class AlignStar(object):
