@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -20,8 +20,8 @@ import logging
 # external packages
 
 # local imports
-from mountcontrol.connection import Connection
-from mountcontrol.convert import valueToInt
+from mw4.mountcontrol.connection import Connection
+from mw4.mountcontrol.convert import valueToInt
 
 
 class Firmware(object):
