@@ -13,7 +13,7 @@
 #
 # Michael Würtenberger
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -24,13 +24,13 @@ import logging
 import skyfield.api
 
 # local imports
-from mountcontrol.connection import Connection
-from mountcontrol.convert import valueToFloat
-from mountcontrol.convert import valueToInt
-from mountcontrol.convert import valueToAngle
-from mountcontrol.convert import sexagesimalizeToInt
-from mountcontrol.alignStar import AlignStar
-from mountcontrol.modelStar import ModelStar
+from mw4.mountcontrol.connection import Connection
+from mw4.mountcontrol.convert import valueToFloat
+from mw4.mountcontrol.convert import valueToInt
+from mw4.mountcontrol.convert import valueToAngle
+from mw4.mountcontrol.convert import sexagesimalizeToInt
+from mw4.mountcontrol.alignStar import AlignStar
+from mw4.mountcontrol.modelStar import ModelStar
 
 
 class Model(object):
@@ -545,7 +545,7 @@ class Model(object):
         :param      number: number of point in int / float
         :return:    success
         """
-        if not isinstance(number, (int, float)):
+        if isinstance(number, str):
             return False
 
         number = int(number)
