@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -22,11 +22,11 @@ from skyfield.api import Star, Angle
 import numpy
 
 # local imports
-from mountcontrol.convert import stringToDegree
-from mountcontrol.convert import valueToAngle
-from mountcontrol.convert import valueToFloat
-from mountcontrol.convert import valueToInt
-from mountcontrol.convert import topoToAltAz
+from mw4.mountcontrol.convert import stringToDegree
+from mw4.mountcontrol.convert import valueToAngle
+from mw4.mountcontrol.convert import valueToFloat
+from mw4.mountcontrol.convert import valueToInt
+from mw4.mountcontrol.convert import topoToAltAz
 
 
 class ModelStar(object):
@@ -109,7 +109,7 @@ class ModelStar(object):
             ha = stringToDegree(ha)
             dec = stringToDegree(dec)
 
-            if not ha or not dec:
+            if ha is None or dec is None:
                 self.log.warning('Malformed value: {0}'.format(value))
                 return
             self._coord = Star(ra_hours=ha, dec_degrees=dec)
