@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -20,17 +20,50 @@ import logging
 # external packages
 
 # local imports
-from mountcontrol.firmware import Firmware
-from mountcontrol.dome import Dome
-from mountcontrol.setting import Setting
-from mountcontrol.obsSite import ObsSite
-from mountcontrol.model import Model
-from mountcontrol.satellite import Satellite
-from mountcontrol.geometry import Geometry
+from mw4.mountcontrol.firmware import Firmware
+from mw4.mountcontrol.dome import Dome
+from mw4.mountcontrol.setting import Setting
+from mw4.mountcontrol.obsSite import ObsSite
+from mw4.mountcontrol.model import Model
+from mw4.mountcontrol.satellite import Satellite
+from mw4.mountcontrol.geometry import Geometry
 
 
-__all__ = ['Mount',
-           ]
+__all__ = ['Mount']
+
+
+def checkFormatMAC(value):
+    """
+    checkFormatMAC makes some checks to ensure that the format of the
+    string is ok for WOL package.
+
+    :param      value: string with mac address
+    :return:    checked string in upper cases
+    """
+    if not value:
+        return None
+
+    if not isinstance(value, str):
+        return None
+
+    value = value.upper()
+    value = value.replace('.', ':')
+    value = value.split(':')
+    if len(value) != 6:
+        return None
+
+    for chunk in value:
+        if len(chunk) != 2:
+            return None
+
+        for char in chunk:
+            if char not in ['0', '1', '2', '3', '4',
+                            '5', '6', '7', '8', '9',
+                            'A', 'B', 'C', 'D', 'E', 'F']:
+                return None
+
+    value = '{0:2s}:{1:2s}:{2:2s}:{3:2s}:{4:2s}:{5:2s}'.format(*value)
+    return value
 
 
 class Mount(object):
@@ -102,7 +135,7 @@ class Mount(object):
 
     @MAC.setter
     def MAC(self, value):
-        value = self.checkFormatMAC(value)
+        value = checkFormatMAC(value)
         self._MAC = value
 
     def checkFormatHost(self, value):
@@ -125,44 +158,6 @@ class Mount(object):
 
         return value
 
-    def checkFormatMAC(self, value):
-        """
-        checkFormatMAC makes some checks to ensure that the format of the
-        string is ok for WOL package.
-
-        :param      value: string with mac address
-        :return:    checked string in upper cases
-        """
-        if not value:
-            self.log.info('wrong MAC value: {0}'.format(value))
-            return None
-
-        if not isinstance(value, str):
-            self.log.info('wrong MAC value: {0}'.format(value))
-            return None
-
-        value = value.upper()
-        value = value.replace('.', ':')
-        value = value.split(':')
-        if len(value) != 6:
-            self.log.info('wrong MAC value: {0}'.format(value))
-            return None
-
-        for chunk in value:
-            if len(chunk) != 2:
-                self.log.info('wrong MAC value: {0}'.format(value))
-                return None
-
-            for char in chunk:
-                if char not in ['0', '1', '2', '3', '4',
-                                '5', '6', '7', '8', '9',
-                                'A', 'B', 'C', 'D', 'E', 'F']:
-                    self.log.info('wrong MAC value: {0}'.format(value))
-                    return None
-
-        value = '{0:2s}:{1:2s}:{2:2s}:{3:2s}:{4:2s}:{5:2s}'.format(*value)
-        return value
-
     def resetData(self):
         """
         resetData deletes all data already stored in classes just by redefining
