@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -26,14 +26,14 @@ import skyfield.starlib as starlib
 import numpy as np
 
 # local imports
-from base.transform import diffModulusSign
-from .connection import Connection
-from .convert import stringToAngle
-from .convert import stringToDegree
-from .convert import valueToFloat
-from .convert import valueToInt
-from .convert import valueToAngle
-from .convert import sexagesimalizeToInt
+from mw4.base.transform import diffModulusSign
+from mw4.mountcontrol.connection import Connection
+from mw4.mountcontrol.convert import stringToAngle
+from mw4.mountcontrol.convert import stringToDegree
+from mw4.mountcontrol.convert import valueToFloat
+from mw4.mountcontrol.convert import valueToInt
+from mw4.mountcontrol.convert import valueToAngle
+from mw4.mountcontrol.convert import sexagesimalizeToInt
 
 
 class ObsSite(object):
@@ -91,6 +91,7 @@ class ObsSite(object):
         self.verbose = verbose
         self.loader = None
         self.AzDirection = None
+        self.flipped = False
         self.lastAz = None
         self._location = None
         self.ts = None
@@ -569,7 +570,7 @@ class ObsSite(object):
         :return:
         """
         if platform.system() == 'Windows':
-            corrTerm = +0.001
+            corrTerm = -0.001
         elif platform.system() == 'Linux':
             corrTerm = -0.001
         elif platform.system() == 'Darwin':
@@ -667,6 +668,7 @@ class ObsSite(object):
             else:
                 slewTypes['keep'] = ':MA#'
 
+        self.flipped = self._piersideTarget != self.pierside
         conn = Connection(self.host)
 
         commandString = ':PO#' + slewTypes[slewType]
@@ -1269,17 +1271,6 @@ class ObsSite(object):
 
         return True
 
-    def stopMoveNorth(self):
-        """
-        :return:    success
-        """
-        conn = Connection(self.host)
-        suc, response, numberOfChunks = conn.communicate(':Qn#')
-        if not suc:
-            return False
-
-        return True
-
     def stopMoveAll(self):
         """
         :return:    success
@@ -1291,6 +1282,17 @@ class ObsSite(object):
 
         return True
 
+    def stopMoveNorth(self):
+        """
+        :return:    success
+        """
+        conn = Connection(self.host)
+        suc, response, numberOfChunks = conn.communicate(':Qn#')
+        if not suc:
+            return False
+
+        return True
+
     def stopMoveEast(self):
         """
         stopMoveEast sends the flip command to the mount.
@@ -1319,7 +1321,7 @@ class ObsSite(object):
         :return:    success
         """
         conn = Connection(self.host)
-        suc, response, numberOfChunks = conn.communicate(':Ww#')
+        suc, response, numberOfChunks = conn.communicate(':Qw#')
         if not suc:
             return False
 
