@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -24,8 +24,8 @@ import wakeonlan
 import numpy as np
 
 # local imports
-from base.tpool import Worker
-import mountcontrol.mount
+from mw4.base.tpool import Worker
+import mw4.mountcontrol.mount
 
 
 __all__ = ['Mount',
@@ -62,7 +62,7 @@ class MountSignals(PyQt5.QtCore.QObject):
     alert = PyQt5.QtCore.pyqtSignal()
 
 
-class Mount(mountcontrol.mount.Mount):
+class Mount(mw4.mountcontrol.mount.Mount):
     """
     The Mount class is the main interface for interacting with the mount computer.
     The user could:
@@ -82,7 +82,7 @@ class Mount(mountcontrol.mount.Mount):
 
     """
 
-    CYCLE_POINTING = 550
+    CYCLE_POINTING = 500
     CYCLE_DOME = 950
     CYCLE_CLOCK = 1000
     CYCLE_MOUNT_UP = 2700
@@ -91,23 +91,16 @@ class Mount(mountcontrol.mount.Mount):
     # set timeout
     SOCKET_TIMEOUT = 3.5
 
-    def __init__(self,
-                 host=None,
-                 MAC=None,
-                 threadPool=None,
-                 pathToData=None,
-                 verbose=None,
-                 ):
+    def __init__(self, host=None, MAC=None,
+                 threadPool=None, pathToData=None, verbose=None):
 
-        super().__init__(host=host,
-                         MAC=MAC,
-                         pathToData=pathToData,
-                         verbose=verbose,
-                         )
+        super().__init__(host=host, MAC=MAC,
+                         pathToData=pathToData, verbose=verbose)
 
         self.threadPool = threadPool
         self.mountUp = False
-        self._settlingTime = 0
+        self._waitTime = 0
+        self._waitTimeFlip = 0
         self.statusAlert = False
         self.statusSlew = True
         self.signals = MountSignals()
@@ -129,17 +122,17 @@ class Mount(mountcontrol.mount.Mount):
         self.timerMountUp.timeout.connect(self.cycleCheckMountUp)
         self.settlingWait = PyQt5.QtCore.QTimer()
         self.settlingWait.setSingleShot(True)
-        self.settlingWait.timeout.connect(self.waitSettlingAndEmit)
+        self.settlingWait.timeout.connect(self.waitAfterSettlingAndEmit)
 
     @property
-    def settlingTime(self):
-        return self._settlingTime / 1000
+    def waitTimeFlip(self):
+        return self._waitTimeFlip / 1000
 
-    @settlingTime.setter
-    def settlingTime(self, value):
-        self._settlingTime = value * 1000
+    @waitTimeFlip.setter
+    def waitTimeFlip(self, value):
+        self._waitTimeFlip = value * 1000
 
-    def waitSettlingAndEmit(self):
+    def waitAfterSettlingAndEmit(self):
         """
         :return: true for test purpose
         """
@@ -259,7 +252,7 @@ class Mount(mountcontrol.mount.Mount):
 
     def clearCyclePointing(self):
         """
-        the cyclic or long lasting tasks for getting date from the mount should
+        the cyclic or long-lasting tasks for getting date from the mount should
         not run twice for the same data at the same time.
 
         :return: true for test purpose
@@ -271,9 +264,14 @@ class Mount(mountcontrol.mount.Mount):
         else:
             self.statusAlert = False
 
+        if self.obsSite.flipped:
+            settleWait = self._waitTimeFlip
+        else:
+            settleWait = 0
+
         if self.obsSite.status not in [2, 6]:
             if not self.statusSlew:
-                self.settlingWait.start(self._settlingTime)
+                self.settlingWait.start(int(settleWait))
             self.statusSlew = True
         else:
             self.statusSlew = False
@@ -660,7 +658,7 @@ class Mount(mountcontrol.mount.Mount):
         self.calcTrajectory(replay=sim)
         return True
 
-    def workerProgTrajectory(self, alt=[], az=[], sim=False):
+    def workerProgTrajectory(self, alt=None, az=None, sim=False):
         """
         :param alt:
         :param az:
@@ -680,7 +678,7 @@ class Mount(mountcontrol.mount.Mount):
         self.signals.trajectoryProgress.emit(100)
         return sim
 
-    def progTrajectory(self, start, alt=[], az=[], sim=False):
+    def progTrajectory(self, start, alt=None, az=None, sim=False):
         """
         :param start:
         :param alt:
