@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -22,9 +22,9 @@ import skyfield.timelib
 from skyfield.api import Angle
 
 # local imports
-from mountcontrol.connection import Connection
-from mountcontrol.convert import valueToAngle
-from mountcontrol.convert import valueToFloat
+from mw4.mountcontrol.connection import Connection
+from mw4.mountcontrol.convert import valueToAngle
+from mw4.mountcontrol.convert import valueToFloat
 
 
 class TLEParams(object):
@@ -640,7 +640,7 @@ class Satellite(object):
 
         return True
 
-    def progTrajectory(self, alt=[], az=[]):
+    def progTrajectory(self, alt, az):
         """
         :param alt:
         :param az:
